addEmailBan abstract method
- @POST.new('/admin/bans/email/add')
- @Body.new() required BanEmailRequest body,
Add email ban.
Ban one or more email addresses from registering or creating accounts. Users attempting to use banned emails will be blocked.
body - Name not received - field will be skipped.
Implementation
@POST('/admin/bans/email/add')
Future<void> addEmailBan({@Body() required BanEmailRequest body});