addPhraseBan abstract method
- @POST.new('/admin/bans/phrase/add')
- @Body.new() required BanPhraseRequest body,
Add phrase ban.
Ban a phrase. Matching is case-insensitive and also normalizes common bypass tricks such as inserted whitespace, punctuation, invisible characters, and compatibility glyphs.
body - Name not received - field will be skipped.
Implementation
@POST('/admin/bans/phrase/add')
Future<void> addPhraseBan({@Body() required BanPhraseRequest body});