adminBillingRefundPolicyCancelNow abstract method

  1. @POST.new('/admin/billing/users/{userId}/refund-policy-cancel-now')
Future<AdminBillingRefundLatestInvoiceCancelResponse> adminBillingRefundPolicyCancelNow({
  1. @Path.new('userId') required String userId,
  2. @Body.new() required AdminBillingRefundLatestInvoiceCancelRequest body,
})

Apply refund policy and cancel subscription immediately.

Cancels a user subscription immediately and applies the support refund policy against the latest paid Stripe invoice.

userId - The userId.

body - Name not received - field will be skipped.

Implementation

@POST('/admin/billing/users/{userId}/refund-policy-cancel-now')
Future<AdminBillingRefundLatestInvoiceCancelResponse>
adminBillingRefundPolicyCancelNow({
  @Path('userId') required String userId,
  @Body() required AdminBillingRefundLatestInvoiceCancelRequest body,
});