getLegalHoldStatus abstract method

  1. @GET.new('/admin/reports/{report_id}/legal-hold')
Future<LegalHoldResponse> getLegalHoldStatus({
  1. @Path.new('report_id') required String reportId,
})

Get legal hold status.

Retrieve the current legal hold status of a report. Indicates whether evidence is preserved for legal proceedings and the hold expiration date if set.

reportId - The report id.

Implementation

@GET('/admin/reports/{report_id}/legal-hold')
Future<LegalHoldResponse> getLegalHoldStatus({
  @Path('report_id') required String reportId,
});