getVoiceDiagnosticDownload abstract method

  1. @POST.new('/admin/voice-diagnostics/download')
Future<GetVoiceDiagnosticDownloadResponse> getVoiceDiagnosticDownload({
  1. @Body.new() required GetVoiceDiagnosticDownloadRequest body,
})

Get a presigned download URL for a voice diagnostic upload.

Issues a short-lived (5 minutes) presigned GET URL for the requested voice diagnostic archive in the dedicated bucket. Returns 404 (UnknownUserError) when the upload row does not exist for that user. Requires VOICE_DIAGNOSTICS_VIEW permission.

body - Name not received - field will be skipped.

Implementation

@POST('/admin/voice-diagnostics/download')
Future<GetVoiceDiagnosticDownloadResponse> getVoiceDiagnosticDownload({
  @Body() required GetVoiceDiagnosticDownloadRequest body,
});