listVisionarySlots abstract method
List all visionary slots.
Retrieve the complete list of visionary slots with their reservation status.
Implementation
@GET('/admin/visionary-slots')
Future<ListVisionarySlotsResponse> listVisionarySlots();
List all visionary slots.
Retrieve the complete list of visionary slots with their reservation status.
@GET('/admin/visionary-slots')
Future<ListVisionarySlotsResponse> listVisionarySlots();