lookupMessageByAttachment abstract method
- @POST.new('/admin/messages/lookup-by-attachment')
- @Body.new() required LookupMessageByAttachmentRequest body,
Look up message by attachment.
Finds and retrieves message containing a specific attachment by ID. Used to locate messages with sensitive or illegal content. Requires MESSAGE_LOOKUP permission.
body - Name not received - field will be skipped.
Implementation
@POST('/admin/messages/lookup-by-attachment')
Future<LookupMessageResponse> lookupMessageByAttachment({
@Body() required LookupMessageByAttachmentRequest body,
});