reportMessageAttachmentToNcmec abstract method

  1. @POST.new('/admin/messages/report-to-ncmec')
Future<NcmecAttachmentSubmitResultResponse> reportMessageAttachmentToNcmec({
  1. @Body.new() required ReportAttachmentToNcmecRequest body,
})

Report an image attachment to NCMEC.

Submits a specific image attachment to NCMEC, creates an audit log entry, silently disables the user, triggers one archive for the user, and schedules content deletion after the archive completes.

body - Name not received - field will be skipped.

Implementation

@POST('/admin/messages/report-to-ncmec')
Future<NcmecAttachmentSubmitResultResponse> reportMessageAttachmentToNcmec({
  @Body() required ReportAttachmentToNcmecRequest body,
});