updateUserHasVerifiedPhone abstract method

  1. @POST.new('/admin/users/update-has-verified-phone')
Future<UserMutationResponse> updateUserHasVerifiedPhone({
  1. @Body.new() required UpdateHasVerifiedPhoneRequest body,
})

Update user phone verification flag.

Set whether a user is treated as having completed phone verification. This is the only supported path for clearing the irreversible user-facing phone verification flag.

body - Name not received - field will be skipped.

Implementation

@POST('/admin/users/update-has-verified-phone')
Future<UserMutationResponse> updateUserHasVerifiedPhone({
  @Body() required UpdateHasVerifiedPhoneRequest body,
});