AuthApi class abstract

Annotations
  • @RestApi.new()

Constructors

AuthApi(Dio dio, {String? baseUrl})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

authenticateWithWebauthn({required WebAuthnAuthenticateRequest body}) Future<AuthTokenWithUserIdResponse>
Authenticate with WebAuthn.
authorizeIpAddress({required AuthorizeIpRequest body}) Future<void>
Authorize IP address.
cancelHandoff({required String code}) Future<void>
Cancel handoff.
completeHandoff({required HandoffCompleteRequest body}) Future<void>
Complete handoff.
completeSso({required SsoCompleteRequest body}) Future<SsoCompleteResponse>
Complete SSO.
forgotPassword({required ForgotPasswordRequest body}) Future<void>
Forgot password.
getHandoffInfo({required String code}) Future<HandoffInfoResponse>
Get handoff info.
getHandoffStatus({required String code}) Future<HandoffStatusResponse>
Get handoff status.
getSsoStatus() Future<SsoStatusResponse>
Get SSO status.
getUsernameSuggestions({required UsernameSuggestionsRequest body}) Future<UsernameSuggestionsResponse>
Get username suggestions.
getWebauthnAuthenticationOptions() Future
Get WebAuthn authentication options.
getWebauthnMfaOptions({required MfaTicketRequest body}) Future
Get WebAuthn MFA options.
initiateHandoff() Future<HandoffInitiateResponse>
Initiate handoff.
listAuthSessions() Future<AuthSessionsResponse>
List auth sessions.
loginUser({required LoginRequest body}) Future<AuthLoginResponse>
Login account.
loginWithTotp({required MfaTotpRequest body}) Future<AuthTokenWithUserIdResponse>
Login with TOTP.
loginWithWebauthnMfa({required WebAuthnMfaRequest body}) Future<AuthTokenWithUserIdResponse>
Login with WebAuthn MFA.
logoutAllSessions({required LogoutAuthSessionsRequest body}) Future<void>
Logout all sessions.
logoutUser() Future<void>
Logout account.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
pollIpAuthorization({required String ticket}) Future<IpAuthorizationPollResponse>
Poll IP authorization.
registerAccount({required RegisterRequest body}) Future<AuthRegisterResponse>
Register account.
resendIpAuthorization({required MfaTicketRequest body}) Future<void>
Resend IP authorization.
resendVerificationEmail() Future<void>
Resend verification email.
resetPassword({required ResetPasswordRequest body}) Future<AuthLoginResponse>
Reset password.
revertEmailChange({required EmailRevertRequest body}) Future<AuthLoginResponse>
Revert email change.
startSso({required SsoStartRequest body}) Future<SsoStartResponse>
Start SSO.
toString() String
A string representation of this object.
inherited
validateResetPasswordToken({required String token}) Future<ValidateResetPasswordTokenResponse>
Validate reset password token.
verifyEmail({required VerifyEmailRequest body}) Future<void>
Verify email.

Operators

operator ==(Object other) bool
The equality operator.
inherited