registerAccount abstract method

  1. @POST.new('/auth/register')
Future<AuthRegisterResponse> registerAccount({
  1. @Body.new() required RegisterRequest body,
})

Register account.

Create a new user account with email and password. Requires CAPTCHA verification. User account is created but must verify email before logging in.

body - Name not received - field will be skipped.

Implementation

@POST('/auth/register')
Future<AuthRegisterResponse> registerAccount({
  @Body() required RegisterRequest body,
});