validateResetPasswordToken abstract method
- @GET.new('/auth/reset/{token}')
- @Path.new('token') required String token,
Validate reset password token.
Check whether a password reset token is valid and unexpired before allowing the user to submit a new password. Does not consume the token.
token - The token.
Implementation
@GET('/auth/reset/{token}')
Future<ValidateResetPasswordTokenResponse> validateResetPasswordToken({
@Path('token') required String token,
});