verifyEmail abstract method
- @POST.new('/auth/verify')
- @Body.new() required VerifyEmailRequest body,
Verify email.
Verify user email address using the code sent during registration. Email verification is required before the account becomes fully usable.
body - Name not received - field will be skipped.
Implementation
@POST('/auth/verify')
Future<void> verifyEmail({@Body() required VerifyEmailRequest body});