GatewayCompressionStats class

Snapshot of zstd traffic observed on the current socket.

Constructors

GatewayCompressionStats({required int frames, required int wireBytes, required int decompressedBytes, required bool compressionNegotiated})
const

Properties

compressionNegotiated bool
Whether the first WebSocket frame was binary.
final
decompressedBytes int
Bytes produced by the streaming decoder.
final
frames int
Number of binary compressed frames decoded.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
wireBytes int
Compressed bytes received in binary frames.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited