CallUpdateEvent class

Inheritance

Constructors

CallUpdateEvent({required String channelId, String? messageId, String? region, List<String>? ringing, List<VoiceState>? voiceStates})
const

Properties

channelId String
final
hashCode int
The hash code for this object.
no setterinherited
messageId String?
final
region String?
final
ringing List<String>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
voiceStates List<VoiceState>?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited