GuildMemberListUpdateEvent class
- Inheritance
-
- Object
- GatewayEvent
- GuildMemberListUpdateEvent
Constructors
-
GuildMemberListUpdateEvent({required String guildId, required String id, String? channelId, required int memberCount, required int onlineCount, required List<
MemberListGroup> groups, required List<MemberListOp> ops}) -
const
Properties
- channelId → String?
-
final
-
groups
→ List<
MemberListGroup> -
final
- guildId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- memberCount → int
-
final
- onlineCount → int
-
final
-
ops
→ List<
MemberListOp> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited