GuildMembersChunkEvent class
- Inheritance
-
- Object
- GatewayEvent
- GuildMembersChunkEvent
Constructors
Properties
- chunkCount → int
-
final
- chunkIndex → int
-
final
- guildId → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
members
→ List<
GuildMemberResponse> -
final
- nonce → String?
-
final
-
notFound
→ List<
String> ? -
final
-
presences
→ List<
Map< ?String, dynamic> > -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited