GatewayCustomStatus class

Custom status data for presence updates.

Constructors

GatewayCustomStatus({String? text, String? expiresAt, String? emojiId, String? emojiName, bool? emojiAnimated})
const

Properties

emojiAnimated bool?
final
emojiId String?
final
emojiName String?
final
expiresAt String?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited