bulkDeleteMyMessagesInGuild abstract method
- @POST.new('/users/@me/guilds/{guild_id}/messages/bulk-delete-mine')
- @Path.new('guild_id') required SnowflakeType guildId,
- @Body.new() required SudoVerificationSchema body,
Bulk delete my messages in guild.
Deletes every message the caller has authored across all channels of the specified guild. Caller must be a member of the guild and pass sudo mode verification.
guildId - The ID of the guild.
body - Name not received - field will be skipped.
Implementation
@POST('/users/@me/guilds/{guild_id}/messages/bulk-delete-mine')
Future<void> bulkDeleteMyMessagesInGuild({
@Path('guild_id') required SnowflakeType guildId,
@Body() required SudoVerificationSchema body,
});