leaveGuild abstract method
- @DELETE.new('/users/@me/guilds/{guild_id}')
- @Path.new('guild_id') required SnowflakeType guildId,
- @Query.new('delete_messages') String? deleteMessages,
- @Body.new() SudoVerificationSchema? body,
Leave guild.
Removes the current user from the specified guild membership. When delete_messages is true, the caller's authored messages in the guild are deleted before leaving; that path requires sudo mode verification.
guildId - The ID of the guild.
body - Name not received - field will be skipped.
Implementation
@DELETE('/users/@me/guilds/{guild_id}')
Future<void> leaveGuild({
@Path('guild_id') required SnowflakeType guildId,
@Query('delete_messages') String? deleteMessages,
@Body() SudoVerificationSchema? body,
});