InvitesApi class abstract

Annotations
  • @RestApi.new()

Constructors

InvitesApi(Dio dio, {String? baseUrl})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

acceptInvite({required String inviteCode}) Future<InviteResponseSchema>
Accept invite.
createChannelInvite({required SnowflakeType channelId, required ChannelInviteCreateRequest body}) Future<InviteMetadataResponseSchema>
Create channel invite.
createPackInvite({required SnowflakeType packId, required PackInviteCreateRequest body}) Future<InviteMetadataResponseSchema>
Create pack invite.
deleteInvite({required String inviteCode}) Future<void>
Delete invite.
getInvite({required String inviteCode}) Future<InviteResponseSchema>
Get invite information.
listChannelInvites({required SnowflakeType channelId}) Future<List<InviteMetadataResponseSchema>>
List channel invites.
listGuildInvites({required SnowflakeType guildId}) Future<List<InviteMetadataResponseSchema>>
List guild invites.
listPackInvites({required SnowflakeType packId}) Future<List<InviteMetadataResponseSchema>>
List pack invites.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited