acceptInvite abstract method
- @POST.new('/invites/{invite_code}')
- @Path.new('invite_code') required String inviteCode,
Accept invite.
Accepts an invite using its code, adding the authenticated user to the corresponding guild, pack, or other entity. The invite usage count is incremented, and if it reaches its maximum usage limit or expiration, the invite is automatically revoked. Returns the accepted invite details.
inviteCode - The invite code.
Implementation
@POST('/invites/{invite_code}')
Future<InviteResponseSchema> acceptInvite({
@Path('invite_code') required String inviteCode,
});