createChannelInvite abstract method
- @POST.new('/channels/{channel_id}/invites')
- @Path.new('channel_id') required SnowflakeType channelId,
- @Body.new() required ChannelInviteCreateRequest body,
Create channel invite.
Creates a new invite for the specified channel with optional parameters such as maximum age, maximum uses, and temporary membership settings. The authenticated user must have permission to create invites for the channel. Returns the created invite with full metadata including usage statistics.
channelId - The ID of the channel.
body - Name not received - field will be skipped.
Implementation
@POST('/channels/{channel_id}/invites')
Future<InviteMetadataResponseSchema> createChannelInvite({
@Path('channel_id') required SnowflakeType channelId,
@Body() required ChannelInviteCreateRequest body,
});