createPackInvite abstract method
- @POST.new('/packs/{pack_id}/invites')
- @Path.new('pack_id') required SnowflakeType packId,
- @Body.new() required PackInviteCreateRequest body,
Create pack invite.
Creates a new invite for the specified pack with optional parameters such as maximum age and maximum uses. The authenticated user must have permission to create invites for the pack and must be a default (non-bot) user. Returns the created invite with full metadata including usage statistics.
packId - The ID of the pack.
body - Name not received - field will be skipped.
Implementation
@POST('/packs/{pack_id}/invites')
Future<InviteMetadataResponseSchema> createPackInvite({
@Path('pack_id') required SnowflakeType packId,
@Body() required PackInviteCreateRequest body,
});