getInvite abstract method
- @GET.new('/invites/{invite_code}')
- @Path.new('invite_code') required String inviteCode,
Get invite information.
Fetches detailed information about an invite using its code, including the guild, channel, or pack it belongs to and metadata such as expiration and usage limits. This endpoint does not require authentication and does not consume the invite.
inviteCode - The invite code.
Implementation
@GET('/invites/{invite_code}')
Future<InviteResponseSchema> getInvite({
@Path('invite_code') required String inviteCode,
});