AdminArchiveResponseSchema class

Annotations
  • @JsonSerializable.new()

Constructors

AdminArchiveResponseSchema({required SnowflakeType archiveId, required AdminArchiveResponseSchemaSubjectTypeSubjectType subjectType, required SnowflakeType subjectId, required SnowflakeType requestedBy, required String requestedAt, required String? startedAt, required String? completedAt, required String? failedAt, required String? fileSize, required num progressPercent, required String? progressStep, required String? errorMessage, required String? downloadUrlExpiresAt, required String? expiresAt})
const
AdminArchiveResponseSchema.fromJson(Map<String, Object?> json)
factory

Properties

archiveId SnowflakeType
final
completedAt String?
final
downloadUrlExpiresAt String?
final
errorMessage String?
final
expiresAt String?
final
failedAt String?
final
fileSize String?
final
hashCode int
The hash code for this object.
no setterinherited
progressPercent num
final
progressStep String?
final
requestedAt String
final
requestedBy SnowflakeType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startedAt String?
final
subjectId SnowflakeType
final
subjectType AdminArchiveResponseSchemaSubjectTypeSubjectType
Type of subject being archived
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited