AdminAuditLogResponseSchema class

Annotations
  • @JsonSerializable.new()

Constructors

AdminAuditLogResponseSchema({required SnowflakeType logId, required SnowflakeType adminUserId, required String targetType, required String targetId, required String action, required String? auditLogReason, required Map<String, String> metadata, required String createdAt})
const
AdminAuditLogResponseSchema.fromJson(Map<String, Object?> json)
factory

Properties

action String
final
adminUserId SnowflakeType
final
auditLogReason String?
final
createdAt String
final
hashCode int
The hash code for this object.
no setterinherited
logId SnowflakeType
final
metadata Map<String, String>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetId String
The ID of the affected entity (user, channel, role, invite code, etc.)
final
targetType String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited