AdminBillingOverviewResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
AdminBillingOverviewResponse({required AdminSubscriptionResponse? subscription, required List<
AdminPaymentResponse> payments, required List<AdminPaymentMethodResponse> paymentMethods, required String? stripeCustomerId}) -
const
-
AdminBillingOverviewResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
paymentMethods
→ List<
AdminPaymentMethodResponse> -
final
-
payments
→ List<
AdminPaymentResponse> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stripeCustomerId → String?
-
final
- subscription → AdminSubscriptionResponse?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited