AdminInvoiceResponse class

Annotations
  • @JsonSerializable.new()

Constructors

AdminInvoiceResponse({required String id, required num amountDue, required num amountPaid, required String currency, required String? status, required num created, required String? billingReason, required String? subscriptionId, required String? paymentType, required String? paymentStatus, required String? paymentIntentId, required String? chargeId, required String? paidAt, required String? hostedInvoiceUrl, required String? invoicePdf})
const
AdminInvoiceResponse.fromJson(Map<String, Object?> json)
factory

Properties

amountDue num
final
amountPaid num
final
billingReason String?
final
chargeId String?
final
created num
final
currency String
final
hashCode int
The hash code for this object.
no setterinherited
hostedInvoiceUrl String?
final
id String
final
invoicePdf String?
final
paidAt String?
final
paymentIntentId String?
final
paymentStatus String?
final
paymentType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String?
final
subscriptionId String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited