AdminPaymentMethodResponse class

Annotations
  • @JsonSerializable.new()

Constructors

AdminPaymentMethodResponse({required String id, required String type, required String? cardBrand, required String? cardLast4, required num? cardExpMonth, required num? cardExpYear, required num created})
const
AdminPaymentMethodResponse.fromJson(Map<String, Object?> json)
factory

Properties

cardBrand String?
final
cardExpMonth num?
final
cardExpYear num?
final
cardLast4 String?
final
created num
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited