AdminPaymentResponse class

Annotations
  • @JsonSerializable.new()

Constructors

AdminPaymentResponse({required String status, required String userId, required String? stripeCustomerId, required String? paymentIntentId, required String? resolvedPaymentIntentId, required String? chargeId, required String? subscriptionId, required String? invoiceId, required String? priceId, required String? productType, required num amountCents, required String currency, required String? checkoutSessionId, required AdminPaymentResponseStripeSourceStripeSource stripeSource, required bool refundableViaPaymentIntent, required num refundedAmountCents, required num netAmountCents, required List<AdminPaymentRefundResponse> refunds, required String? paymentMethodType, required String? paymentMethodBrand, required String? paymentMethodLast4, required String? stripePaymentMethodCountryCode, required String? completedAt, required String? stripeCustomerCountryCode, required bool? stripeTermsOfServiceAccepted, required bool isGift, required String? giftCode, required String? purchaseGeoipCountryCode, required String? purchaseClientCountryCode, required bool euWithdrawalWaiverRequired, required bool euWithdrawalWaiverAccepted, required String? euWithdrawalWaiverAcceptedAt, required String? euWithdrawalWaiverTextVersion, required String createdAt, required String? stripeBillingCountryCode})
const
AdminPaymentResponse.fromJson(Map<String, Object?> json)
factory

Properties

amountCents num
final
chargeId String?
final
checkoutSessionId String?
final
completedAt String?
final
createdAt String
final
currency String
final
euWithdrawalWaiverAccepted bool
final
euWithdrawalWaiverAcceptedAt String?
final
euWithdrawalWaiverRequired bool
final
euWithdrawalWaiverTextVersion String?
final
giftCode String?
final
hashCode int
The hash code for this object.
no setterinherited
invoiceId String?
final
isGift bool
final
netAmountCents num
final
paymentIntentId String?
final
paymentMethodBrand String?
final
paymentMethodLast4 String?
final
paymentMethodType String?
final
priceId String?
final
productType String?
final
purchaseClientCountryCode String?
final
purchaseGeoipCountryCode String?
final
refundableViaPaymentIntent bool
final
refundedAmountCents num
final
refunds List<AdminPaymentRefundResponse>
final
resolvedPaymentIntentId String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final
stripeBillingCountryCode String?
final
stripeCustomerCountryCode String?
final
stripeCustomerId String?
final
stripePaymentMethodCountryCode String?
final
stripeSource AdminPaymentResponseStripeSourceStripeSource
final
stripeTermsOfServiceAccepted bool?
final
subscriptionId String?
final
userId String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited