AdminRelationshipEntrySchema class

Annotations
  • @JsonSerializable.new()

Constructors

AdminRelationshipEntrySchema({required SnowflakeType targetUserId, required RelationshipCategoryEnum category, required String? nickname, required String? since, required AdminResolvedUserSchema? target})
const
AdminRelationshipEntrySchema.fromJson(Map<String, Object?> json)
factory

Properties

category RelationshipCategoryEnum
final
hashCode int
The hash code for this object.
no setterinherited
nickname String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
since String?
final
target AdminResolvedUserSchema?
final
targetUserId SnowflakeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited