AdminResolvedUserSchema class

Annotations
  • @JsonSerializable.new()

Constructors

AdminResolvedUserSchema({required SnowflakeType id, required String username, required String discriminator, required String? globalName, required String? avatar})
const
AdminResolvedUserSchema.fromJson(Map<String, Object?> json)
factory

Properties

avatar String?
final
discriminator String
final
globalName String?
final
hashCode int
The hash code for this object.
no setterinherited
id SnowflakeType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited