AdminSubscriptionResponse class

Annotations
  • @JsonSerializable.new()

Constructors

AdminSubscriptionResponse({required String id, required String status, required String? currentPeriodStart, required String? currentPeriodEnd, required bool cancelAtPeriodEnd, required String? cancelAt, required String? canceledAt, required String? planInterval, required num? planAmountCents, required String? planCurrency, required String? defaultPaymentMethodId})
const
AdminSubscriptionResponse.fromJson(Map<String, Object?> json)
factory

Properties

cancelAt String?
final
cancelAtPeriodEnd bool
final
canceledAt String?
final
currentPeriodEnd String?
final
currentPeriodStart String?
final
defaultPaymentMethodId String?
final
hashCode int
The hash code for this object.
no setterinherited
id String
final
planAmountCents num?
final
planCurrency String?
final
planInterval String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited