ApiErrorCode enum

Error codes returned by API operations

Inheritance
Available extensions
Annotations
  • @JsonEnum.new()

Values

accessDenied → const ApiErrorCode
const ApiErrorCode('ACCESS_DENIED')
accountDisabled → const ApiErrorCode
const ApiErrorCode('ACCOUNT_DISABLED')
badGateway → const ApiErrorCode
const ApiErrorCode('BAD_GATEWAY')
badRequest → const ApiErrorCode
const ApiErrorCode('BAD_REQUEST')
blueskyOauthAuthorizationFailed → const ApiErrorCode
const ApiErrorCode('BLUESKY_OAUTH_AUTHORIZATION_FAILED')
blueskyOauthCallbackFailed → const ApiErrorCode
const ApiErrorCode('BLUESKY_OAUTH_CALLBACK_FAILED')
blueskyOauthNotEnabled → const ApiErrorCode
const ApiErrorCode('BLUESKY_OAUTH_NOT_ENABLED')
blueskyOauthSessionExpired → const ApiErrorCode
const ApiErrorCode('BLUESKY_OAUTH_SESSION_EXPIRED')
blueskyOauthStateInvalid → const ApiErrorCode
const ApiErrorCode('BLUESKY_OAUTH_STATE_INVALID')
accountScheduledForDeletion → const ApiErrorCode
const ApiErrorCode('ACCOUNT_SCHEDULED_FOR_DELETION')
accountSuspendedPermanently → const ApiErrorCode
const ApiErrorCode('ACCOUNT_SUSPENDED_PERMANENTLY')
accountSuspendedTemporarily → const ApiErrorCode
const ApiErrorCode('ACCOUNT_SUSPENDED_TEMPORARILY')
accountSuspiciousActivity → const ApiErrorCode
const ApiErrorCode('ACCOUNT_SUSPICIOUS_ACTIVITY')
accountTooNewForGuild → const ApiErrorCode
const ApiErrorCode('ACCOUNT_TOO_NEW_FOR_GUILD')
aclsMustBeNonEmpty → const ApiErrorCode
const ApiErrorCode('ACLS_MUST_BE_NON_EMPTY')
adminApiKeyNotFound → const ApiErrorCode
const ApiErrorCode('ADMIN_API_KEY_NOT_FOUND')
applicationNotFound → const ApiErrorCode
const ApiErrorCode('APPLICATION_NOT_FOUND')
applicationNotOwned → const ApiErrorCode
const ApiErrorCode('APPLICATION_NOT_OWNED')
alreadyFriends → const ApiErrorCode
const ApiErrorCode('ALREADY_FRIENDS')
auditLogIndexing → const ApiErrorCode
const ApiErrorCode('AUDIT_LOG_INDEXING')
botsCannotCreateGuilds → const ApiErrorCode
const ApiErrorCode('BOTS_CANNOT_CREATE_GUILDS')
botsCannotSendFriendRequests → const ApiErrorCode
const ApiErrorCode('BOTS_CANNOT_SEND_FRIEND_REQUESTS')
botAlreadyInGuild → const ApiErrorCode
const ApiErrorCode('BOT_ALREADY_IN_GUILD')
botApplicationNotFound → const ApiErrorCode
const ApiErrorCode('BOT_APPLICATION_NOT_FOUND')
botIsPrivate → const ApiErrorCode
const ApiErrorCode('BOT_IS_PRIVATE')
botUserAuthEndpointAccessDenied → const ApiErrorCode
const ApiErrorCode('BOT_USER_AUTH_ENDPOINT_ACCESS_DENIED')
botUserAuthSessionCreationDenied → const ApiErrorCode
const ApiErrorCode('BOT_USER_AUTH_SESSION_CREATION_DENIED')
botUserGenerationFailed → const ApiErrorCode
const ApiErrorCode('BOT_USER_GENERATION_FAILED')
botUserNotFound → const ApiErrorCode
const ApiErrorCode('BOT_USER_NOT_FOUND')
callAlreadyExists → const ApiErrorCode
const ApiErrorCode('CALL_ALREADY_EXISTS')
cannotEditOtherUserMessage → const ApiErrorCode
const ApiErrorCode('CANNOT_EDIT_OTHER_USER_MESSAGE')
cannotExecuteOnDm → const ApiErrorCode
const ApiErrorCode('CANNOT_EXECUTE_ON_DM')
cannotBlockSystemUser → const ApiErrorCode
const ApiErrorCode('CANNOT_BLOCK_SYSTEM_USER')
cannotModifySystemWebhook → const ApiErrorCode
const ApiErrorCode('CANNOT_MODIFY_SYSTEM_WEBHOOK')
cannotModifyVoiceState → const ApiErrorCode
const ApiErrorCode('CANNOT_MODIFY_VOICE_STATE')
cannotRedeemPlutoniumWithVisionary → const ApiErrorCode
const ApiErrorCode('CANNOT_REDEEM_PLUTONIUM_WITH_VISIONARY')
cannotReportGuild → const ApiErrorCode
const ApiErrorCode('CANNOT_REPORT_GUILD')
cannotReportOwnGuild → const ApiErrorCode
const ApiErrorCode('CANNOT_REPORT_OWN_GUILD')
cannotReportOwnMessage → const ApiErrorCode
const ApiErrorCode('CANNOT_REPORT_OWN_MESSAGE')
cannotReportYourself → const ApiErrorCode
const ApiErrorCode('CANNOT_REPORT_YOURSELF')
cannotSendEmptyMessage → const ApiErrorCode
const ApiErrorCode('CANNOT_SEND_EMPTY_MESSAGE')
cannotSendFriendRequestToBlockedUser → const ApiErrorCode
const ApiErrorCode('CANNOT_SEND_FRIEND_REQUEST_TO_BLOCKED_USER')
cannotSendFriendRequestToSelf → const ApiErrorCode
const ApiErrorCode('CANNOT_SEND_FRIEND_REQUEST_TO_SELF')
cannotSendMessagesInNonTextChannel → const ApiErrorCode
const ApiErrorCode('CANNOT_SEND_MESSAGES_IN_NON_TEXT_CHANNEL')
cannotSendMessagesToUser → const ApiErrorCode
const ApiErrorCode('CANNOT_SEND_MESSAGES_TO_USER')
cannotTransferOwnershipToBot → const ApiErrorCode
const ApiErrorCode('CANNOT_TRANSFER_OWNERSHIP_TO_BOT')
cannotShrinkReservedSlots → const ApiErrorCode
const ApiErrorCode('CANNOT_SHRINK_RESERVED_SLOTS')
captchaRequired → const ApiErrorCode
const ApiErrorCode('CAPTCHA_REQUIRED')
channelIndexing → const ApiErrorCode
const ApiErrorCode('CHANNEL_INDEXING')
communicationDisabled → const ApiErrorCode
const ApiErrorCode('COMMUNICATION_DISABLED')
connectionAlreadyExists → const ApiErrorCode
const ApiErrorCode('CONNECTION_ALREADY_EXISTS')
connectionInitiationTokenInvalid → const ApiErrorCode
const ApiErrorCode('CONNECTION_INITIATION_TOKEN_INVALID')
connectionInvalidIdentifier → const ApiErrorCode
const ApiErrorCode('CONNECTION_INVALID_IDENTIFIER')
connectionInvalidType → const ApiErrorCode
const ApiErrorCode('CONNECTION_INVALID_TYPE')
connectionLimitReached → const ApiErrorCode
const ApiErrorCode('CONNECTION_LIMIT_REACHED')
connectionNotFound → const ApiErrorCode
const ApiErrorCode('CONNECTION_NOT_FOUND')
connectionVerificationFailed → const ApiErrorCode
const ApiErrorCode('CONNECTION_VERIFICATION_FAILED')
conflict → const ApiErrorCode
const ApiErrorCode('CONFLICT')
contentBlocked → const ApiErrorCode
const ApiErrorCode('CONTENT_BLOCKED')
creationFailed → const ApiErrorCode
const ApiErrorCode('CREATION_FAILED')
decryptionFailed → const ApiErrorCode
const ApiErrorCode('DECRYPTION_FAILED')
deletionFailed → const ApiErrorCode
const ApiErrorCode('DELETION_FAILED')
discoveryAlreadyApplied → const ApiErrorCode
const ApiErrorCode('DISCOVERY_ALREADY_APPLIED')
discoveryApplicationAlreadyReviewed → const ApiErrorCode
const ApiErrorCode('DISCOVERY_APPLICATION_ALREADY_REVIEWED')
discoveryApplicationNotFound → const ApiErrorCode
const ApiErrorCode('DISCOVERY_APPLICATION_NOT_FOUND')
discoveryDescriptionRequired → const ApiErrorCode
const ApiErrorCode('DISCOVERY_DESCRIPTION_REQUIRED')
discoveryDisabled → const ApiErrorCode
const ApiErrorCode('DISCOVERY_DISABLED')
discoveryInsufficientMembers → const ApiErrorCode
const ApiErrorCode('DISCOVERY_INSUFFICIENT_MEMBERS')
discoveryInvalidCategory → const ApiErrorCode
const ApiErrorCode('DISCOVERY_INVALID_CATEGORY')
discoveryNotDiscoverable → const ApiErrorCode
const ApiErrorCode('DISCOVERY_NOT_DISCOVERABLE')
discriminatorRequired → const ApiErrorCode
const ApiErrorCode('DISCRIMINATOR_REQUIRED')
emailServiceNotTestable → const ApiErrorCode
const ApiErrorCode('EMAIL_SERVICE_NOT_TESTABLE')
emailVerificationRequired → const ApiErrorCode
const ApiErrorCode('EMAIL_VERIFICATION_REQUIRED')
canaryTesterEmailVerificationRequired → const ApiErrorCode
const ApiErrorCode('CANARY_TESTER_EMAIL_VERIFICATION_REQUIRED')
directMessageEmailVerificationRequired → const ApiErrorCode
const ApiErrorCode('DIRECT_MESSAGE_EMAIL_VERIFICATION_REQUIRED')
friendRequestEmailVerificationRequired → const ApiErrorCode
const ApiErrorCode('FRIEND_REQUEST_EMAIL_VERIFICATION_REQUIRED')
guildCreationEmailVerificationRequired → const ApiErrorCode
const ApiErrorCode('GUILD_CREATION_EMAIL_VERIFICATION_REQUIRED')
guildEmailVerificationRequired → const ApiErrorCode
const ApiErrorCode('GUILD_EMAIL_VERIFICATION_REQUIRED')
mfaEmailVerificationRequired → const ApiErrorCode
const ApiErrorCode('MFA_EMAIL_VERIFICATION_REQUIRED')
profileEmailVerificationRequired → const ApiErrorCode
const ApiErrorCode('PROFILE_EMAIL_VERIFICATION_REQUIRED')
purchaseEmailVerificationRequired → const ApiErrorCode
const ApiErrorCode('PURCHASE_EMAIL_VERIFICATION_REQUIRED')
reactionEmailVerificationRequired → const ApiErrorCode
const ApiErrorCode('REACTION_EMAIL_VERIFICATION_REQUIRED')
reportEmailVerificationRequired → const ApiErrorCode
const ApiErrorCode('REPORT_EMAIL_VERIFICATION_REQUIRED')
registrationClosed → const ApiErrorCode
const ApiErrorCode('REGISTRATION_CLOSED')
registrationPendingApproval → const ApiErrorCode
const ApiErrorCode('REGISTRATION_PENDING_APPROVAL')
registrationRejected → const ApiErrorCode
const ApiErrorCode('REGISTRATION_REJECTED')
registrationUrlInvalid → const ApiErrorCode
const ApiErrorCode('REGISTRATION_URL_INVALID')
emptyEncryptedBody → const ApiErrorCode
const ApiErrorCode('EMPTY_ENCRYPTED_BODY')
encryptionFailed → const ApiErrorCode
const ApiErrorCode('ENCRYPTION_FAILED')
euWithdrawalWaiverRequired → const ApiErrorCode
const ApiErrorCode('EU_WITHDRAWAL_WAIVER_REQUIRED')
explicitContentCannotBeSent → const ApiErrorCode
const ApiErrorCode('EXPLICIT_CONTENT_CANNOT_BE_SENT')
featureNotAvailableSelfHosted → const ApiErrorCode
const ApiErrorCode('FEATURE_NOT_AVAILABLE_SELF_HOSTED')
featureTemporarilyDisabled → const ApiErrorCode
const ApiErrorCode('FEATURE_TEMPORARILY_DISABLED')
fileSizeTooLarge → const ApiErrorCode
const ApiErrorCode('FILE_SIZE_TOO_LARGE')
forbidden → const ApiErrorCode
const ApiErrorCode('FORBIDDEN')
friendRequestBlocked → const ApiErrorCode
const ApiErrorCode('FRIEND_REQUEST_BLOCKED')
gatewayTimeout → const ApiErrorCode
const ApiErrorCode('GATEWAY_TIMEOUT')
generalError → const ApiErrorCode
const ApiErrorCode('GENERAL_ERROR')
gone → const ApiErrorCode
const ApiErrorCode('GONE')
giftCodeAlreadyRedeemed → const ApiErrorCode
const ApiErrorCode('GIFT_CODE_ALREADY_REDEEMED')
guildPhoneVerificationRequired → const ApiErrorCode
const ApiErrorCode('GUILD_PHONE_VERIFICATION_REQUIRED')
guildTemplateFetchFailed → const ApiErrorCode
const ApiErrorCode('GUILD_TEMPLATE_FETCH_FAILED')
guildTemplateInvalid → const ApiErrorCode
const ApiErrorCode('GUILD_TEMPLATE_INVALID')
guildVerificationRequired → const ApiErrorCode
const ApiErrorCode('GUILD_VERIFICATION_REQUIRED')
handoffCodeExpired → const ApiErrorCode
const ApiErrorCode('HANDOFF_CODE_EXPIRED')
harvestExpired → const ApiErrorCode
const ApiErrorCode('HARVEST_EXPIRED')
harvestFailed → const ApiErrorCode
const ApiErrorCode('HARVEST_FAILED')
harvestNotReady → const ApiErrorCode
const ApiErrorCode('HARVEST_NOT_READY')
httpGetAuthorizeNotSupported → const ApiErrorCode
const ApiErrorCode('HTTP_GET_AUTHORIZE_NOT_SUPPORTED')
instanceVersionMismatch → const ApiErrorCode
const ApiErrorCode('INSTANCE_VERSION_MISMATCH')
internalServerError → const ApiErrorCode
const ApiErrorCode('INTERNAL_SERVER_ERROR')
invalidAclsFormat → const ApiErrorCode
const ApiErrorCode('INVALID_ACLS_FORMAT')
invalidApiOrigin → const ApiErrorCode
const ApiErrorCode('INVALID_API_ORIGIN')
invalidAuthToken → const ApiErrorCode
const ApiErrorCode('INVALID_AUTH_TOKEN')
invalidBotFlag → const ApiErrorCode
const ApiErrorCode('INVALID_BOT_FLAG')
invalidCaptcha → const ApiErrorCode
const ApiErrorCode('INVALID_CAPTCHA')
invalidChannelTypeForCall → const ApiErrorCode
const ApiErrorCode('INVALID_CHANNEL_TYPE_FOR_CALL')
invalidChannelType → const ApiErrorCode
const ApiErrorCode('INVALID_CHANNEL_TYPE')
invalidClient → const ApiErrorCode
const ApiErrorCode('INVALID_CLIENT')
invalidClientSecret → const ApiErrorCode
const ApiErrorCode('INVALID_CLIENT_SECRET')
invalidDsaReportTarget → const ApiErrorCode
const ApiErrorCode('INVALID_DSA_REPORT_TARGET')
invalidDsaTicket → const ApiErrorCode
const ApiErrorCode('INVALID_DSA_TICKET')
invalidDsaVerificationCode → const ApiErrorCode
const ApiErrorCode('INVALID_DSA_VERIFICATION_CODE')
invalidDecryptedJson → const ApiErrorCode
const ApiErrorCode('INVALID_DECRYPTED_JSON')
invalidEphemeralKey → const ApiErrorCode
const ApiErrorCode('INVALID_EPHEMERAL_KEY')
invalidFlagsFormat → const ApiErrorCode
const ApiErrorCode('INVALID_FLAGS_FORMAT')
invalidIv → const ApiErrorCode
const ApiErrorCode('INVALID_IV')
invalidFormBody → const ApiErrorCode
const ApiErrorCode('INVALID_FORM_BODY')
invalidGrant → const ApiErrorCode
const ApiErrorCode('INVALID_GRANT')
invalidHandoffCode → const ApiErrorCode
const ApiErrorCode('INVALID_HANDOFF_CODE')
invalidPackType → const ApiErrorCode
const ApiErrorCode('INVALID_PACK_TYPE')
invalidPermissionsInteger → const ApiErrorCode
const ApiErrorCode('INVALID_PERMISSIONS_INTEGER')
invalidPermissionsNegative → const ApiErrorCode
const ApiErrorCode('INVALID_PERMISSIONS_NEGATIVE')
invalidPhoneNumber → const ApiErrorCode
const ApiErrorCode('INVALID_PHONE_NUMBER')
invalidPhoneVerificationCode → const ApiErrorCode
const ApiErrorCode('INVALID_PHONE_VERIFICATION_CODE')
invalidRedirectUri → const ApiErrorCode
const ApiErrorCode('INVALID_REDIRECT_URI')
invalidRequest → const ApiErrorCode
const ApiErrorCode('INVALID_REQUEST')
invalidResponseTypeForNonBot → const ApiErrorCode
const ApiErrorCode('INVALID_RESPONSE_TYPE_FOR_NON_BOT')
invalidScope → const ApiErrorCode
const ApiErrorCode('INVALID_SCOPE')
invalidStreamKeyFormat → const ApiErrorCode
const ApiErrorCode('INVALID_STREAM_KEY_FORMAT')
invalidStreamThumbnailPayload → const ApiErrorCode
const ApiErrorCode('INVALID_STREAM_THUMBNAIL_PAYLOAD')
invalidSudoToken → const ApiErrorCode
const ApiErrorCode('INVALID_SUDO_TOKEN')
invalidSuspiciousFlagsFormat → const ApiErrorCode
const ApiErrorCode('INVALID_SUSPICIOUS_FLAGS_FORMAT')
invalidSystemFlag → const ApiErrorCode
const ApiErrorCode('INVALID_SYSTEM_FLAG')
invalidTimestamp → const ApiErrorCode
const ApiErrorCode('INVALID_TIMESTAMP')
invalidToken → const ApiErrorCode
const ApiErrorCode('INVALID_TOKEN')
invalidWebauthnAuthenticationCounter → const ApiErrorCode
const ApiErrorCode('INVALID_WEBAUTHN_AUTHENTICATION_COUNTER')
invalidWebauthnCredentialCounter → const ApiErrorCode
const ApiErrorCode('INVALID_WEBAUTHN_CREDENTIAL_COUNTER')
invalidWebauthnCredential → const ApiErrorCode
const ApiErrorCode('INVALID_WEBAUTHN_CREDENTIAL')
invalidWebauthnPublicKeyFormat → const ApiErrorCode
const ApiErrorCode('INVALID_WEBAUTHN_PUBLIC_KEY_FORMAT')
invitesDisabled → const ApiErrorCode
const ApiErrorCode('INVITES_DISABLED')
ipAuthorizationRequired → const ApiErrorCode
const ApiErrorCode('IP_AUTHORIZATION_REQUIRED')
ipAuthorizationResendCooldown → const ApiErrorCode
const ApiErrorCode('IP_AUTHORIZATION_RESEND_COOLDOWN')
ipAuthorizationResendLimitExceeded → const ApiErrorCode
const ApiErrorCode('IP_AUTHORIZATION_RESEND_LIMIT_EXCEEDED')
globalIpBanned → const ApiErrorCode
const ApiErrorCode('GLOBAL_IP_BANNED')
globalIpTemporarilyBanned → const ApiErrorCode
const ApiErrorCode('GLOBAL_IP_TEMPORARILY_BANNED')
ipBanned → const ApiErrorCode
const ApiErrorCode('IP_BANNED')
residentialProxyBlocked → const ApiErrorCode
const ApiErrorCode('RESIDENTIAL_PROXY_BLOCKED')
torBlocked → const ApiErrorCode
const ApiErrorCode('TOR_BLOCKED')
maxAnimatedEmojis → const ApiErrorCode
const ApiErrorCode('MAX_ANIMATED_EMOJIS')
maxApplications → const ApiErrorCode
const ApiErrorCode('MAX_APPLICATIONS')
maxBookmarks → const ApiErrorCode
const ApiErrorCode('MAX_BOOKMARKS')
maxCategoryChannels → const ApiErrorCode
const ApiErrorCode('MAX_CATEGORY_CHANNELS')
maxEmojis → const ApiErrorCode
const ApiErrorCode('MAX_EMOJIS')
maxFavoriteMemes → const ApiErrorCode
const ApiErrorCode('MAX_FAVORITE_MEMES')
maxFriends → const ApiErrorCode
const ApiErrorCode('MAX_FRIENDS')
maxGroupDmRecipients → const ApiErrorCode
const ApiErrorCode('MAX_GROUP_DM_RECIPIENTS')
maxGroupDms → const ApiErrorCode
const ApiErrorCode('MAX_GROUP_DMS')
groupDmRecipientsNotAddable → const ApiErrorCode
const ApiErrorCode('GROUP_DM_RECIPIENTS_NOT_ADDABLE')
maxGuildChannels → const ApiErrorCode
const ApiErrorCode('MAX_GUILD_CHANNELS')
maxGuildMembers → const ApiErrorCode
const ApiErrorCode('MAX_GUILD_MEMBERS')
maxGuildRoles → const ApiErrorCode
const ApiErrorCode('MAX_GUILD_ROLES')
maxGuilds → const ApiErrorCode
const ApiErrorCode('MAX_GUILDS')
newAccountGuildJoinRateLimited → const ApiErrorCode
const ApiErrorCode('NEW_ACCOUNT_GUILD_JOIN_RATE_LIMITED')
maxInvites → const ApiErrorCode
const ApiErrorCode('MAX_INVITES')
maxPackExpressions → const ApiErrorCode
const ApiErrorCode('MAX_PACK_EXPRESSIONS')
maxPacks → const ApiErrorCode
const ApiErrorCode('MAX_PACKS')
maxPinsPerChannel → const ApiErrorCode
const ApiErrorCode('MAX_PINS_PER_CHANNEL')
messageTotalAttachmentSizeTooLarge → const ApiErrorCode
const ApiErrorCode('MESSAGE_TOTAL_ATTACHMENT_SIZE_TOO_LARGE')
maxReactions → const ApiErrorCode
const ApiErrorCode('MAX_REACTIONS')
maxStickers → const ApiErrorCode
const ApiErrorCode('MAX_STICKERS')
maxWebhooksPerChannel → const ApiErrorCode
const ApiErrorCode('MAX_WEBHOOKS_PER_CHANNEL')
maxWebhooksPerGuild → const ApiErrorCode
const ApiErrorCode('MAX_WEBHOOKS_PER_GUILD')
maxWebhooks → const ApiErrorCode
const ApiErrorCode('MAX_WEBHOOKS')
ncmecAlreadySubmitted → const ApiErrorCode
const ApiErrorCode('NCMEC_ALREADY_SUBMITTED')
ncmecSubmissionFailed → const ApiErrorCode
const ApiErrorCode('NCMEC_SUBMISSION_FAILED')
mediaMetadataError → const ApiErrorCode
const ApiErrorCode('MEDIA_METADATA_ERROR')
methodNotAllowed → const ApiErrorCode
const ApiErrorCode('METHOD_NOT_ALLOWED')
missingAccess → const ApiErrorCode
const ApiErrorCode('MISSING_ACCESS')
missingAcl → const ApiErrorCode
const ApiErrorCode('MISSING_ACL')
missingAuthorization → const ApiErrorCode
const ApiErrorCode('MISSING_AUTHORIZATION')
missingClientSecret → const ApiErrorCode
const ApiErrorCode('MISSING_CLIENT_SECRET')
missingEphemeralKey → const ApiErrorCode
const ApiErrorCode('MISSING_EPHEMERAL_KEY')
missingIv → const ApiErrorCode
const ApiErrorCode('MISSING_IV')
missingOauthFields → const ApiErrorCode
const ApiErrorCode('MISSING_OAUTH_FIELDS')
missingOauthScope → const ApiErrorCode
const ApiErrorCode('MISSING_OAUTH_SCOPE')
missingPermissions → const ApiErrorCode
const ApiErrorCode('MISSING_PERMISSIONS')
missingRedirectUri → const ApiErrorCode
const ApiErrorCode('MISSING_REDIRECT_URI')
noActiveCall → const ApiErrorCode
const ApiErrorCode('NO_ACTIVE_CALL')
noActiveSubscription → const ApiErrorCode
const ApiErrorCode('NO_ACTIVE_SUBSCRIPTION')
notFound → const ApiErrorCode
const ApiErrorCode('NOT_FOUND')
notImplemented → const ApiErrorCode
const ApiErrorCode('NOT_IMPLEMENTED')
noPasskeysRegistered → const ApiErrorCode
const ApiErrorCode('NO_PASSKEYS_REGISTERED')
noPendingDeletion → const ApiErrorCode
const ApiErrorCode('NO_PENDING_DELETION')
noUsersWithFluxertagExist → const ApiErrorCode
const ApiErrorCode('NO_USERS_WITH_FLUXERTAG_EXIST')
noVisionarySlotsAvailable → const ApiErrorCode
const ApiErrorCode('NO_VISIONARY_SLOTS_AVAILABLE')
notABotApplication → const ApiErrorCode
const ApiErrorCode('NOT_A_BOT_APPLICATION')
notFriendsWithUser → const ApiErrorCode
const ApiErrorCode('NOT_FRIENDS_WITH_USER')
notOwnerOfAdminApiKey → const ApiErrorCode
const ApiErrorCode('NOT_OWNER_OF_ADMIN_API_KEY')
nsfwContentAgeRestricted → const ApiErrorCode
const ApiErrorCode('NSFW_CONTENT_AGE_RESTRICTED')
nsfwEmojiStickerBlocked → const ApiErrorCode
const ApiErrorCode('NSFW_EMOJI_STICKER_BLOCKED')
packAccessDenied → const ApiErrorCode
const ApiErrorCode('PACK_ACCESS_DENIED')
passkeyAuthenticationFailed → const ApiErrorCode
const ApiErrorCode('PASSKEY_AUTHENTICATION_FAILED')
passkeysDisabled → const ApiErrorCode
const ApiErrorCode('PASSKEYS_DISABLED')
phoneAddNotEligible → const ApiErrorCode
const ApiErrorCode('PHONE_ADD_NOT_ELIGIBLE')
phoneAlreadyUsed → const ApiErrorCode
const ApiErrorCode('PHONE_ALREADY_USED')
phoneRateLimitExceeded → const ApiErrorCode
const ApiErrorCode('PHONE_RATE_LIMIT_EXCEEDED')
phoneVerificationRequired → const ApiErrorCode
const ApiErrorCode('PHONE_VERIFICATION_REQUIRED')
premiumPurchaseBlocked → const ApiErrorCode
const ApiErrorCode('PREMIUM_PURCHASE_BLOCKED')
previewMustBeJpeg → const ApiErrorCode
const ApiErrorCode('PREVIEW_MUST_BE_JPEG')
processingFailed → const ApiErrorCode
const ApiErrorCode('PROCESSING_FAILED')
rateLimited → const ApiErrorCode
const ApiErrorCode('RATE_LIMITED')
redirectUriRequiredForNonBot → const ApiErrorCode
const ApiErrorCode('REDIRECT_URI_REQUIRED_FOR_NON_BOT')
reportAlreadyResolved → const ApiErrorCode
const ApiErrorCode('REPORT_ALREADY_RESOLVED')
reportBanned → const ApiErrorCode
const ApiErrorCode('REPORT_BANNED')
responseValidationError → const ApiErrorCode
const ApiErrorCode('RESPONSE_VALIDATION_ERROR')
resourceLocked → const ApiErrorCode
const ApiErrorCode('RESOURCE_LOCKED')
serviceUnavailable → const ApiErrorCode
const ApiErrorCode('SERVICE_UNAVAILABLE')
sessionTokenMismatch → const ApiErrorCode
const ApiErrorCode('SESSION_TOKEN_MISMATCH')
singleCommunityCannotCreateGuilds → const ApiErrorCode
const ApiErrorCode('SINGLE_COMMUNITY_CANNOT_CREATE_GUILDS')
singleCommunityCannotDelete → const ApiErrorCode
const ApiErrorCode('SINGLE_COMMUNITY_CANNOT_DELETE')
singleCommunityCannotLeave → const ApiErrorCode
const ApiErrorCode('SINGLE_COMMUNITY_CANNOT_LEAVE')
instancePolicyTransitionNotAllowed → const ApiErrorCode
const ApiErrorCode('INSTANCE_POLICY_TRANSITION_NOT_ALLOWED')
slowmodeRateLimited → const ApiErrorCode
const ApiErrorCode('SLOWMODE_RATE_LIMITED')
smsVerificationUnavailable → const ApiErrorCode
const ApiErrorCode('SMS_VERIFICATION_UNAVAILABLE')
ssoRequired → const ApiErrorCode
const ApiErrorCode('SSO_REQUIRED')
streamKeyChannelMismatch → const ApiErrorCode
const ApiErrorCode('STREAM_KEY_CHANNEL_MISMATCH')
streamKeyScopeMismatch → const ApiErrorCode
const ApiErrorCode('STREAM_KEY_SCOPE_MISMATCH')
streamThumbnailPayloadEmpty → const ApiErrorCode
const ApiErrorCode('STREAM_THUMBNAIL_PAYLOAD_EMPTY')
stripeError → const ApiErrorCode
const ApiErrorCode('STRIPE_ERROR')
stripeGiftRedemptionInProgress → const ApiErrorCode
const ApiErrorCode('STRIPE_GIFT_REDEMPTION_IN_PROGRESS')
stripeInvalidProduct → const ApiErrorCode
const ApiErrorCode('STRIPE_INVALID_PRODUCT')
stripeInvalidProductConfiguration → const ApiErrorCode
const ApiErrorCode('STRIPE_INVALID_PRODUCT_CONFIGURATION')
stripeNoActiveSubscription → const ApiErrorCode
const ApiErrorCode('STRIPE_NO_ACTIVE_SUBSCRIPTION')
stripeNoPurchaseHistory → const ApiErrorCode
const ApiErrorCode('STRIPE_NO_PURCHASE_HISTORY')
stripeRefundOutsideWindow → const ApiErrorCode
const ApiErrorCode('STRIPE_REFUND_OUTSIDE_WINDOW')
stripeRefundCooldownActive → const ApiErrorCode
const ApiErrorCode('STRIPE_REFUND_COOLDOWN_ACTIVE')
stripeNoSubscription → const ApiErrorCode
const ApiErrorCode('STRIPE_NO_SUBSCRIPTION')
stripePaymentNotAvailable → const ApiErrorCode
const ApiErrorCode('STRIPE_PAYMENT_NOT_AVAILABLE')
stripeSubscriptionAlreadyCanceling → const ApiErrorCode
const ApiErrorCode('STRIPE_SUBSCRIPTION_ALREADY_CANCELING')
stripeSubscriptionNotCanceling → const ApiErrorCode
const ApiErrorCode('STRIPE_SUBSCRIPTION_NOT_CANCELING')
stripeSubscriptionPeriodEndMissing → const ApiErrorCode
const ApiErrorCode('STRIPE_SUBSCRIPTION_PERIOD_END_MISSING')
stripeWebhookNotAvailable → const ApiErrorCode
const ApiErrorCode('STRIPE_WEBHOOK_NOT_AVAILABLE')
stripeWebhookSignatureInvalid → const ApiErrorCode
const ApiErrorCode('STRIPE_WEBHOOK_SIGNATURE_INVALID')
stripeWebhookSignatureMissing → const ApiErrorCode
const ApiErrorCode('STRIPE_WEBHOOK_SIGNATURE_MISSING')
directMessagesDisabled → const ApiErrorCode
const ApiErrorCode('DIRECT_MESSAGES_DISABLED')
donationAmountInvalid → const ApiErrorCode
const ApiErrorCode('DONATION_AMOUNT_INVALID')
donationMagicLinkExpired → const ApiErrorCode
const ApiErrorCode('DONATION_MAGIC_LINK_EXPIRED')
donationMagicLinkInvalid → const ApiErrorCode
const ApiErrorCode('DONATION_MAGIC_LINK_INVALID')
donationMagicLinkUsed → const ApiErrorCode
const ApiErrorCode('DONATION_MAGIC_LINK_USED')
donorNotFound → const ApiErrorCode
const ApiErrorCode('DONOR_NOT_FOUND')
sudoModeRequired → const ApiErrorCode
const ApiErrorCode('SUDO_MODE_REQUIRED')
tagAlreadyTaken → const ApiErrorCode
const ApiErrorCode('TAG_ALREADY_TAKEN')
temporaryInviteRequiresPresence → const ApiErrorCode
const ApiErrorCode('TEMPORARY_INVITE_REQUIRES_PRESENCE')
testHarnessDisabled → const ApiErrorCode
const ApiErrorCode('TEST_HARNESS_DISABLED')
testHarnessForbidden → const ApiErrorCode
const ApiErrorCode('TEST_HARNESS_FORBIDDEN')
twoFaNotEnabled → const ApiErrorCode
const ApiErrorCode('TWO_FA_NOT_ENABLED')
twoFactorRequired → const ApiErrorCode
const ApiErrorCode('TWO_FACTOR_REQUIRED')
unauthorized → const ApiErrorCode
const ApiErrorCode('UNAUTHORIZED')
unclaimedAccountCannotAcceptFriendRequests → const ApiErrorCode
const ApiErrorCode('UNCLAIMED_ACCOUNT_CANNOT_ACCEPT_FRIEND_REQUESTS')
unclaimedAccountCannotAddReactions → const ApiErrorCode
const ApiErrorCode('UNCLAIMED_ACCOUNT_CANNOT_ADD_REACTIONS')
unclaimedAccountCannotCreateApplications → const ApiErrorCode
const ApiErrorCode('UNCLAIMED_ACCOUNT_CANNOT_CREATE_APPLICATIONS')
unclaimedAccountCannotCreateGuilds → const ApiErrorCode
const ApiErrorCode('UNCLAIMED_ACCOUNT_CANNOT_CREATE_GUILDS')
unclaimedAccountCannotJoinGroupDms → const ApiErrorCode
const ApiErrorCode('UNCLAIMED_ACCOUNT_CANNOT_JOIN_GROUP_DMS')
unclaimedAccountCannotJoinOneOnOneVoiceCalls → const ApiErrorCode
const ApiErrorCode('UNCLAIMED_ACCOUNT_CANNOT_JOIN_ONE_ON_ONE_VOICE_CALLS')
unclaimedAccountCannotJoinVoiceChannels → const ApiErrorCode
const ApiErrorCode('UNCLAIMED_ACCOUNT_CANNOT_JOIN_VOICE_CHANNELS')
unclaimedAccountCannotMakePurchases → const ApiErrorCode
const ApiErrorCode('UNCLAIMED_ACCOUNT_CANNOT_MAKE_PURCHASES')
unclaimedAccountCannotSendDirectMessages → const ApiErrorCode
const ApiErrorCode('UNCLAIMED_ACCOUNT_CANNOT_SEND_DIRECT_MESSAGES')
unclaimedAccountCannotSendFriendRequests → const ApiErrorCode
const ApiErrorCode('UNCLAIMED_ACCOUNT_CANNOT_SEND_FRIEND_REQUESTS')
unclaimedAccountCannotSendMessages → const ApiErrorCode
const ApiErrorCode('UNCLAIMED_ACCOUNT_CANNOT_SEND_MESSAGES')
unclaimedAccountCannotSubmitReports → const ApiErrorCode
const ApiErrorCode('UNCLAIMED_ACCOUNT_CANNOT_SUBMIT_REPORTS')
unknownChannel → const ApiErrorCode
const ApiErrorCode('UNKNOWN_CHANNEL')
unknownEmoji → const ApiErrorCode
const ApiErrorCode('UNKNOWN_EMOJI')
unknownFavoriteMeme → const ApiErrorCode
const ApiErrorCode('UNKNOWN_FAVORITE_MEME')
unknownGiftCode → const ApiErrorCode
const ApiErrorCode('UNKNOWN_GIFT_CODE')
unknownGuild → const ApiErrorCode
const ApiErrorCode('UNKNOWN_GUILD')
unknownHarvest → const ApiErrorCode
const ApiErrorCode('UNKNOWN_HARVEST')
unknownInvite → const ApiErrorCode
const ApiErrorCode('UNKNOWN_INVITE')
unknownMember → const ApiErrorCode
const ApiErrorCode('UNKNOWN_MEMBER')
unknownMessage → const ApiErrorCode
const ApiErrorCode('UNKNOWN_MESSAGE')
unknownPack → const ApiErrorCode
const ApiErrorCode('UNKNOWN_PACK')
unknownReport → const ApiErrorCode
const ApiErrorCode('UNKNOWN_REPORT')
unknownRole → const ApiErrorCode
const ApiErrorCode('UNKNOWN_ROLE')
unknownSticker → const ApiErrorCode
const ApiErrorCode('UNKNOWN_STICKER')
unknownSuspiciousFlag → const ApiErrorCode
const ApiErrorCode('UNKNOWN_SUSPICIOUS_FLAG')
unknownUserFlag → const ApiErrorCode
const ApiErrorCode('UNKNOWN_USER_FLAG')
unknownUser → const ApiErrorCode
const ApiErrorCode('UNKNOWN_USER')
unknownVoiceRegion → const ApiErrorCode
const ApiErrorCode('UNKNOWN_VOICE_REGION')
unknownVoiceServer → const ApiErrorCode
const ApiErrorCode('UNKNOWN_VOICE_SERVER')
unknownWebauthnCredential → const ApiErrorCode
const ApiErrorCode('UNKNOWN_WEBAUTHN_CREDENTIAL')
unknownApplication → const ApiErrorCode
const ApiErrorCode('UNKNOWN_APPLICATION')
unknownWebhook → const ApiErrorCode
const ApiErrorCode('UNKNOWN_WEBHOOK')
unfurlStreamTooLarge → const ApiErrorCode
const ApiErrorCode('UNFURL_STREAM_TOO_LARGE')
unsupportedResponseType → const ApiErrorCode
const ApiErrorCode('UNSUPPORTED_RESPONSE_TYPE')
usernameNotAvailable → const ApiErrorCode
const ApiErrorCode('USERNAME_NOT_AVAILABLE')
updateFailed → const ApiErrorCode
const ApiErrorCode('UPDATE_FAILED')
userBannedFromGuild → const ApiErrorCode
const ApiErrorCode('USER_BANNED_FROM_GUILD')
userIpBannedFromGuild → const ApiErrorCode
const ApiErrorCode('USER_IP_BANNED_FROM_GUILD')
userNotInVoice → const ApiErrorCode
const ApiErrorCode('USER_NOT_IN_VOICE')
userOwnsGuilds → const ApiErrorCode
const ApiErrorCode('USER_OWNS_GUILDS')
validationError → const ApiErrorCode
const ApiErrorCode('VALIDATION_ERROR')
voiceChannelFull → const ApiErrorCode
const ApiErrorCode('VOICE_CHANNEL_FULL')
webauthnCredentialLimitReached → const ApiErrorCode
const ApiErrorCode('WEBAUTHN_CREDENTIAL_LIMIT_REACHED')
ageVerificationAlreadyVerified → const ApiErrorCode
const ApiErrorCode('AGE_VERIFICATION_ALREADY_VERIFIED')
ageVerificationInvalidCardType → const ApiErrorCode
const ApiErrorCode('AGE_VERIFICATION_INVALID_CARD_TYPE')
$unknown → const ApiErrorCode

Default value for all unparsed values, allows backward compatibility when adding new values on the backend.

const ApiErrorCode(null)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
json → String?
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

$valuesDefined → List<ApiErrorCode>
Returns all defined enum values excluding the $unknown value.
no setter

Constants

values → const List<ApiErrorCode>
A constant List of the values in this enum, in order of their declaration.