botGlobalName property
The display name of the bot user, if set
Implementation
@JsonKey(includeIfNull: true, name: 'bot_global_name')
final String? botGlobalName;
The display name of the bot user, if set
@JsonKey(includeIfNull: true, name: 'bot_global_name')
final String? botGlobalName;