hasBotToken property
Whether a hashed bot token is stored for this application
Implementation
@JsonKey(name: 'has_bot_token')
final bool hasBotToken;
Whether a hashed bot token is stored for this application
@JsonKey(name: 'has_bot_token')
final bool hasBotToken;