hasClientSecret property
Whether a hashed client secret is stored for this application
Implementation
@JsonKey(name: 'has_client_secret')
final bool hasClientSecret;
Whether a hashed client secret is stored for this application
@JsonKey(name: 'has_client_secret')
final bool hasClientSecret;