ApplicationPublicResponse class

Annotations
  • @JsonSerializable.new()

Constructors

ApplicationPublicResponse({required String id, required String name, required String? icon, required String? description, required List<String> redirectUris, required List<String> scopes, required bool botPublic, required ApplicationBotResponse? bot, UserPartialResponse? currentUser})
const
ApplicationPublicResponse.fromJson(Map<String, Object?> json)
factory

Properties

bot ApplicationBotResponse?
The bot user associated with the application
final
botPublic bool
Whether the bot can be invited by anyone
final
currentUser UserPartialResponse?
Partial user data for the authenticated requester, when a session token is present
final
description String?
The description of the application
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
The icon hash of the application
final
id String
The unique identifier of the application
final
name String
The name of the application
final
redirectUris List<String>
The registered redirect URIs for OAuth2
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
The available OAuth2 scopes
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited