currentUser property
Partial user data for the authenticated requester, when a session token is present
Implementation
@JsonKey(includeIfNull: false, name: 'current_user')
final UserPartialResponse? currentUser;
Partial user data for the authenticated requester, when a session token is present
@JsonKey(includeIfNull: false, name: 'current_user')
final UserPartialResponse? currentUser;