ApplicationResponse class

Annotations
  • @JsonSerializable.new()

Constructors

ApplicationResponse({required String id, required String name, required List<String> redirectUris, required bool botPublic, required bool botRequireCodeGrant, String? clientSecret, ApplicationBotResponse? bot})
const
ApplicationResponse.fromJson(Map<String, Object?> json)
factory

Properties

bot ApplicationBotResponse?
final
botPublic bool
Whether the bot can be invited by anyone
final
botRequireCodeGrant bool
Whether the bot requires OAuth2 code grant
final
clientSecret String?
The client secret for OAuth2 authentication
final
hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier of the application
final
name String
The name of the application
final
redirectUris List<String>
The registered redirect URIs for OAuth2
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited