description property
The persisted bot profile bio used as the application description
Implementation
@JsonKey(includeIfNull: true)
final String? description;
The persisted bot profile bio used as the application description
@JsonKey(includeIfNull: true)
final String? description;