AuthMfaRequiredResponse class

Annotations
  • @JsonSerializable.new()

Constructors

AuthMfaRequiredResponse({required AuthMfaRequiredResponseMfaMfa mfa, required String ticket, required List<String> allowedMethods, required bool totp, required bool webauthn})
const
AuthMfaRequiredResponse.fromJson(Map<String, Object?> json)
factory

Properties

allowedMethods List<String>
List of allowed MFA methods
final
hashCode int
The hash code for this object.
no setterinherited
mfa AuthMfaRequiredResponseMfaMfa
Indicates MFA is required to complete authentication
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ticket String
MFA ticket to use when completing MFA verification
final
totp bool
Whether TOTP authenticator MFA is available
final
webauthn bool
Whether WebAuthn security key MFA is available
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited