AuthRegisterResponse class

Constructors

AuthRegisterResponse(Map<String, dynamic> _json)
const
AuthRegisterResponse.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toAuthRegistrationPendingApprovalResponse() → AuthRegisterResponseAuthRegistrationPendingApprovalResponse
toAuthTokenWithUserIdResponse() → AuthRegisterResponseAuthTokenWithUserIdResponse
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
toVariant2() → AuthRegisterResponseVariant2

Operators

operator ==(Object other) → bool
The equality operator.
inherited