AuthTokenWithUserIdResponse class

Annotations
  • @JsonSerializable.new()

Constructors

AuthTokenWithUserIdResponse({required String token, required String userId, required AuthTokenWithUserIdResponseUser user})
const
AuthTokenWithUserIdResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
Authentication token for API requests
final
user AuthTokenWithUserIdResponseUser
Partial user data for the authenticated account
final
userId String
ID of the authenticated user
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited