BanAvatarHashRequest class

Annotations
  • @JsonSerializable.new()

Constructors

BanAvatarHashRequest({required List<String> hashes, String? category, int? severity, String? sourceUrl, String? reason, String? notes})
const
BanAvatarHashRequest.fromJson(Map<String, Object?> json)
factory

Properties

category String?
final
hashCode int
The hash code for this object.
no setterinherited
hashes List<String>
final
notes String?
final
reason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity int?
final
sourceUrl String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited