BanFileShaRequest class

Annotations
  • @JsonSerializable.new()

Constructors

BanFileShaRequest({required String sha256Hex, String? category, int? severity, String? contentType, String? sourceUrl, String? notes})
const
BanFileShaRequest.fromJson(Map<String, Object?> json)
factory

Properties

category String?
final
contentType String?
Optional MIME type hint for observability
final
hashCode int
The hash code for this object.
no setterinherited
notes String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity int?
final
sha256Hex String
SHA-256 in hex
final
sourceUrl String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited