BanProfileSubstringRequest class

Annotations
  • @JsonSerializable.new()

Constructors

BanProfileSubstringRequest({required ProfileSubstringScopeSchema scope, required List<String> substrings, String? reason, String? notes})
const
BanProfileSubstringRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
notes String?
final
reason String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope ProfileSubstringScopeSchema
final
substrings List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited