BotProfileUpdateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

BotProfileUpdateRequest({UsernameType? username, DiscriminatorType? discriminator, Base64ImageType? avatar, Base64ImageType? banner, String? bio, BotFlags? botFlags})
const
BotProfileUpdateRequest.fromJson(Map<String, Object?> json)
factory

Properties

avatar → Base64ImageType?
The avatar image as base64
final
The banner image as base64
final
bio → Base64ImageType?
The bio or description of the bot
final
botFlags → BotFlags?
final
discriminator → Base64ImageType?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
username → Base64ImageType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited