BotTokenResetResponse class

Annotations
  • @JsonSerializable.new()

Constructors

BotTokenResetResponse({required String token, required BotTokenResetResponseBot bot})
const
BotTokenResetResponse.fromJson(Map<String, Object?> json)
factory

Properties

bot → BotTokenResetResponseBot
Detailed bot user metadata
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
The new bot token
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited