BulkMessageFetchResponseChannels class

Annotations
  • @JsonSerializable.new()

Constructors

BulkMessageFetchResponseChannels({required String channelId, required List<MessageResponseSchema> messages})
const
BulkMessageFetchResponseChannels.fromJson(Map<String, Object?> json)
factory

Properties

channelId String
The ID of the channel whose messages were fetched
final
hashCode int
The hash code for this object.
no setterinherited
messages List<MessageResponseSchema>
Messages fetched for this channel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited