BulkUpdateUserFlagsRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
BulkUpdateUserFlagsRequest({required List<
SnowflakeType> userIds, List<UserFlags> ? addFlags, List<UserFlags> ? removeFlags}) -
const
-
BulkUpdateUserFlagsRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
-
addFlags
→ List<
UserFlags> ? -
User flags to add to all specified users
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
removeFlags
→ List<
UserFlags> ? -
User flags to remove from all specified users
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
userIds
→ List<
SnowflakeType> -
List of user IDs to update
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited