CallRingBodySchema class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
CallRingBodySchema({List<
SnowflakeType> ? recipients, String? latitude, String? longitude}) -
const
-
CallRingBodySchema.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- latitude → String?
-
Client latitude used for automatic region selection
final
- longitude → String?
-
Client longitude used for automatic region selection
final
-
recipients
→ List<
SnowflakeType> ? -
User IDs to ring for the call
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited