region property
The preferred voice region for the call (1-64 characters). Omit or set to null for automatic region selection.
Implementation
@JsonKey(includeIfNull: false)
final String? region;
The preferred voice region for the call (1-64 characters). Omit or set to null for automatic region selection.
@JsonKey(includeIfNull: false)
final String? region;