ChangeDobRequest class

Annotations
  • @JsonSerializable.new()

Constructors

ChangeDobRequest({required SnowflakeType userId, required String dateOfBirth})
const
ChangeDobRequest.fromJson(Map<String, Object?> json)
factory

Properties

dateOfBirth String
New date of birth in YYYY-MM-DD format
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId SnowflakeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited