ChannelCreateRequest0 class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

ChannelCreateRequest0({required String? topic, required String? url, required SnowflakeType? parentId, required int? bitrate, required int? userLimit, required List<ChannelOverwriteRequest>? permissionOverwrites, required bool? nsfw, required bool? nsfwOverride, required ContentWarningLevel? contentWarningLevel, required String? contentWarningText, required ChannelCreateTextRequestTypeType type, required String name})
const
ChannelCreateRequest0.fromJson(Map<String, dynamic> json)
factory

Properties

bitrate int?
final
contentWarningLevel ContentWarningLevel?
final
contentWarningText String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
nsfw bool?
final
nsfwOverride bool?
final
parentId SnowflakeType?
final
permissionOverwrites List<ChannelOverwriteRequest>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topic String?
final
type ChannelCreateTextRequestTypeType
final
url String?
final
userLimit int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited