ChannelInviteCreateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

ChannelInviteCreateRequest({int? maxUses, int? maxAge, bool? unique, bool? temporary})
const
ChannelInviteCreateRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
maxAge → int?
Duration in seconds before the invite expires (0 for never)
final
maxUses → int?
Maximum number of times this invite can be used (0 for unlimited)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
temporary → bool?
Whether members that joined via this invite should be kicked after disconnecting
final
unique → bool?
Whether to create a new unique invite or reuse an existing one
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited