temporary property
Whether members that joined via this invite should be kicked after disconnecting
Implementation
@JsonKey(includeIfNull: false)
final bool? temporary;
Whether members that joined via this invite should be kicked after disconnecting
@JsonKey(includeIfNull: false)
final bool? temporary;