ChannelPartialResponse class

Annotations
  • @JsonSerializable.new()

Constructors

ChannelPartialResponse({required String id, required int type, String? name, List<ChannelPartialResponseRecipients>? recipients})
const
ChannelPartialResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier (snowflake) for this channel
final
name → String?
The name of the channel
final
recipients → List<ChannelPartialResponseRecipients>?
The recipients of the DM channel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → int
The type of the channel
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited