ChannelPositionUpdateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

ChannelPositionUpdateRequest({required SnowflakeType id, int? position, SnowflakeType? parentId, SnowflakeType? precedingSiblingId, bool? lockPermissions})
const
ChannelPositionUpdateRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id SnowflakeType
final
lockPermissions bool?
Whether to sync permissions with the new parent
final
parentId SnowflakeType?
New parent category ID
final
position int?
New position for the channel
final
precedingSiblingId SnowflakeType?
ID of the sibling channel that should directly precede this channel after reordering
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited