lastPinTimestamp property
The ISO 8601 timestamp of when the last pinned message was pinned
Implementation
@JsonKey(includeIfNull: false, name: 'last_pin_timestamp')
final DateTime? lastPinTimestamp;
The ISO 8601 timestamp of when the last pinned message was pinned
@JsonKey(includeIfNull: false, name: 'last_pin_timestamp')
final DateTime? lastPinTimestamp;