userLimit property
The maximum number of users allowed in the voice channel
Implementation
@JsonKey(includeIfNull: false, name: 'user_limit')
final Int32Type? userLimit;
The maximum number of users allowed in the voice channel
@JsonKey(includeIfNull: false, name: 'user_limit')
final Int32Type? userLimit;