ownerId property
ID of the new owner of the group DM
Implementation
@JsonKey(includeIfNull: false, name: 'owner_id')
final SnowflakeType? ownerId;
ID of the new owner of the group DM
@JsonKey(includeIfNull: false, name: 'owner_id')
final SnowflakeType? ownerId;