ChannelUpdateRequest3 class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

ChannelUpdateRequest3({required GroupDmChannelUpdateRequestTypeType type, required String? name, required Base64ImageType? icon, required SnowflakeType? ownerId, required ChannelNicknameOverrides? nicks})
const
ChannelUpdateRequest3.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon → String?
final
name → String?
final
nicks → ChannelNicknameOverrides?
final
ownerId → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → GroupDmChannelUpdateRequestTypeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited