ClearGuildFieldsRequestFieldsFields enum
Guild image field that can be cleared
Values
- icon → const ClearGuildFieldsRequestFieldsFields
-
const ClearGuildFieldsRequestFieldsFields('icon') -
const ClearGuildFieldsRequestFieldsFields('banner') - splash → const ClearGuildFieldsRequestFieldsFields
-
const ClearGuildFieldsRequestFieldsFields('splash') - embedSplash → const ClearGuildFieldsRequestFieldsFields
-
const ClearGuildFieldsRequestFieldsFields('embed_splash') - $unknown → const ClearGuildFieldsRequestFieldsFields
-
Default value for all unparsed values, allows backward compatibility when adding new values on the backend.
const ClearGuildFieldsRequestFieldsFields(null)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- json → String?
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
$valuesDefined
→ List<
ClearGuildFieldsRequestFieldsFields> -
Returns all defined enum values excluding the $unknown value.
no setter
Constants
-
values
→ const List<
ClearGuildFieldsRequestFieldsFields> - A constant List of the values in this enum, in order of their declaration.