ClientAttachmentReferenceRequestIdId class

The identifier of the attachment being referenced (snowflake ID or file index)

Constructors

ClientAttachmentReferenceRequestIdId(Map<String, dynamic> _json)
const
ClientAttachmentReferenceRequestIdId.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toInt32Type() ClientAttachmentReferenceRequestIdIdInt32Type
toJson() Map<String, dynamic>
toSnowflakeType() ClientAttachmentReferenceRequestIdIdSnowflakeType
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited