initiationToken property
Signed token the client sends back at verify time
Implementation
@JsonKey(name: 'initiation_token')
final String initiationToken;
Signed token the client sends back at verify time
@JsonKey(name: 'initiation_token')
final String initiationToken;