CreateAdminApiKeyRequest class

Annotations
  • @JsonSerializable.new()

Constructors

CreateAdminApiKeyRequest({required String name, required List<String> acls, int? expiresInDays})
const
CreateAdminApiKeyRequest.fromJson(Map<String, Object?> json)
factory

Properties

acls List<String>
List of access control permissions for the key
final
expiresInDays int?
Number of days until the key expires
final
hashCode int
The hash code for this object.
no setterinherited
name String
Display name for the API key
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited