CreateAdminApiKeyResponse class

Annotations
  • @JsonSerializable.new()

Constructors

CreateAdminApiKeyResponse({required String keyId, required String key, required String name, required String createdAt, required String? expiresAt, required List<String> acls})
const
CreateAdminApiKeyResponse.fromJson(Map<String, Object?> json)
factory

Properties

acls List<String>
List of access control permissions for the key
final
createdAt String
ISO 8601 timestamp when the key was created
final
expiresAt String?
ISO 8601 timestamp when the key expires, or null if no expiration
final
hashCode int
The hash code for this object.
no setterinherited
key String
The generated API key secret (only shown once)
final
keyId String
Unique identifier for the API key
final
name String
Display name for the API key
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited