CreateConnectionRequest class

Annotations
  • @JsonSerializable.new()

Constructors

CreateConnectionRequest({required CreateConnectionRequestTypeType type, required String identifier, Int32Type? visibilityFlags})
const
CreateConnectionRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
identifier → String
The connection identifier (handle or domain)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → CreateConnectionRequestTypeType
The type of connection to create
final
visibilityFlags → Int32Type?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited