CreateVoiceRegionRequest class

Annotations
  • @JsonSerializable.new()

Constructors

CreateVoiceRegionRequest({required String id, required String name, required String emoji, required num latitude, required num longitude, bool? isDefault, bool? vipOnly, List<String>? requiredGuildFeatures, List<SnowflakeType>? allowedGuildIds, List<SnowflakeType>? allowedUserIds})
const
CreateVoiceRegionRequest.fromJson(Map<String, Object?> json)
factory

Properties

allowedGuildIds List<SnowflakeType>?
Guild IDs explicitly allowed to use this region
final
allowedUserIds List<SnowflakeType>?
User IDs explicitly allowed to use this region
final
emoji String
Emoji representing the region
final
hashCode int
The hash code for this object.
no setterinherited
id String
Unique identifier for the voice region
final
isDefault bool?
Whether this is the default region
final
latitude num
Geographic latitude coordinate
final
longitude num
Geographic longitude coordinate
final
name String
Display name of the voice region
final
requiredGuildFeatures List<String>?
Guild features required to use this region
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vipOnly bool?
Whether this region is restricted to VIP users
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited