DeleteWebAuthnCredentialRequest class

Annotations
  • @JsonSerializable.new()

Constructors

DeleteWebAuthnCredentialRequest({required SnowflakeType userId, required String credentialId})
const
DeleteWebAuthnCredentialRequest.fromJson(Map<String, Object?> json)
factory

Properties

credentialId String
ID of the WebAuthn credential to delete
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId SnowflakeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited