DisableTotpRequest class

Annotations
  • @JsonSerializable.new()

Constructors

DisableTotpRequest({required String code, PasswordType? password, DisableTotpRequestMfaMethodMfaMethod? mfaMethod, String? mfaCode, dynamic webauthnResponse, String? webauthnChallenge})
const
DisableTotpRequest.fromJson(Map<String, Object?> json)
factory

Properties

code String
The TOTP code to verify
final
hashCode int
The hash code for this object.
no setterinherited
mfaCode String?
MFA verification code from an authenticator app
final
mfaMethod DisableTotpRequestMfaMethodMfaMethod?
MFA method to use for verification
final
password PasswordType?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webauthnChallenge String?
WebAuthn challenge string
final
webauthnResponse → dynamic
WebAuthn authentication response
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited