DiscoveryApplicationRequest class

Annotations
  • @JsonSerializable.new()

Constructors

DiscoveryApplicationRequest({required String description, required int categoryType, String? primaryLanguage, List<String>? customTags})
const
DiscoveryApplicationRequest.fromJson(Map<String, Object?> json)
factory

Properties

categoryType int
Discovery category type
final
customTags List<String>?
Up to 10 custom discovery tags
final
description String
Description for discovery listing
final
hashCode int
The hash code for this object.
no setterinherited
primaryLanguage String?
Primary community language (BCP-47 code)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited