DiscoveryStatusResponse class

Annotations
  • @JsonSerializable.new()

Constructors

DiscoveryStatusResponse({required bool eligible, required num minMemberCount, DiscoveryApplicationResponse? application})
const
DiscoveryStatusResponse.fromJson(Map<String, Object?> json)
factory

Properties

application DiscoveryApplicationResponse?
Current discovery application, if any
final
eligible bool
Whether the guild meets the requirements to apply for discovery
final
hashCode int
The hash code for this object.
no setterinherited
minMemberCount num
Minimum member count required for discovery eligibility
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited