DonationCheckoutRequest class

Annotations
  • @JsonSerializable.new()

Constructors

DonationCheckoutRequest({required String email, required int amountCents, required DonationCheckoutRequestCurrencyCurrency currency, required DonationCheckoutRequestIntervalInterval? interval})
const
DonationCheckoutRequest.fromJson(Map<String, Object?> json)
factory

Properties

amountCents int
Donation amount in minor units for the selected currency
final
currency DonationCheckoutRequestCurrencyCurrency
Currency for the donation
final
email String
Donor email address
final
hashCode int
The hash code for this object.
no setterinherited
interval DonationCheckoutRequestIntervalInterval?
Billing interval (null for one-time donation)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited