DsaReportRequestGuild class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

DsaReportRequestGuild({required String ticket, required String? additionalInfo, required String reporterFullLegalName, required GuildDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence reporterCountryOfResidence, required String? reporterFluxerTag, required GuildDsaReportRequestReportTypeReportType reportType, required GuildDsaReportRequestCategoryCategory category, required SnowflakeType guildId, required String? inviteCode})
const
DsaReportRequestGuild.fromJson(Map<String, dynamic> json)
factory

Properties

additionalInfo → String?
final
category → GuildDsaReportRequestCategoryCategory
final
guildId → String
final
hashCode → int
The hash code for this object.
no setterinherited
inviteCode → String?
final
reporterCountryOfResidence → GuildDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence
final
reporterFluxerTag → String?
final
reporterFullLegalName → String
final
reportType → GuildDsaReportRequestReportTypeReportType
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ticket → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited