DsaReportRequestMessage class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

DsaReportRequestMessage({required String ticket, required String? additionalInfo, required String reporterFullLegalName, required MessageDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence reporterCountryOfResidence, required String? reporterFluxerTag, required MessageDsaReportRequestReportTypeReportType reportType, required MessageDsaReportRequestCategoryCategory category, required String messageLink, required String? reportedUserTag})
const
DsaReportRequestMessage.fromJson(Map<String, dynamic> json)
factory

Properties

additionalInfo → String?
final
category → MessageDsaReportRequestCategoryCategory
final
hashCode → int
The hash code for this object.
no setterinherited
final
reportedUserTag → String?
final
reporterCountryOfResidence → MessageDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence
final
reporterFluxerTag → String?
final
reporterFullLegalName → String
final
reportType → MessageDsaReportRequestReportTypeReportType
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ticket → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited