DsaReportRequestUser class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

DsaReportRequestUser({required String ticket, required String? additionalInfo, required String reporterFullLegalName, required UserDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence reporterCountryOfResidence, required String? reporterFluxerTag, required UserDsaReportRequestReportTypeReportType reportType, required UserDsaReportRequestCategoryCategory category, required SnowflakeType? userId, required String? userTag})
const
DsaReportRequestUser.fromJson(Map<String, dynamic> json)
factory

Properties

additionalInfo → String?
final
category → UserDsaReportRequestCategoryCategory
final
hashCode → int
The hash code for this object.
no setterinherited
reporterCountryOfResidence → UserDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence
final
reporterFluxerTag → String?
final
reporterFullLegalName → String
final
reportType → UserDsaReportRequestReportTypeReportType
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ticket → String
final
userId → String?
final
userTag → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited