DsaReportUserRequest class

Annotations
  • @JsonSerializable.new()

Constructors

DsaReportUserRequest({required String ticket, required String reporterFullLegalName, required DsaReportUserRequestReporterCountryOfResidenceReporterCountryOfResidence reporterCountryOfResidence, required DsaReportUserRequestReportTypeReportType reportType, required UserReportCategoryEnum category, String? additionalInfo, String? reporterFluxerTag, SnowflakeType? userId, String? userTag})
const
DsaReportUserRequest.fromJson(Map<String, Object?> json)
factory

Properties

additionalInfo String?
Additional context or details about the report
final
category UserReportCategoryEnum
final
hashCode int
The hash code for this object.
no setterinherited
reporterCountryOfResidence DsaReportUserRequestReporterCountryOfResidenceReporterCountryOfResidence
EU country code of the reporter residence
final
reporterFluxerTag String?
Fluxer tag of the reporter if they have an account
final
reporterFullLegalName String
Full legal name of the person filing the report
final
reportType DsaReportUserRequestReportTypeReportType
Type of report
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ticket String
Verification ticket obtained from email verification
final
userId SnowflakeType?
final
userTag String?
Fluxer tag of the user being reported
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited