EmailChangeRequestNewRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
- EmailChangeRequestNewRequest({required String ticket, required EmailType newEmail, required String originalProof})
-
const
-
EmailChangeRequestNewRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- newEmail → EmailType
-
final
- originalProof → String
-
Proof token obtained from verifying the original email
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ticket → String
-
Email change ticket identifier
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited