EmailChangeStartResponse class

Annotations
  • @JsonSerializable.new()

Constructors

EmailChangeStartResponse({required String ticket, required bool requireOriginal, required String? originalEmail, required String? originalProof, required String? originalCodeExpiresAt, required String? resendAvailableAt})
const
EmailChangeStartResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
originalCodeExpiresAt String?
ISO8601 timestamp when the original verification code expires
final
originalEmail String?
The original email address on record
final
originalProof String?
Proof token generated when original email verification is not required
final
requireOriginal bool
Whether verification of the original email is required
final
resendAvailableAt String?
ISO8601 timestamp when the original verification code can be resent
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ticket String
Ticket returned for email change actions
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited