EmbedFieldResponse class

Annotations
  • @JsonSerializable.new()

Constructors

EmbedFieldResponse({required String name, required String value, required bool inline})
const
EmbedFieldResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
inline bool
Whether the field should be displayed inline
final
name String
The name of the field
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
The value of the field
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited