EmbedFooterResponse class

Annotations
  • @JsonSerializable.new()

Constructors

EmbedFooterResponse({required String text, String? iconUrl, String? proxyIconUrl})
const
EmbedFooterResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
iconUrl String?
The URL of the footer icon
final
proxyIconUrl String?
The proxied URL of the footer icon
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String
The footer text
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited