Enum0 enum

A hint about the type of token being revoked. Name not received and was auto-generated.

Inheritance
Available extensions
Annotations
  • @JsonEnum.new()

Values

accessToken → const Enum0
const Enum0('access_token')
refreshToken → const Enum0
const Enum0('refresh_token')
$unknown → const Enum0

Default value for all unparsed values, allows backward compatibility when adding new values on the backend.

const Enum0(null)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
json → String?
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

$valuesDefined → List<Enum0>
Returns all defined enum values excluding the $unknown value.
no setter

Constants

values → const List<Enum0>
A constant List of the values in this enum, in order of their declaration.