Error class

Annotations
  • @JsonSerializable.new()

Constructors

Error({required ApiErrorCode code, required String message, List<ValidationErrorItem>? errors})
const
Error.fromJson(Map<String, Object?> json)
factory

Properties

code → ApiErrorCode
final
errors → List<ValidationErrorItem>?
Field-specific validation errors
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
Human-readable error message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited