FriendRequestCreateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

FriendRequestCreateRequest({bool? staffForceAccept})
const
FriendRequestCreateRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
staffForceAccept → bool?
Staff-only: immediately create the friendship
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited