GetVoiceRegionRequest class

Annotations
  • @JsonSerializable.new()

Constructors

GetVoiceRegionRequest({required String id, bool? includeServers})
const
GetVoiceRegionRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
ID of the voice region to retrieve
final
includeServers bool?
Whether to include voice servers in the response
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited