GetVoiceServerRequest class

Annotations
  • @JsonSerializable.new()

Constructors

GetVoiceServerRequest({required String regionId, required String serverId})
const
GetVoiceServerRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
regionId String
ID of the region the server belongs to
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serverId String
ID of the voice server to retrieve
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited