GitHubWebhookCheckRun class

Annotations
  • @JsonSerializable.new()

Constructors

GitHubWebhookCheckRun({required String name, required String htmlUrl, required GitHubWebhookCheckRunCheckSuite checkSuite, String? conclusion, String? detailsUrl, GitHubWebhookCheckRunOutput? output, List<GitHubWebhookCheckRunPullRequests>? pullRequests})
const
GitHubWebhookCheckRun.fromJson(Map<String, Object?> json)
factory

Properties

checkSuite → GitHubWebhookCheckRunCheckSuite
final
conclusion → String?
final
detailsUrl → String?
final
hashCode → int
The hash code for this object.
no setterinherited
htmlUrl → String
final
name → String
final
output → GitHubWebhookCheckRunOutput?
final
pullRequests → List<GitHubWebhookCheckRunPullRequests>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited