GitHubWebhookCheckSuite class

Annotations
  • @JsonSerializable.new()

Constructors

GitHubWebhookCheckSuite({required String headSha, required GitHubWebhookCheckSuiteApp app, String? conclusion, String? headBranch, List<GitHubWebhookCheckSuitePullRequests>? pullRequests})
const
GitHubWebhookCheckSuite.fromJson(Map<String, Object?> json)
factory

Properties

app GitHubWebhookCheckSuiteApp
final
conclusion String?
final
hashCode int
The hash code for this object.
no setterinherited
headBranch String?
final
headSha String
final
pullRequests List<GitHubWebhookCheckSuitePullRequests>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited