GitHubWebhookComment class

Annotations
  • @JsonSerializable.new()

Constructors

GitHubWebhookComment({required Int64Type id, required String htmlUrl, required GitHubWebhookCommentUser user, required String body, String? commitId})
const
GitHubWebhookComment.fromJson(Map<String, Object?> json)
factory

Properties

body → String
final
commitId → String?
final
hashCode → int
The hash code for this object.
no setterinherited
htmlUrl → String
final
id → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → GitHubWebhookCommentUser
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited