GitHubWebhookForkee class

Annotations
  • @JsonSerializable.new()

Constructors

GitHubWebhookForkee({required Int32Type id, required String htmlUrl, required String name, required String fullName})
const
GitHubWebhookForkee.fromJson(Map<String, Object?> json)
factory

Properties

fullName String
final
hashCode int
The hash code for this object.
no setterinherited
htmlUrl String
final
id Int32Type
final
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited