GitHubWebhookHeadCommit class

Annotations
  • @JsonSerializable.new()

Constructors

GitHubWebhookHeadCommit({required String id, required String url, required String message, required GitHubWebhookHeadCommitAuthor author})
const
GitHubWebhookHeadCommit.fromJson(Map<String, Object?> json)
factory

Properties

author → GitHubWebhookHeadCommitAuthor
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
url → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited