GitHubWebhookPullRequest class

Annotations
  • @JsonSerializable.new()

Constructors

GitHubWebhookPullRequest({required Int64Type id, required Int32Type number, required String htmlUrl, required GitHubWebhookPullRequestUser user, required String title, String? body})
const
GitHubWebhookPullRequest.fromJson(Map<String, Object?> json)
factory

Properties

body → String?
final
hashCode → int
The hash code for this object.
no setterinherited
htmlUrl → String
final
id → String
final
number → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final
user → GitHubWebhookPullRequestUser
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited