GroupDmChannelUpdateRequest class

Annotations
  • @JsonSerializable.new()

Properties

hashCode → int
The hash code for this object.
no setterinherited
icon → Base64ImageType?
Base64-encoded icon image for the group DM
final
name → Base64ImageType?
The name of the group DM
final
nicks → ChannelNicknameOverrides?
Custom nicknames for users in this group DM
final
ownerId → Base64ImageType?
ID of the new owner of the group DM
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → GroupDmChannelUpdateRequestTypeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited