GroupDmInviteMetadataResponse class

Annotations
  • @JsonSerializable.new()

Constructors

GroupDmInviteMetadataResponse({required String code, required GroupDmInviteMetadataResponseTypeType type, required ChannelPartialResponse channel, required int memberCount, required bool temporary, required DateTime createdAt, required int uses, required int maxUses, UserPartialResponse? inviter, DateTime? expiresAt})
const
GroupDmInviteMetadataResponse.fromJson(Map<String, Object?> json)
factory

Properties

channel ChannelPartialResponse
final
code String
The unique invite code
final
createdAt DateTime
ISO8601 timestamp of when the invite was created
final
expiresAt DateTime?
ISO8601 timestamp of when the invite expires
final
hashCode int
The hash code for this object.
no setterinherited
inviter UserPartialResponse?
The user who created the invite
final
maxUses int
The maximum number of times this invite can be used
final
memberCount int
The current member count of the group DM
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temporary bool
Whether the invite grants temporary membership
final
type GroupDmInviteMetadataResponseTypeType
The type of invite (group DM)
final
uses int
The number of times this invite has been used
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited