GroupDmInviteResponse class

Annotations
  • @JsonSerializable.new()

Constructors

GroupDmInviteResponse({required String code, required GroupDmInviteResponseTypeType type, required ChannelPartialResponse channel, required int memberCount, required bool temporary, UserPartialResponse? inviter, DateTime? expiresAt})
const
GroupDmInviteResponse.fromJson(Map<String, Object?> json)
factory

Properties

channel → ChannelPartialResponse
final
code → String
The unique invite code
final
expiresAt → DateTime?
ISO8601 timestamp of when the invite expires
final
hashCode → int
The hash code for this object.
no setterinherited
inviter → UserPartialResponse?
The user who created the invite
final
memberCount → int
The current member count of the group DM
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
temporary → bool
Whether the invite grants temporary membership
final
type → GroupDmInviteResponseTypeType
The type of invite (group DM)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited