GuildAuditLogEntryResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
GuildAuditLogEntryResponse({required String id, required AuditLogActionType actionType, SnowflakeType? userId, String? targetId, String? reason, GuildAuditLogEntryResponseOptions? options, List<
AuditLogChangeSchema> ? changes}) -
const
-
GuildAuditLogEntryResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- actionType → AuditLogActionType
-
final
-
changes
→ List<
AuditLogChangeSchema> ? -
Changes made to the target
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The unique identifier for this audit log entry
final
- options → GuildAuditLogEntryResponseOptions?
-
Additional options depending on action type
final
- reason → String?
-
The reason provided for the action
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- targetId → String?
-
The ID of the affected entity (user, channel, role, invite code, etc.)
final
- userId → SnowflakeType?
-
The user ID of the user who performed the action
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited