GuildCreateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

GuildCreateRequest({required String name, Base64ImageType? icon, bool? emptyFeatures, TemplateSerializedGuild? template})
const
GuildCreateRequest.fromJson(Map<String, Object?> json)
factory

Properties

emptyFeatures → bool?
Whether to create the guild without default features
final
hashCode → int
The hash code for this object.
no setterinherited
icon → Base64ImageType?
Base64-encoded image data for the guild icon
final
name → String
The name of the guild (1-100 characters)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
template → TemplateSerializedGuild?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited