GuildDeleteRequestMfaMethodMfaMethod enum

MFA method to use for verification

Inheritance
  • Object
  • Enum
  • GuildDeleteRequestMfaMethodMfaMethod
Available extensions
Annotations
  • @JsonEnum.new()

Values

totp → const GuildDeleteRequestMfaMethodMfaMethod
const GuildDeleteRequestMfaMethodMfaMethod('totp')
webAuthn → const GuildDeleteRequestMfaMethodMfaMethod
const GuildDeleteRequestMfaMethodMfaMethod('webauthn')
$unknown → const GuildDeleteRequestMfaMethodMfaMethod

Default value for all unparsed values, allows backward compatibility when adding new values on the backend.

const GuildDeleteRequestMfaMethodMfaMethod(null)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
json → String?
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

$valuesDefined → List<GuildDeleteRequestMfaMethodMfaMethod>
Returns all defined enum values excluding the $unknown value.
no setter

Constants

values → const List<GuildDeleteRequestMfaMethodMfaMethod>
A constant List of the values in this enum, in order of their declaration.