GuildDsaReportRequest class

Annotations
  • @JsonSerializable.new()

Constructors

GuildDsaReportRequest({required String ticket, required String reporterFullLegalName, required GuildDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence reporterCountryOfResidence, required GuildDsaReportRequestReportTypeReportType reportType, required GuildDsaReportRequestCategoryCategory category, required SnowflakeType guildId, String? additionalInfo, String? reporterFluxerTag, String? inviteCode})
const
GuildDsaReportRequest.fromJson(Map<String, Object?> json)
factory

Properties

additionalInfo → String?
Additional context or details about the report
final
category → GuildDsaReportRequestCategoryCategory
Category of the guild report
final
guildId → SnowflakeType
final
hashCode → int
The hash code for this object.
no setterinherited
inviteCode → String?
Invite code used to access the guild
final
reporterCountryOfResidence → GuildDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence
EU country code of the reporter residence
final
reporterFluxerTag → String?
Fluxer tag of the reporter if they have an account
final
reporterFullLegalName → SnowflakeType
Full legal name of the person filing the report
final
reportType → GuildDsaReportRequestReportTypeReportType
Type of report
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ticket → SnowflakeType
Verification ticket obtained from email verification
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → SnowflakeType
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited