GuildInviteMetadataResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- GuildInviteMetadataResponse({required String code, required GuildInviteMetadataResponseTypeType type, required GuildInviteMetadataResponseGuild guild, required ChannelPartialResponse channel, required int memberCount, required int presenceCount, required bool temporary, required DateTime createdAt, required int uses, required int maxUses, required int maxAge, UserPartialResponse? inviter, DateTime? expiresAt})
-
const
-
GuildInviteMetadataResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- channel → ChannelPartialResponse
-
final
- code → String
-
The unique invite code
final
- createdAt → DateTime
-
ISO8601 timestamp of when the invite was created
final
- expiresAt → DateTime?
-
ISO8601 timestamp of when the invite expires
final
- guild → GuildInviteMetadataResponseGuild
-
The guild this invite is for
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inviter → UserPartialResponse?
-
The user who created the invite
final
- maxAge → int
-
The duration in seconds before the invite expires
final
- maxUses → int
-
The maximum number of times this invite can be used
final
- memberCount → int
-
The approximate total member count of the guild
final
- presenceCount → int
-
The approximate online member count of the guild
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temporary → bool
-
Whether the invite grants temporary membership
final
- type → GuildInviteMetadataResponseTypeType
-
The type of invite (guild)
final
- uses → int
-
The number of times this invite has been used
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited