GuildInviteResponseGuild class

Annotations
  • @JsonSerializable.new()

Constructors

GuildInviteResponseGuild({required String id, required String name, required GuildInviteResponseGuildSplashCardAlignmentSplashCardAlignment splashCardAlignment, required List<GuildFeatureSchema> features, String? icon, String? banner, Int32Type? bannerWidth, Int32Type? bannerHeight, String? splash, Int32Type? splashWidth, Int32Type? splashHeight, String? embedSplash, Int32Type? embedSplashWidth, Int32Type? embedSplashHeight})
const
GuildInviteResponseGuild.fromJson(Map<String, Object?> json)
factory

Properties

The hash of the guild banner
final
bannerHeight → Int32Type?
The height of the guild banner in pixels
final
bannerWidth → Int32Type?
The width of the guild banner in pixels
final
embedSplash → String?
The hash of the embedded invite splash
final
embedSplashHeight → Int32Type?
The height of the embedded invite splash in pixels
final
embedSplashWidth → Int32Type?
The width of the embedded invite splash in pixels
final
features → List<GuildFeatureSchema>
Array of guild feature flags
final
hashCode → int
The hash code for this object.
no setterinherited
icon → String?
The hash of the guild icon
final
id → String
The unique identifier for this guild
final
name → String
The name of the guild
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
splash → String?
The hash of the guild splash screen
final
splashCardAlignment → GuildInviteResponseGuildSplashCardAlignmentSplashCardAlignment
The alignment of the splash card
final
splashHeight → Int32Type?
The height of the guild splash in pixels
final
splashWidth → Int32Type?
The width of the guild splash in pixels
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited