embedSplashHeight property
The height of the embedded invite splash in pixels
Implementation
@JsonKey(includeIfNull: false, name: 'embed_splash_height')
final Int32Type? embedSplashHeight;
The height of the embedded invite splash in pixels
@JsonKey(includeIfNull: false, name: 'embed_splash_height')
final Int32Type? embedSplashHeight;