embedSplashWidth property
The width of the embedded invite splash in pixels
Implementation
@JsonKey(includeIfNull: false, name: 'embed_splash_width')
final Int32Type? embedSplashWidth;
The width of the embedded invite splash in pixels
@JsonKey(includeIfNull: false, name: 'embed_splash_width')
final Int32Type? embedSplashWidth;