GuildMemberSearchRequest class

Annotations
  • @JsonSerializable.new()

Constructors

GuildMemberSearchRequest({String? query, int? limit, int? offset, List<String>? roleIds, int? joinedAtGte, int? joinedAtLte, List<JoinSourceType>? joinSourceType, List<String>? sourceInviteCode, bool? isBot, int? userCreatedAtGte, int? userCreatedAtLte, GuildMemberSearchRequestSortBySortBy? sortBy, GuildMemberSearchRequestSortOrderSortOrder? sortOrder})
const
GuildMemberSearchRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isBot bool?
Filter by bot status
final
joinedAtGte int?
Filter members who joined at or after this unix timestamp
final
joinedAtLte int?
Filter members who joined at or before this unix timestamp
final
joinSourceType List<JoinSourceType>?
Filter by join source types
final
limit int?
Maximum number of results to return
final
offset int?
Number of results to skip for pagination
final
query String?
Text to search for in usernames, global names, and nicknames
final
roleIds List<String>?
Filter by role IDs (member must have all specified roles)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortBy GuildMemberSearchRequestSortBySortBy?
Sort results by field
final
sortOrder GuildMemberSearchRequestSortOrderSortOrder?
Sort order
final
sourceInviteCode List<String>?
Filter by invite codes used to join
final
userCreatedAtGte int?
Filter members whose account was created at or after this unix timestamp
final
userCreatedAtLte int?
Filter members whose account was created at or before this unix timestamp
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited