joinedAtLte property
Filter members who joined at or before this unix timestamp
Implementation
@JsonKey(includeIfNull: false, name: 'joined_at_lte')
final int? joinedAtLte;
Filter members who joined at or before this unix timestamp
@JsonKey(includeIfNull: false, name: 'joined_at_lte')
final int? joinedAtLte;