userCreatedAtGte property
Filter members whose account was created at or after this unix timestamp
Implementation
@JsonKey(includeIfNull: false, name: 'user_created_at_gte')
final int? userCreatedAtGte;
Filter members whose account was created at or after this unix timestamp
@JsonKey(includeIfNull: false, name: 'user_created_at_gte')
final int? userCreatedAtGte;