userCreatedAtLte property
Filter members whose account was created at or before this unix timestamp
Implementation
@JsonKey(includeIfNull: false, name: 'user_created_at_lte')
final int? userCreatedAtLte;
Filter members whose account was created at or before this unix timestamp
@JsonKey(includeIfNull: false, name: 'user_created_at_lte')
final int? userCreatedAtLte;