GuildMemberSearchResponse class

Annotations
  • @JsonSerializable.new()

Constructors

GuildMemberSearchResponse({required String guildId, required List<GuildMemberSearchResult> members, required int pageResultCount, required int totalResultCount, required bool indexing})
const
GuildMemberSearchResponse.fromJson(Map<String, Object?> json)
factory

Properties

guildId String
Guild ID
final
hashCode int
The hash code for this object.
no setterinherited
indexing bool
Whether the guild members are currently being indexed
final
members List<GuildMemberSearchResult>
Matching members
final
pageResultCount int
Number of results in this page
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalResultCount int
Total number of matching results
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited