GuildMemberUpdateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

GuildMemberUpdateRequest({required String? nick, required DateTime? communicationDisabledUntil, List<SnowflakeType>? roles, Base64ImageType? avatar, Base64ImageType? banner, String? bio, String? pronouns, int? accentColor, GuildMemberProfileFlags? profileFlags, MentionReplyPreferences? mentionFlags, bool? mute, bool? deaf, String? timeoutReason, SnowflakeType? channelId, String? connectionId})
const
GuildMemberUpdateRequest.fromJson(Map<String, Object?> json)
factory

Properties

accentColor → int?
The accent color for the member guild profile as an integer
final
avatar → Base64ImageType?
Base64-encoded image data for the member guild avatar
final
Base64-encoded image data for the member guild banner
final
bio → Base64ImageType?
The member guild profile bio (1-320 characters)
final
channelId → Base64ImageType?
The voice channel ID to move the member to
final
communicationDisabledUntil → DateTime?
ISO8601 timestamp until which the member is timed out
final
connectionId → Base64ImageType?
The voice connection ID for the member
final
deaf → bool?
Whether the member is deafened in voice channels
final
hashCode → int
The hash code for this object.
no setterinherited
mentionFlags → MentionReplyPreferences?
Per-guild reply mention preference override for this member; NO_PREFERENCE inherits the user's account-wide setting
final
mute → bool?
Whether the member is muted in voice channels
final
nick → Base64ImageType?
The nickname to set for the member (1-32 characters)
final
profileFlags → int?
final
pronouns → Base64ImageType?
The member guild profile pronouns (1-40 characters)
final
roles → List<SnowflakeType>?
Array of role IDs to assign to the member (max 100)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timeoutReason → Base64ImageType?
The reason for timing out the member (1-512 characters)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited