afkTimeout property
AFK timeout in seconds before moving users to the AFK channel
Implementation
@JsonKey(name: 'afk_timeout')
final int afkTimeout;
AFK timeout in seconds before moving users to the AFK channel
@JsonKey(name: 'afk_timeout')
final int afkTimeout;