channels property
Channels visible to the requesting user from gateway state
Implementation
@JsonKey(includeIfNull: false)
final List<ChannelResponse>? channels;
Channels visible to the requesting user from gateway state
@JsonKey(includeIfNull: false)
final List<ChannelResponse>? channels;