systemChannelId property
The ID of the channel where system messages are sent
Implementation
@JsonKey(includeIfNull: false, name: 'system_channel_id')
final SnowflakeType? systemChannelId;
The ID of the channel where system messages are sent
@JsonKey(includeIfNull: false, name: 'system_channel_id')
final SnowflakeType? systemChannelId;