GuildRoleCreateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

GuildRoleCreateRequest({required String name, int? color, UnsignedInt64Type? permissions})
const
GuildRoleCreateRequest.fromJson(Map<String, Object?> json)
factory

Properties

color → int?
The color of the role as an integer (default: 0)
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the role (1-100 characters)
final
permissions → UnsignedInt64Type?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited