GuildRoleResponse class

Annotations
  • @JsonSerializable.new()

Constructors

GuildRoleResponse({required String id, required String name, required int color, required int position, required String permissions, required bool hoist, required bool mentionable, Int32Type? hoistPosition, String? unicodeEmoji})
const
GuildRoleResponse.fromJson(Map<String, Object?> json)
factory

Properties

color → int
The colour of the role as an integer
final
hashCode → int
The hash code for this object.
no setterinherited
hoist → bool
Whether this role is displayed separately in the member list
final
hoistPosition → Int32Type?
The position of the role in the hoisted member list
final
id → String
The unique identifier for this role
final
mentionable → bool
Whether this role can be mentioned by anyone
final
name → String
The name of the role
final
permissions → String
The permissions bitfield for the role
final
position → int
The position of the role in the role hierarchy
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unicodeEmoji → String?
The unicode emoji for this role
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited