hoist property
Whether the role should be displayed separately in the member list
Implementation
@JsonKey(includeIfNull: false)
final bool? hoist;
Whether the role should be displayed separately in the member list
@JsonKey(includeIfNull: false)
final bool? hoist;