hoistPosition property
The position of the role in the hoisted member list
Implementation
@JsonKey(includeIfNull: false, name: 'hoist_position')
final int? hoistPosition;
The position of the role in the hoisted member list
@JsonKey(includeIfNull: false, name: 'hoist_position')
final int? hoistPosition;