GuildStickerBulkCreateRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
GuildStickerBulkCreateRequest({required List<
GuildStickerCreateRequest> stickers}) -
const
-
GuildStickerBulkCreateRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stickers
→ List<
GuildStickerCreateRequest> -
Array of sticker objects to create (1-50 stickers per batch)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited