GuildStickerBulkCreateResponseFailed class

Annotations
  • @JsonSerializable.new()

Constructors

GuildStickerBulkCreateResponseFailed({required String name, required String error})
const
GuildStickerBulkCreateResponseFailed.fromJson(Map<String, Object?> json)
factory

Properties

error String
The error message explaining why the sticker failed to create
final
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the sticker that failed to create
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited