GuildStickerMetadataResponse class

Annotations
  • @JsonSerializable.new()

Constructors

GuildStickerMetadataResponse({required String id, required String guildId, required String name, required bool animated, required bool allowCloning})
const
GuildStickerMetadataResponse.fromJson(Map<String, Object?> json)
factory

Properties

allowCloning bool
Whether the source guild allows non-members to use the in-app clone shortcut
final
animated bool
Whether this sticker is animated
final
guildId String
The guild this sticker belongs to
final
hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier for this sticker
final
name String
The name of the sticker
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited