GuildTemplateResponse class

Annotations
  • @JsonSerializable.new()

Constructors

GuildTemplateResponse({required String code, required String name, required GuildTemplateResponseSerializedSourceGuild serializedSourceGuild, String? description})
const
GuildTemplateResponse.fromJson(Map<String, Object?> json)
factory

Properties

code String
The template code
final
description String?
The description of the template
final
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the template
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
serializedSourceGuild GuildTemplateResponseSerializedSourceGuild
The serialised guild data
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited