GuildTransferOwnershipRequest class

Annotations
  • @JsonSerializable.new()

Constructors

GuildTransferOwnershipRequest({required SnowflakeType newOwnerId, PasswordType? password})
const
GuildTransferOwnershipRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
newOwnerId SnowflakeType
final
password PasswordType?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited