HandoffCompleteRequest class

Annotations
  • @JsonSerializable.new()

Constructors

HandoffCompleteRequest({required String code, required String userId, String? token})
const
HandoffCompleteRequest.fromJson(Map<String, Object?> json)
factory

Properties

code → String
The handoff code from the initiating session
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String?
The authentication token to transfer
final
userId → String
The user ID associated with the authenticated session
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited