HandoffStatusResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- HandoffStatusResponse({required String status, String? token, SnowflakeType? userId, UserPartialResponse? user})
-
const
-
HandoffStatusResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
Current status of the handoff (pending, completed, expired)
final
- token → String?
-
Authentication token if handoff is complete
final
- user → UserPartialResponse?
-
Partial user data if handoff is complete
final
- userId → SnowflakeType?
-
User ID if handoff is complete
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited