InstanceConfigUpdateRequestSso class

Annotations
  • @JsonSerializable.new()

Constructors

InstanceConfigUpdateRequestSso({bool? enabled, String? displayName, String? issuer, String? authorizationUrl, String? tokenUrl, String? userinfoUrl, String? jwksUrl, String? clientId, String? clientSecret, String? scope, List<String>? allowedDomains, bool? autoProvision, String? redirectUri})
const
InstanceConfigUpdateRequestSso.fromJson(Map<String, Object?> json)
factory

Properties

allowedDomains List<String>?
final
authorizationUrl String?
final
autoProvision bool?
final
clientId String?
final
clientSecret String?
final
displayName String?
final
enabled bool?
final
hashCode int
The hash code for this object.
no setterinherited
issuer String?
final
jwksUrl String?
final
redirectUri String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String?
final
tokenUrl String?
final
userinfoUrl String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited