InstatusWebhookComponent class

Annotations
  • @JsonSerializable.new()

Constructors

InstatusWebhookComponent({String? id, String? name, String? status, String? createdAt})
const
InstatusWebhookComponent.fromJson(Map<String, Object?> json)
factory

Properties

createdAt → String?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
final
name → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited