InstatusWebhookComponentUpdate class

Annotations
  • @JsonSerializable.new()

Constructors

InstatusWebhookComponentUpdate({String? createdAt, String? newStatus, String? componentId})
const
InstatusWebhookComponentUpdate.fromJson(Map<String, Object?> json)
factory

Properties

componentId String?
final
createdAt String?
final
hashCode int
The hash code for this object.
no setterinherited
newStatus String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited