InviteMetadataResponseSchemaPackInviteMetadataResponse class

Annotations
  • @JsonSerializable.new()

Constructors

InviteMetadataResponseSchemaPackInviteMetadataResponse({required String code, required PackInviteMetadataResponseTypeType type, required PackInviteMetadataResponsePack pack, required UserPartialResponse? inviter, required DateTime? expiresAt, required bool temporary, required DateTime createdAt, required int uses, required int maxUses})
const
InviteMetadataResponseSchemaPackInviteMetadataResponse.fromJson(Map<String, dynamic> json)
factory

Properties

code String
final
createdAt DateTime
final
expiresAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
inviter UserPartialResponse?
final
maxUses int
final
pack PackInviteMetadataResponsePack
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temporary bool
final
type PackInviteMetadataResponseTypeType
final
uses int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited