InviteResponseSchema class

Constructors

InviteResponseSchema(Map<String, dynamic> _json)
const
InviteResponseSchema.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toGroupDmInviteResponse() → InviteResponseSchemaGroupDmInviteResponse
toGuildInviteResponse() → InviteResponseSchemaGuildInviteResponse
toJson() → Map<String, dynamic>
toPackInviteResponse() → InviteResponseSchemaPackInviteResponse
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited