InviteResponseSchemaGroupDmInviteResponse class

Annotations
  • @JsonSerializable.new()

Constructors

InviteResponseSchemaGroupDmInviteResponse({required String code, required GroupDmInviteResponseTypeType type, required ChannelPartialResponse channel, required UserPartialResponse? inviter, required int memberCount, required DateTime? expiresAt, required bool temporary})
const
InviteResponseSchemaGroupDmInviteResponse.fromJson(Map<String, dynamic> json)
factory

Properties

channel ChannelPartialResponse
final
code String
final
expiresAt DateTime?
final
hashCode int
The hash code for this object.
no setterinherited
inviter UserPartialResponse?
final
memberCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temporary bool
final
type GroupDmInviteResponseTypeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited