JobStatusEnum enum
Values
- queued → const JobStatusEnum
-
const JobStatusEnum('queued') - running → const JobStatusEnum
-
const JobStatusEnum('running') - succeeded → const JobStatusEnum
-
const JobStatusEnum('succeeded') - failed → const JobStatusEnum
-
const JobStatusEnum('failed') - cancelled → const JobStatusEnum
-
const JobStatusEnum('cancelled') - deadletter → const JobStatusEnum
-
const JobStatusEnum('deadletter') - $unknown → const JobStatusEnum
-
Default value for all unparsed values, allows backward compatibility when adding new values on the backend.
const JobStatusEnum(null)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- json → String?
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
$valuesDefined
→ List<
JobStatusEnum> -
Returns all defined enum values excluding the $unknown value.
no setter
Constants
-
values
→ const List<
JobStatusEnum> - A constant List of the values in this enum, in order of their declaration.