LimitConfigGetResponse class

Annotations
  • @JsonSerializable.new()

Constructors

LimitConfigGetResponse({required LimitConfigGetResponseLimitConfig limitConfig, required String limitConfigJson, required bool selfHosted, required Map<String, Map<String, num>> defaults, required Map<String, Metadata> metadata, required Map<String, String> categories, required List<String> limitKeys, Map<String, Bounds>? bounds})
const
LimitConfigGetResponse.fromJson(Map<String, Object?> json)
factory

Properties

bounds Map<String, Bounds>?
final
categories Map<String, String>
final
defaults Map<String, Map<String, num>>
final
hashCode int
The hash code for this object.
no setterinherited
limitConfig LimitConfigGetResponseLimitConfig
final
limitConfigJson String
final
limitKeys List<String>
final
metadata Map<String, Metadata>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfHosted bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited