LimitRuleResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
LimitRuleResponse({required String id, required Map<
String, num> overrides, LimitFilterResponse? filters}) -
const
-
LimitRuleResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- filters → LimitFilterResponse?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
Unique identifier for this limit rule
final
-
overrides
→ Map<
String, num> -
Map of limit keys to their override values (differences from defaults)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited