ListGuildAuditLogsRequest class

Annotations
  • @JsonSerializable.new()

Constructors

ListGuildAuditLogsRequest({required SnowflakeType guildId, Int32Type? limit, SnowflakeType? before, SnowflakeType? after, SnowflakeType? userId, AuditLogActionType? actionType})
const
ListGuildAuditLogsRequest.fromJson(Map<String, Object?> json)
factory

Properties

actionType AuditLogActionType?
final
after SnowflakeType?
final
before SnowflakeType?
final
guildId SnowflakeType
final
hashCode int
The hash code for this object.
no setterinherited
limit Int32Type?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId SnowflakeType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited