ListReportsRequest class

Annotations
  • @JsonSerializable.new()

Constructors

ListReportsRequest({ReportStatus? status, int? limit, int? offset})
const
ListReportsRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
limit int?
Maximum number of reports to return
final
offset int?
Number of reports to skip
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ReportStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited