ListUserChangeLogRequest class

Annotations
  • @JsonSerializable.new()

Constructors

ListUserChangeLogRequest({required SnowflakeType userId, int? limit, String? pageToken})
const
ListUserChangeLogRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
limit int?
Maximum number of entries to return
final
pageToken String?
Pagination token for the next page of results
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId SnowflakeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited