ListUserSessionsResponse class

Annotations
  • @JsonSerializable.new()

Constructors

ListUserSessionsResponse({required List<UserSessionResponse> sessions})
const
ListUserSessionsResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessions List<UserSessionResponse>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited