Locale enum
The locale code for the user interface language
Values
- ar → const Locale
-
const Locale('ar') - bg → const Locale
-
const Locale('bg') - cs → const Locale
-
const Locale('cs') - da → const Locale
-
const Locale('da') - de → const Locale
-
const Locale('de') - el → const Locale
-
const Locale('el') - enGb → const Locale
-
const Locale('en-GB') - enUs → const Locale
-
const Locale('en-US') - esEs → const Locale
-
const Locale('es-ES') - es419 → const Locale
-
const Locale('es-419') - fi → const Locale
-
const Locale('fi') - fr → const Locale
-
const Locale('fr') - he → const Locale
-
const Locale('he') - hi → const Locale
-
const Locale('hi') - hr → const Locale
-
const Locale('hr') - hu → const Locale
-
const Locale('hu') - id → const Locale
-
const Locale('id') - it → const Locale
-
const Locale('it') - ja → const Locale
-
const Locale('ja') - ko → const Locale
-
const Locale('ko') - lt → const Locale
-
const Locale('lt') - nl → const Locale
-
const Locale('nl') - no → const Locale
-
const Locale('no') - pl → const Locale
-
const Locale('pl') - ptBr → const Locale
-
const Locale('pt-BR') - ro → const Locale
-
const Locale('ro') - ru → const Locale
-
const Locale('ru') - svSe → const Locale
-
const Locale('sv-SE') - th → const Locale
-
const Locale('th') - tr → const Locale
-
const Locale('tr') - uk → const Locale
-
const Locale('uk') - vi → const Locale
-
const Locale('vi') - zhCn → const Locale
-
const Locale('zh-CN') - zhTw → const Locale
-
const Locale('zh-TW') - $unknown → const Locale
-
Default value for all unparsed values, allows backward compatibility when adding new values on the backend.
const Locale(null)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- json → String?
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
$valuesDefined
→ List<
Locale> -
Returns all defined enum values excluding the $unknown value.
no setter