LogoutAuthSessionsRequest class

Annotations
  • @JsonSerializable.new()

Constructors

LogoutAuthSessionsRequest({required List<String> sessionIdHashes, PasswordType? password})
const
LogoutAuthSessionsRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
password PasswordType?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionIdHashes List<String>
Array of session ID hashes to log out (max 100)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited