LookupMessageRequest class

Annotations
  • @JsonSerializable.new()

Constructors

LookupMessageRequest({required SnowflakeType channelId, required SnowflakeType messageId, int? contextLimit})
const
LookupMessageRequest.fromJson(Map<String, Object?> json)
factory

Properties

channelId SnowflakeType
final
contextLimit int?
final
hashCode int
The hash code for this object.
no setterinherited
messageId SnowflakeType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited