MessageCallResponse class

Annotations
  • @JsonSerializable.new()

Constructors

MessageCallResponse({required List<String> participants, DateTime? endedTimestamp})
const
MessageCallResponse.fromJson(Map<String, Object?> json)
factory

Properties

endedTimestamp DateTime?
The ISO 8601 timestamp of when the call ended
final
hashCode int
The hash code for this object.
no setterinherited
participants List<String>
The user IDs of participants in the call
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited