MessageDsaReportRequest class

Annotations
  • @JsonSerializable.new()

Constructors

MessageDsaReportRequest({required String ticket, required String reporterFullLegalName, required MessageDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence reporterCountryOfResidence, required MessageDsaReportRequestReportTypeReportType reportType, required MessageDsaReportRequestCategoryCategory category, required String messageLink, String? additionalInfo, String? reporterFluxerTag, String? reportedUserTag})
const
MessageDsaReportRequest.fromJson(Map<String, Object?> json)
factory

Properties

additionalInfo → String?
Additional context or details about the report
final
category → MessageDsaReportRequestCategoryCategory
Category of the message report
final
hashCode → int
The hash code for this object.
no setterinherited
Link to the message being reported
final
reportedUserTag → String?
Fluxer tag of the user who sent the message
final
reporterCountryOfResidence → MessageDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence
EU country code of the reporter residence
final
reporterFluxerTag → String?
Fluxer tag of the reporter if they have an account
final
reporterFullLegalName → String
Full legal name of the person filing the report
final
reportType → MessageDsaReportRequestReportTypeReportType
Type of report
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ticket → String
Verification ticket obtained from email verification
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited