MessageEmbedResponse class

Annotations
  • @JsonSerializable.new()

Constructors

MessageEmbedResponse({required String type, String? url, String? title, Int32Type? color, DateTime? timestamp, String? description, EmbedAuthorResponse? author, EmbedMediaResponse? image, EmbedMediaResponse? thumbnail, EmbedFooterResponse? footer, List<EmbedFieldResponse>? fields, EmbedAuthorResponse? provider, EmbedMediaResponse? video, EmbedMediaResponse? audio, String? html, Int32Type? htmlWidth, Int32Type? htmlHeight, bool? nsfw, List<MessageEmbedChildResponse>? children})
const
MessageEmbedResponse.fromJson(Map<String, Object?> json)
factory

Properties

audio → EmbedMediaResponse?
The audio of the embed
final
author → EmbedAuthorResponse?
The author information of the embed
final
children → List<MessageEmbedChildResponse>?
Internal nested embeds generated by unfurlers
final
color → Int32Type?
The color code of the embed sidebar
final
description → String?
The description of the embed
final
fields → List<EmbedFieldResponse>?
The fields of the embed
final
The footer of the embed
final
hashCode → int
The hash code for this object.
no setterinherited
html → String?
Sanitized oEmbed HTML for trusted specialized embed renderers
final
htmlHeight → Int32Type?
The preferred height of sanitized oEmbed HTML
final
htmlWidth → Int32Type?
The preferred width of sanitized oEmbed HTML
final
image → EmbedMediaResponse?
The image of the embed
final
nsfw → bool?
Whether the embed is flagged as NSFW
final
provider → EmbedAuthorResponse?
The provider of the embed (e.g., YouTube, Twitter)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
thumbnail → EmbedMediaResponse?
The thumbnail of the embed
final
timestamp → DateTime?
The ISO 8601 timestamp of the embed content
final
title → String?
The title of the embed
final
type → String
The type of embed (e.g., rich, image, video, gifv, article, link)
final
url → String?
The URL of the embed
final
video → EmbedMediaResponse?
The video of the embed
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited