MessageShredResponse class

Annotations
  • @JsonSerializable.new()

Constructors

MessageShredResponse({required MessageShredResponseSuccessSuccess success, required String jobId, int? requested})
const
MessageShredResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
jobId String
final
requested int?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
success MessageShredResponseSuccessSuccess
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited