MessageSnapshotAttachmentEditRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
- MessageSnapshotAttachmentEditRequest({required MessageSnapshotAttachmentEditRequestIdId id, String? title, String? description})
-
const
-
MessageSnapshotAttachmentEditRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- description → String?
-
Alt text description for the attachment (1-4096 characters)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → MessageSnapshotAttachmentEditRequestIdId
-
The identifier of the snapshot attachment
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
A title for the attachment (1-1024 characters)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited