MessageStickerResponse class

Annotations
  • @JsonSerializable.new()

Constructors

MessageStickerResponse({required String id, required String name, required bool animated, bool? nsfw})
const
MessageStickerResponse.fromJson(Map<String, Object?> json)
factory

Properties

animated → bool
Whether the sticker is animated
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
The unique identifier of the sticker
final
name → String
The name of the sticker
final
nsfw → bool?
Whether this sticker is classified as NSFW
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited