Metadata class

Annotations
  • @JsonSerializable.new()

Constructors

Metadata({required String key, required String label, required String description, required String category, required String scope, required bool isToggle, MetadataUnitUnit? unit, num? min, num? max})
const
Metadata.fromJson(Map<String, Object?> json)
factory

Properties

category String
final
description String
final
hashCode int
The hash code for this object.
no setterinherited
isToggle bool
final
key String
final
label String
final
max num?
final
min num?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String
final
unit MetadataUnitUnit?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited