MfaBackupCodesRequest class

Annotations
  • @JsonSerializable.new()

Constructors

MfaBackupCodesRequest({required bool regenerate, PasswordType? password, MfaBackupCodesRequestMfaMethodMfaMethod? mfaMethod, String? mfaCode, dynamic webauthnResponse, String? webauthnChallenge})
const
MfaBackupCodesRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mfaCode String?
MFA verification code from an authenticator app
final
mfaMethod MfaBackupCodesRequestMfaMethodMfaMethod?
MFA method to use for verification
final
password PasswordType?
final
regenerate bool
Whether to regenerate backup codes
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webauthnChallenge String?
WebAuthn challenge string
final
webauthnResponse → dynamic
WebAuthn authentication response
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited