MutualGuildResponse class

Annotations
  • @JsonSerializable.new()

Constructors

MutualGuildResponse({required String id, required String? nick})
const
MutualGuildResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The ID of the mutual guild
final
nick String?
The nickname of the target user in this guild
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited