NodeStatsResponseNodes class

Annotations
  • @JsonSerializable.new()

Constructors

NodeStatsResponseNodes({required String nodeId, required String status, required Int32Type sessions, required Int32Type guilds, required Int32Type presences, required Int32Type calls, required NodeStatsResponseNodesMemory memory, required Int32Type processCount, required Int32Type processLimit, required Int32Type uptimeSeconds})
const
NodeStatsResponseNodes.fromJson(Map<String, Object?> json)
factory

Properties

calls Int32Type
final
guilds Int32Type
final
hashCode int
The hash code for this object.
no setterinherited
memory NodeStatsResponseNodesMemory
final
nodeId String
final
presences Int32Type
final
processCount Int32Type
final
processLimit Int32Type
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessions Int32Type
final
status String
final
uptimeSeconds Int32Type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited