NodeStatsResponseNodesMemory class

Annotations
  • @JsonSerializable.new()

Constructors

NodeStatsResponseNodesMemory({required Int64StringType total, required Int64StringType processes, required Int64StringType system})
const
NodeStatsResponseNodesMemory.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
processes Int64StringType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
system Int64StringType
final
total Int64StringType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited