OAuth2AuthorizationResponse class

Annotations
  • @JsonSerializable.new()

Constructors

OAuth2AuthorizationResponse({required OAuth2AuthorizationResponseApplication application, required List<String> scopes, required String authorizedAt})
const
OAuth2AuthorizationResponse.fromJson(Map<String, Object?> json)
factory

Properties

application OAuth2AuthorizationResponseApplication
The application that was authorized
final
authorizedAt String
The timestamp when the authorization was granted
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scopes List<String>
The list of granted OAuth2 scopes
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited