OAuth2AuthorizationResponseApplication class
- Annotations
-
- @JsonSerializable.new()
Constructors
- OAuth2AuthorizationResponseApplication({required String id, required String name, required String? icon, required String? description, required bool botPublic})
-
const
-
OAuth2AuthorizationResponseApplication.fromJson(Map<
String, Object?> json) -
factory
Properties
- botPublic → bool
-
Whether the bot can be invited by anyone
final
- description → String?
-
The description of the application
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
The icon hash of the application
final
- id → String
-
The unique identifier of the application
final
- name → String
-
The name of the application
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited