Object2 class

Name not received and was auto-generated.

Constructors

Object2(Map<String, dynamic> _json)
const
Object2.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toClientAttachmentReferenceRequest() Object2ClientAttachmentReferenceRequest
toClientUploadedAttachmentRequest() Object2ClientUploadedAttachmentRequest
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited