Object2ClientAttachmentReferenceRequest class

Annotations
  • @JsonSerializable.new()

Constructors

Object2ClientAttachmentReferenceRequest({required String? title, required String? description, required MessageAttachmentFlags? flags, required Int32Type? duration, required String? waveform, required dynamic id, required String? filename})
const
Object2ClientAttachmentReferenceRequest.fromJson(Map<String, dynamic> json)
factory

Properties

description → String?
final
duration → Int32Type?
final
filename → String?
final
flags → Int32Type?
final
hashCode → int
The hash code for this object.
no setterinherited
id → dynamic
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final
waveform → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited