Object2ClientUploadedAttachmentRequest class

Annotations
  • @JsonSerializable.new()

Constructors

Object2ClientUploadedAttachmentRequest({required String? title, required String? description, required MessageAttachmentFlags? flags, required Int32Type? duration, required String? waveform, required Int32Type id, required String filename, required String uploadFilename, required NonNegativeSafeIntegerType fileSize, required String contentType})
const
Object2ClientUploadedAttachmentRequest.fromJson(Map<String, dynamic> json)
factory

Properties

contentType → String
final
description → String?
final
duration → Int32Type?
final
filename → String
final
fileSize → int
final
flags → Int32Type?
final
hashCode → int
The hash code for this object.
no setterinherited
id → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
final
uploadFilename → String
final
waveform → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited