Object5 class

Annotations
  • @JsonSerializable.new()

Constructors

Object5({dynamic id, String? filename, String? description, String? contentType, NonNegativeSafeIntegerType? size, String? url, String? proxyUrl, int? height, int? width, bool? ephemeral, num? duration, String? waveform, MessageAttachmentFlags? flags})
const
Object5.fromJson(Map<String, Object?> json)
factory

Properties

contentType → String?
MIME type of the file
final
description → String?
Description for the attachment (max 4096 characters)
final
duration → num?
Duration of audio file in seconds
final
ephemeral → bool?
Whether this attachment is ephemeral
final
filename → String?
Name of the file (1-1024 characters)
final
flags → MessageAttachmentFlags?
final
hashCode → int
The hash code for this object.
no setterinherited
height → MessageAttachmentFlags?
Height of the image/video in pixels
final
id → dynamic
Attachment ID for referencing uploaded files
final
proxyUrl → String?
Proxied URL of the attachment
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → MessageAttachmentFlags?
final
url → String?
URL of the attachment
final
waveform → String?
Base64-encoded bytearray of audio waveform
final
width → MessageAttachmentFlags?
Width of the image/video in pixels
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited