PackDashboardResponseSticker class

Annotations
  • @JsonSerializable.new()

Constructors

PackDashboardResponseSticker({required int installedLimit, required int createdLimit, required List<PackSummaryResponse> installed, required List<PackSummaryResponse> created})
const
PackDashboardResponseSticker.fromJson(Map<String, Object?> json)
factory

Properties

created List<PackSummaryResponse>
List of packs the user has created
final
createdLimit int
Maximum number of packs the user can create
final
hashCode int
The hash code for this object.
no setterinherited
installed List<PackSummaryResponse>
List of packs the user has installed
final
installedLimit int
Maximum number of packs the user can install
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited