unique property
Whether to create a new unique invite or reuse an existing one
Implementation
@JsonKey(includeIfNull: false)
final bool? unique;
Whether to create a new unique invite or reuse an existing one
@JsonKey(includeIfNull: false)
final bool? unique;