PackInviteMetadataResponse class

Annotations
  • @JsonSerializable.new()

Constructors

PackInviteMetadataResponse({required String code, required PackInviteMetadataResponseTypeType type, required PackInviteMetadataResponsePack pack, required bool temporary, required DateTime createdAt, required int uses, required int maxUses, UserPartialResponse? inviter, DateTime? expiresAt})
const
PackInviteMetadataResponse.fromJson(Map<String, Object?> json)
factory

Properties

code String
The unique invite code
final
createdAt DateTime
ISO8601 timestamp of when the invite was created
final
expiresAt DateTime?
ISO8601 timestamp of when the invite expires
final
hashCode int
The hash code for this object.
no setterinherited
inviter UserPartialResponse?
The user who created the invite
final
maxUses int
The maximum number of times this invite can be used
final
pack PackInviteMetadataResponsePack
The pack this invite is for
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temporary bool
Whether the invite grants temporary access
final
type PackInviteMetadataResponseTypeType
The type of pack invite (emoji or sticker pack)
final
uses int
The number of times this invite has been used
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited