PackInviteMetadataResponsePack class
- Annotations
-
- @JsonSerializable.new()
Constructors
- PackInviteMetadataResponsePack({required String id, required String name, required PackInviteMetadataResponsePackTypeType type, required String creatorId, required DateTime createdAt, required DateTime updatedAt, required UserPartialResponse creator, String? description})
-
const
-
PackInviteMetadataResponsePack.fromJson(Map<
String, Object?> json) -
factory
Properties
- createdAt → DateTime
-
ISO8601 timestamp of when the pack was created
final
- creator → UserPartialResponse
-
final
- creatorId → String
-
The ID of the user who created the pack
final
- description → String?
-
The description of the pack
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The unique identifier for the pack
final
- name → String
-
The display name of the pack
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → PackInviteMetadataResponsePackTypeType
-
The type of pack (emoji or sticker)
final
- updatedAt → DateTime
-
ISO8601 timestamp of when the pack was last updated
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited