installedAt property
ISO8601 timestamp of when the pack was installed by the user
Implementation
@JsonKey(includeIfNull: false, name: 'installed_at')
final DateTime? installedAt;
ISO8601 timestamp of when the pack was installed by the user
@JsonKey(includeIfNull: false, name: 'installed_at')
final DateTime? installedAt;