PackUpdateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

PackUpdateRequest({String? name, String? description})
const
PackUpdateRequest.fromJson(Map<String, Object?> json)
factory

Properties

description → String?
The new description of the pack
final
hashCode → int
The hash code for this object.
no setterinherited
name → String?
The new name of the pack
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited