PasswordChangeCompleteResponse class

Annotations
  • @JsonSerializable.new()

Constructors

PasswordChangeCompleteResponse({required String token, required String authSessionIdHash})
const
PasswordChangeCompleteResponse.fromJson(Map<String, Object?> json)
factory

Properties

authSessionIdHash String
Base64url-encoded hash of the newly created authentication session
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
Authentication token for the newly created session
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited