PasswordChangeStartResponse class

Annotations
  • @JsonSerializable.new()

Constructors

PasswordChangeStartResponse({required String ticket, required String codeExpiresAt, required String? resendAvailableAt})
const
PasswordChangeStartResponse.fromJson(Map<String, Object?> json)
factory

Properties

codeExpiresAt String
ISO8601 timestamp when the verification code expires
final
hashCode int
The hash code for this object.
no setterinherited
resendAvailableAt String?
ISO8601 timestamp when the code can be resent
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ticket String
Ticket for password change actions
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited