PasswordChangeVerifyRequest class

Annotations
  • @JsonSerializable.new()

Constructors

PasswordChangeVerifyRequest({required String ticket, required String code})
const
PasswordChangeVerifyRequest.fromJson(Map<String, Object?> json)
factory

Properties

code String
Verification code sent to the email address
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ticket String
Password change ticket identifier
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited