PasswordChangeVerifyResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- PasswordChangeVerifyResponse({required String verificationProof})
-
const
-
PasswordChangeVerifyResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verificationProof → String
-
Proof token issued after verifying the email code
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited