PermissionOverwriteCreateRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
- PermissionOverwriteCreateRequest({required PermissionOverwriteCreateRequestTypeType type, UnsignedInt64Type? allow, UnsignedInt64Type? deny})
-
const
-
PermissionOverwriteCreateRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- allow → UnsignedInt64Type?
-
final
- deny → UnsignedInt64Type?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → PermissionOverwriteCreateRequestTypeType
-
The type of overwrite (0 = role, 1 = member)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited