channel property

  1. @JsonKey.new(includeIfNull: false)
PhoneSendVerificationRequestChannelChannel? channel
final

Channel to deliver the OTP on. Defaults to the first available channel from server policy. Server may override to an available fallback when the requested channel is disabled.

Implementation

@JsonKey(includeIfNull: false)
final PhoneSendVerificationRequestChannelChannel? channel;