PhoneSendVerificationResponseInboundChallenge class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

PhoneSendVerificationResponseInboundChallenge({required String channel, required String challengeCode, required String ourNumber, required DateTime expiresAt, required PhoneSendVerificationResponseInboundChallengeReason reason})
const
PhoneSendVerificationResponseInboundChallenge.fromJson(Map<String, dynamic> json)
factory

Properties

challengeCode String
final
channel String
final
expiresAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
ourNumber String
final
reason PhoneSendVerificationResponseInboundChallengeReason
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited