PhoneVerifyRequest class

Annotations
  • @JsonSerializable.new()

Constructors

PhoneVerifyRequest({required PhoneNumberType phone, required String code})
const
PhoneVerifyRequest.fromJson(Map<String, Object?> json)
factory

Properties

code → String
The verification code
final
hashCode → int
The hash code for this object.
no setterinherited
phone → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited