PreloadMessagesRequest class

Annotations
  • @JsonSerializable.new()

Constructors

PreloadMessagesRequest({required List<SnowflakeType> channels})
const
PreloadMessagesRequest.fromJson(Map<String, Object?> json)
factory

Properties

channels List<SnowflakeType>
Array of channel IDs to preload messages from (max 100)
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited