PremiumEffectiveState class

Annotations
  • @JsonSerializable.new()

Constructors

PremiumEffectiveState({required bool isPremium, required UserPremiumTypes? premiumType, required String? premiumSince, required String? premiumUntil, required bool premiumWillCancel, required PremiumEffectiveStatePremiumBillingCyclePremiumBillingCycle? premiumBillingCycle, required int? premiumLifetimeSequence, required String? premiumGraceEndsAt, required bool premiumEnabledOverride, required bool premiumPurchaseDisabled, required bool premiumPerksDisabled, required bool selfHosted, required bool bot})
const
PremiumEffectiveState.fromJson(Map<String, Object?> json)
factory

Properties

bot bool
Whether the account is a bot account with premium-equivalent service access
final
hashCode int
The hash code for this object.
no setterinherited
isPremium bool
Whether premium perks are currently effective for product gating
final
premiumBillingCycle PremiumEffectiveStatePremiumBillingCyclePremiumBillingCycle?
Effective recurring billing cycle, when known
final
premiumEnabledOverride bool
Whether backend premium override is enabled
final
premiumGraceEndsAt String?
Effective grace timestamp exposed to the client
final
premiumLifetimeSequence int?
Effective Visionary sequence number, when applicable
final
premiumPerksDisabled bool
Whether the user temporarily disabled premium perks
final
premiumPurchaseDisabled bool
Whether premium purchase is disabled for this account
final
premiumSince String?
Effective premium start timestamp exposed to the client
final
premiumType UserPremiumTypes?
Effective premium type used by product gates
final
premiumUntil String?
Effective premium end timestamp exposed to the client
final
premiumWillCancel bool
Effective cancellation status exposed to the client
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfHosted bool
Whether the instance treats all users as premium because it is self-hosted
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited