PricingModeEnum enum
Values
- localized → const PricingModeEnum
-
const PricingModeEnum('localized') - valueBase → const PricingModeEnum
-
The name has been replaced because it contains a keyword. Original name:
base.const PricingModeEnum('base') - $unknown → const PricingModeEnum
-
Default value for all unparsed values, allows backward compatibility when adding new values on the backend.
const PricingModeEnum(null)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- json → String?
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
$valuesDefined
→ List<
PricingModeEnum> -
Returns all defined enum values excluding the $unknown value.
no setter
Constants
-
values
→ const List<
PricingModeEnum> - A constant List of the values in this enum, in order of their declaration.