PushRotateRequestKeys class

Annotations
  • @JsonSerializable.new()

Constructors

PushRotateRequestKeys({required String p256dh, required String auth})
const
PushRotateRequestKeys.fromJson(Map<String, Object?> json)
factory

Properties

auth String
The authentication secret (base64url)
final
hashCode int
The hash code for this object.
no setterinherited
p256dh String
The P-256 ECDH public key (base64url)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited