PushSubscribeRequest class

Annotations
  • @JsonSerializable.new()

Constructors

PushSubscribeRequest({required String endpoint, required PushSubscribeRequestKeys keys, String? userAgent})
const
PushSubscribeRequest.fromJson(Map<String, Object?> json)
factory

Properties

endpoint String
The push subscription endpoint URL
final
hashCode int
The hash code for this object.
no setterinherited
keys PushSubscribeRequestKeys
Encryption keys for the push subscription
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userAgent String?
The user agent string identifying the client
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited