PushSubscriptionsListResponseSubscriptions class

Annotations
  • @JsonSerializable.new()

Constructors

PushSubscriptionsListResponseSubscriptions({required String subscriptionId, required String? userAgent})
const
PushSubscriptionsListResponseSubscriptions.fromJson(Map<String, Object?> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
subscriptionId → String
The unique identifier for the push subscription
final
userAgent → String?
The user agent that created this subscription
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited