ReadStateAckResponse class

Annotations
  • @JsonSerializable.new()

Constructors

ReadStateAckResponse({required List<ReadStateResponse> readStates, required String readStateProto})
const
ReadStateAckResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
readStateProto String
Authoritative read states after applying the acknowledgement, encoded as a base64 protobuf bundle
final
readStates List<ReadStateResponse>
Authoritative read states after applying the acknowledgement
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited