readStateProto property
Authoritative read states after applying the acknowledgement, encoded as a base64 protobuf bundle
Implementation
@JsonKey(name: 'read_state_proto')
final String readStateProto;
Authoritative read states after applying the acknowledgement, encoded as a base64 protobuf bundle
@JsonKey(name: 'read_state_proto')
final String readStateProto;