ReadStateResponse class

Annotations
  • @JsonSerializable.new()

Constructors

ReadStateResponse({required String id, required int mentionCount, required SnowflakeType? lastMessageId, required String? lastPinTimestamp, String? version})
const
ReadStateResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → String
The channel ID for this read state
final
lastMessageId → SnowflakeType?
The ID of the last message read
final
lastPinTimestamp → SnowflakeType?
ISO8601 timestamp of the last pinned message acknowledged
final
mentionCount → int
Number of unread mentions in the channel
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
version → SnowflakeType?
Read-state version for ordering updates as a decimal uint64
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited