RefreshSearchIndexResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- RefreshSearchIndexResponse({required RefreshSearchIndexResponseSuccessSuccess success, required String jobId})
-
const
-
RefreshSearchIndexResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- jobId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- success → RefreshSearchIndexResponseSuccessSuccess
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited