RefreshTokenTokenRequest class

Annotations
  • @JsonSerializable.new()

Constructors

RefreshTokenTokenRequest({required RefreshTokenTokenRequestGrantTypeGrantType grantType, required String refreshToken, SnowflakeType? clientId, String? clientSecret})
const
RefreshTokenTokenRequest.fromJson(Map<String, Object?> json)
factory

Properties

clientId → SnowflakeType?
final
clientSecret → SnowflakeType?
The application client secret
final
grantType → RefreshTokenTokenRequestGrantTypeGrantType
The grant type for refreshing an access token
final
hashCode → int
The hash code for this object.
no setterinherited
refreshToken → String
The refresh token to exchange for a new access token
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited