refreshToken property
The refresh token to exchange for a new access token
Implementation
@JsonKey(name: 'refresh_token')
final String refreshToken;
The refresh token to exchange for a new access token
@JsonKey(name: 'refresh_token')
final String refreshToken;