appId property
Client app channel or bundle mapping identifier, such as stable, beta, or canary
Implementation
@JsonKey(includeIfNull: false, name: 'app_id')
final String? appId;
Client app channel or bundle mapping identifier, such as stable, beta, or canary
@JsonKey(includeIfNull: false, name: 'app_id')
final String? appId;