RegisterRequest class

Annotations
  • @JsonSerializable.new()

Constructors

RegisterRequest({EmailType? email, UsernameType? username, String? globalName, PasswordType? password, String? dateOfBirth, bool? consent, String? inviteCode, String? registrationUrlCode, RegisterRequestThemeTheme? theme})
const
RegisterRequest.fromJson(Map<String, Object?> json)
factory

Properties

Whether user consents to terms of service
final
dateOfBirth → String?
Date of birth in YYYY-MM-DD format
final
email → String?
final
globalName → String?
Display name shown to other users
final
hashCode → int
The hash code for this object.
no setterinherited
inviteCode → String?
Guild invite code to join after registration
final
password → String?
final
registrationUrlCode → String?
Admin-issued registration URL code to use for this registration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
theme → RegisterRequestThemeTheme?
Initial UI theme preference for the new account
final
username → String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited