RelationshipResponse class

Annotations
  • @JsonSerializable.new()

Constructors

RelationshipResponse({required String id, required RelationshipTypes type, required UserPartialResponse user, required String? nickname, DateTime? since})
const
RelationshipResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier for the relationship
final
nickname String?
A custom nickname set for the related user
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
since DateTime?
ISO8601 timestamp of when the relationship was established
final
type RelationshipTypes
The type of relationship (friend, blocked, pending, etc.)
final
user UserPartialResponse
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited