RemoveUserRelationshipRequest class

Annotations
  • @JsonSerializable.new()

Constructors

RemoveUserRelationshipRequest({required SnowflakeType userId, required SnowflakeType targetUserId, required RemoveUserRelationshipRequestCategoryCategory category})
const
RemoveUserRelationshipRequest.fromJson(Map<String, Object?> json)
factory

Properties

category RemoveUserRelationshipRequestCategoryCategory
Which relationship to remove. Friend and outgoing_request also remove the mirror entry on the target user.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
targetUserId SnowflakeType
final
userId SnowflakeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited