category property
Which relationship to remove. Friend and outgoing_request also remove the mirror entry on the target user.
Implementation
final RemoveUserRelationshipRequestCategoryCategory category;
Which relationship to remove. Friend and outgoing_request also remove the mirror entry on the target user.
final RemoveUserRelationshipRequestCategoryCategory category;