ReportGuildRequest class

Annotations
  • @JsonSerializable.new()

Constructors

ReportGuildRequest({required SnowflakeType guildId, required ReportGuildRequestCategoryCategory category, String? inviteCode})
const
ReportGuildRequest.fromJson(Map<String, Object?> json)
factory

Properties

category → ReportGuildRequestCategoryCategory
Category of the guild report
final
guildId → SnowflakeType
final
hashCode → int
The hash code for this object.
no setterinherited
inviteCode → String?
Invite code proving access to the guild (required when not a member of a non-discoverable guild)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → SnowflakeType
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited