ReportMessageRequest class

Annotations
  • @JsonSerializable.new()

Constructors

ReportMessageRequest({required SnowflakeType channelId, required SnowflakeType messageId, required ReportMessageRequestCategoryCategory category})
const
ReportMessageRequest.fromJson(Map<String, Object?> json)
factory

Properties

category → ReportMessageRequestCategoryCategory
Category of the message report
final
channelId → SnowflakeType
final
hashCode → int
The hash code for this object.
no setterinherited
messageId → SnowflakeType
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → SnowflakeType
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited