ReportStatus enum

The status of the report

Inheritance
Available extensions
Annotations
  • @JsonEnum.new()

Values

pending → const ReportStatus
const ReportStatus(0)
resolved → const ReportStatus
const ReportStatus(1)
$unknown → const ReportStatus

Default value for all unparsed values, allows backward compatibility when adding new values on the backend.

const ReportStatus(null)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
json int?
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() int?
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

$valuesDefined List<ReportStatus>
Returns all defined enum values excluding the $unknown value.
no setter

Constants

values → const List<ReportStatus>
A constant List of the values in this enum, in order of their declaration.