ResolveReportResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- ResolveReportResponse({required SnowflakeType reportId, required ReportStatus status, required String? resolvedAt, required String? publicComment})
-
const
-
ResolveReportResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- publicComment → String?
-
final
- reportId → SnowflakeType
-
final
- resolvedAt → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → ReportStatus
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited