RichEmbedMediaRequestShape class
- Annotations
-
- @JsonSerializable.new()
Constructors
- RichEmbedMediaRequestShape({required String url, String? description})
-
const
-
RichEmbedMediaRequestShape.fromJson(Map<
String, Object?> json) -
factory
Properties
- description → String?
-
Alt text description of the media
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
URL of the media (image, video, etc.)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited