RichEmbedRequestFields class

Annotations
  • @JsonSerializable.new()

Constructors

RichEmbedRequestFields({required String name, required String value, bool? inline})
const
RichEmbedRequestFields.fromJson(Map<String, Object?> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
inline → bool?
Whether the field should display inline
final
name → String
Name of the field
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → String
Value of the field (0-1024 characters)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited