SavedMessageEntryResponse class

Annotations
  • @JsonSerializable.new()

Constructors

SavedMessageEntryResponse({required String id, required String channelId, required String messageId, required SavedMessageEntryResponseStatusStatus status, required MessageResponseSchema? message})
const
SavedMessageEntryResponse.fromJson(Map<String, Object?> json)
factory

Properties

channelId → String
ID of the channel containing the message
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
Unique identifier for the saved message entry
final
message → MessageResponseSchema?
The message content if available
final
messageId → String
ID of the saved message
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → SavedMessageEntryResponseStatusStatus
Availability status of the saved message
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited