ScheduledMessageReferenceSchema class

Annotations
  • @JsonSerializable.new()

Constructors

ScheduledMessageReferenceSchema({required String messageId, SnowflakeType? channelId, SnowflakeType? guildId, MessageReferenceType? type})
const
ScheduledMessageReferenceSchema.fromJson(Map<String, Object?> json)
factory

Properties

channelId SnowflakeType?
final
guildId SnowflakeType?
final
hashCode int
The hash code for this object.
no setterinherited
messageId String
ID of the message being referenced
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type MessageReferenceType?
The type of message reference
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited