SearchReportsRequest class

Annotations
  • @JsonSerializable.new()

Constructors

SearchReportsRequest({String? query, int? limit, int? offset, SnowflakeType? reporterId, ReportStatus? status, ReportType? reportType, String? category, SnowflakeType? reportedUserId, SnowflakeType? reportedGuildId, SnowflakeType? reportedChannelId, SnowflakeType? guildContextId, SnowflakeType? resolvedByAdminId, SearchReportsRequestSortBySortBy? sortBy, SearchReportsRequestSortOrderSortOrder? sortOrder})
const
SearchReportsRequest.fromJson(Map<String, Object?> json)
factory

Properties

category String?
Filter by report category
final
guildContextId SnowflakeType?
final
hashCode int
The hash code for this object.
no setterinherited
limit int?
Maximum number of entries to return
final
offset int?
Number of entries to skip
final
query String?
Search query string
final
reportedChannelId SnowflakeType?
final
reportedGuildId SnowflakeType?
final
reportedUserId SnowflakeType?
final
reporterId SnowflakeType?
final
reportType ReportType?
final
resolvedByAdminId SnowflakeType?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortBy SearchReportsRequestSortBySortBy?
Field to sort reports by
final
sortOrder SearchReportsRequestSortOrderSortOrder?
Sort order direction
final
status ReportStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited