SearchUsersRequest class

Annotations
  • @JsonSerializable.new()

Constructors

SearchUsersRequest({String? query, String? email, String? lastActiveIp, int? limit, int? offset})
const
SearchUsersRequest.fromJson(Map<String, Object?> json)
factory

Properties

email String?
final
hashCode int
The hash code for this object.
no setterinherited
lastActiveIp String?
final
limit int?
final
offset int?
final
query String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited