recipientCount property
Number of recipients the worker job was queued to deliver to
Implementation
@JsonKey(name: 'recipient_count')
final int recipientCount;
Number of recipients the worker job was queued to deliver to
@JsonKey(name: 'recipient_count')
final int recipientCount;