SetUserTraitsRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
SetUserTraitsRequest({required SnowflakeType userId, required List<
String> traits}) -
const
-
SetUserTraitsRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
traits
→ List<
String> -
List of traits to assign to the user
final
- userId → SnowflakeType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited