SlackWebhookRequest class

Annotations
  • @JsonSerializable.new()

Constructors

SlackWebhookRequest({String? text, String? username, String? iconUrl, List<SlackWebhookRequestAttachments>? attachments})
const
SlackWebhookRequest.fromJson(Map<String, Object?> json)
factory

Properties

attachments → List<SlackWebhookRequestAttachments>?
Array of attachment objects
final
hashCode → int
The hash code for this object.
no setterinherited
iconUrl → String?
Override the default icon of the webhook
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
text → String?
Main text content of the message
final
username → String?
Override the default username of the webhook
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited