SlackWebhookRequestAttachmentsFields class

Annotations
  • @JsonSerializable.new()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
short bool?
Whether the field should be displayed as a short column
final
title String?
Title of the field
final
value String?
Value of the field
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited