SsoCompleteRequest class

Annotations
  • @JsonSerializable.new()

Constructors

SsoCompleteRequest({required String code, required String state})
const
SsoCompleteRequest.fromJson(Map<String, Object?> json)
factory

Properties

code → String
Authorization code from the SSO provider
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → String
State parameter for CSRF protection
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited