SsoCompleteResponse class

Annotations
  • @JsonSerializable.new()

Constructors

SsoCompleteResponse({required String token, required String userId, required SsoCompleteResponseUser user, required String redirectTo})
const
SsoCompleteResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
redirectTo String
URL to redirect the user to after completion
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
Authentication token for the session
final
user SsoCompleteResponseUser
Partial user data for the authenticated account
final
userId String
ID of the authenticated user
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited