SsoConfigResponse class

Annotations
  • @JsonSerializable.new()

Constructors

SsoConfigResponse({required bool enabled, required String? displayName, required String? issuer, required String? authorizationUrl, required String? tokenUrl, required String? userinfoUrl, required String? jwksUrl, required String? clientId, required bool clientSecretSet, required String? scope, required List<String> allowedDomains, required bool autoProvision, required String? redirectUri})
const
SsoConfigResponse.fromJson(Map<String, Object?> json)
factory

Properties

allowedDomains List<String>
final
authorizationUrl String?
final
autoProvision bool
final
clientId String?
final
clientSecretSet bool
final
displayName String?
final
enabled bool
final
hashCode int
The hash code for this object.
no setterinherited
issuer String?
final
jwksUrl String?
final
redirectUri String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scope String?
final
tokenUrl String?
final
userinfoUrl String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited