SsoStartRequest class

Annotations
  • @JsonSerializable.new()

Constructors

SsoStartRequest({String? redirectTo, String? redirectUri})
const
SsoStartRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
redirectTo String?
URL to redirect to after SSO completion
final
redirectUri String?
OAuth redirect URI to use for the SSO provider callback
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited