StreamPreviewUploadBodySchema class

Annotations
  • @JsonSerializable.new()

Constructors

StreamPreviewUploadBodySchema({required SnowflakeType channelId, required String thumbnail, String? contentType})
const
StreamPreviewUploadBodySchema.fromJson(Map<String, Object?> json)
factory

Properties

channelId SnowflakeType
final
contentType String?
MIME type of the thumbnail image
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thumbnail String
Base64-encoded thumbnail image data
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited