StreamPreviewUploadUrlResponseSchemaMethodMethod enum

HTTP method to use for the upload URL

Inheritance
  • Object
  • Enum
  • StreamPreviewUploadUrlResponseSchemaMethodMethod
Available extensions
Annotations
  • @JsonEnum.new()

Values

put → const StreamPreviewUploadUrlResponseSchemaMethodMethod
const StreamPreviewUploadUrlResponseSchemaMethodMethod('PUT')
$unknown → const StreamPreviewUploadUrlResponseSchemaMethodMethod

Default value for all unparsed values, allows backward compatibility when adding new values on the backend.

const StreamPreviewUploadUrlResponseSchemaMethodMethod(null)

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
json → String?
final
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → String
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

$valuesDefined → List<StreamPreviewUploadUrlResponseSchemaMethodMethod>
Returns all defined enum values excluding the $unknown value.
no setter

Constants

values → const List<StreamPreviewUploadUrlResponseSchemaMethodMethod>
A constant List of the values in this enum, in order of their declaration.