TempBanUserRequest class

Annotations
  • @JsonSerializable.new()

Constructors

TempBanUserRequest({required SnowflakeType userId, required int durationHours, String? reason})
const
TempBanUserRequest.fromJson(Map<String, Object?> json)
factory

Properties

durationHours int
Duration of the ban in hours. Use 0 for a permanent ban (until manually unbanned).
final
hashCode int
The hash code for this object.
no setterinherited
reason String?
Reason for the temporary ban
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId SnowflakeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited