TemplateChannel class

Annotations
  • @JsonSerializable.new()

Constructors

TemplateChannel({required dynamic id, required num type, required num position, String? name, String? topic, dynamic parentId, num? bitrate, num? userLimit, bool? nsfw, num? rateLimitPerUser, List<TemplatePermissionOverwrite>? permissionOverwrites})
const
TemplateChannel.fromJson(Map<String, Object?> json)
factory

Properties

bitrate num?
The bitrate for voice channels
final
hashCode int
The hash code for this object.
no setterinherited
id → dynamic
The template-local channel ID
final
name String?
The name of the channel
final
nsfw bool?
Whether the channel is NSFW
final
parentId → dynamic
The template-local ID of the parent category
final
permissionOverwrites List<TemplatePermissionOverwrite>?
Permission overwrites for this channel
final
position num
The position of the channel
final
rateLimitPerUser num?
Slowmode rate limit in seconds
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topic String?
The channel topic
final
type num
The channel type (0 = text, 2 = voice, 4 = category)
final
userLimit num?
The user limit for voice channels
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited