TemplateRole class

Annotations
  • @JsonSerializable.new()

Constructors

TemplateRole({required dynamic id, String? name, dynamic permissions, dynamic permissionsNew, num? color, bool? hoist, bool? mentionable, String? unicodeEmoji})
const
TemplateRole.fromJson(Map<String, Object?> json)
factory

Properties

color num?
The colour of the role as an integer
final
hashCode int
The hash code for this object.
no setterinherited
hoist bool?
Whether the role is hoisted
final
id → dynamic
The template-local role ID
final
mentionable bool?
Whether the role is mentionable
final
name String?
The name of the role
final
permissions → dynamic
The permissions bitfield as a string (legacy)
final
permissionsNew → dynamic
The permissions bitfield as a string (preferred)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
unicodeEmoji String?
The unicode emoji for the role icon
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited