TemplateSerializedGuild class

Annotations
  • @JsonSerializable.new()

Constructors

TemplateSerializedGuild({required String name, required List<TemplateRole> roles, required List<TemplateChannel> channels, String? description, num? verificationLevel, num? defaultMessageNotifications, num? explicitContentFilter, dynamic systemChannelId, num? afkTimeout, num? systemChannelFlags})
const
TemplateSerializedGuild.fromJson(Map<String, Object?> json)
factory

Properties

afkTimeout → num?
The AFK timeout in seconds
final
channels → List<TemplateChannel>
The channels in the template
final
defaultMessageNotifications → num?
The default message notification level
final
description → String?
The description of the template guild
final
explicitContentFilter → num?
The explicit content filter level
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
The name of the template guild
final
roles → List<TemplateRole>
The roles in the template
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
systemChannelFlags → num?
The system channel flags
final
systemChannelId → dynamic
The template-local system channel ID
final
verificationLevel → num?
The verification level
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited