UnregisterMobileDeviceRequest class

Annotations
  • @JsonSerializable.new()

Properties

appId → String?
Client app channel or bundle mapping identifier, such as stable, beta, or canary
final
hashCode → int
The hash code for this object.
no setterinherited
platform → UnregisterMobileDeviceRequestPlatformPlatform
The mobile push notification platform
final
providerEnvironment → UnregisterMobileDeviceRequestProviderEnvironmentProviderEnvironment?
Push provider environment used for this registration
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
The platform-specific push notification token to unregister
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited