UpdateGuildSettingsRequest class

Annotations
  • @JsonSerializable.new()

Constructors

UpdateGuildSettingsRequest({required SnowflakeType guildId, GuildVerificationLevel? verificationLevel, GuildMfaLevel? mfaLevel, NsfwLevel? nsfwLevel, bool? nsfw, ContentWarningLevel? contentWarningLevel, String? contentWarningText, GuildExplicitContentFilter? explicitContentFilter, DefaultMessageNotifications? defaultMessageNotifications, GuildOperations? disabledOperations})
const
UpdateGuildSettingsRequest.fromJson(Map<String, Object?> json)
factory

Properties

contentWarningLevel ContentWarningLevel?
final
contentWarningText String?
Custom content warning text shown before entry
final
defaultMessageNotifications DefaultMessageNotifications?
Default notification setting for new members
final
disabledOperations GuildOperations?
final
explicitContentFilter GuildExplicitContentFilter?
Explicit content filter level
final
guildId SnowflakeType
final
hashCode int
The hash code for this object.
no setterinherited
mfaLevel GuildMfaLevel?
Required MFA level for moderators
final
nsfw bool?
Whether the guild is flagged as adult content
final
nsfwLevel NsfwLevel?
NSFW content level for the guild
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
verificationLevel GuildVerificationLevel?
Required verification level for guild members
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited