UpdateGuildVanityRequest class

Annotations
  • @JsonSerializable.new()

Constructors

UpdateGuildVanityRequest({required SnowflakeType guildId, required String? vanityUrlCode})
const
UpdateGuildVanityRequest.fromJson(Map<String, Object?> json)
factory

Properties

guildId SnowflakeType
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
vanityUrlCode String?
New vanity URL code, or null to remove
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited