UpdateUserFlagsRequest class

Annotations
  • @JsonSerializable.new()

Constructors

UpdateUserFlagsRequest({required SnowflakeType userId, List<UserFlags>? addFlags, List<UserFlags>? removeFlags})
const
UpdateUserFlagsRequest.fromJson(Map<String, Object?> json)
factory

Properties

addFlags List<UserFlags>?
User flags to add
final
hashCode int
The hash code for this object.
no setterinherited
removeFlags List<UserFlags>?
User flags to remove
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId SnowflakeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited