UserAdminResponseSchema class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
UserAdminResponseSchema({required Int32Type? accentColor, required String username, required Int32Type discriminator, required String? globalName, required bool bot, required bool system, required UserFlags flags, required String? avatar, required String? banner, required String? bio, required String? pronouns, required SnowflakeType id, required String? email, required bool emailVerified, required bool emailBounced, required bool hasVerifiedPhone, required String? dateOfBirth, required String? locale, required String? lastActiveLocation, required String? tempBannedUntil, required String? pendingDeletionAt, required String? pendingBulkMessageDeletionAt, required Int32Type? deletionReasonCode, required String? deletionPublicReason, required List<
String> acls, required List<String> traits, required bool hasTotp, required List<Int32Type> authenticatorTypes, required String? lastActiveAt, required String? lastActiveIp, required String? lastActiveIpReverse, required SuspiciousActivityFlags suspiciousActivityFlags}) -
const
-
UserAdminResponseSchema.fromJson(Map<
String, Object?> json) -
factory
Properties
- accentColor → Int32Type?
-
final
-
acls
→ List<
String> -
final
-
authenticatorTypes
→ List<
Int32Type> -
final
- avatar → String?
-
final
-
final
- bio → String?
-
final
- bot → bool
-
final
- dateOfBirth → String?
-
final
- deletionPublicReason → String?
-
final
- deletionReasonCode → Int32Type?
-
final
- discriminator → Int32Type
-
final
- email → String?
-
final
- emailBounced → bool
-
final
- emailVerified → bool
-
final
- flags → UserFlags
-
final
- globalName → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasTotp → bool
-
final
- hasVerifiedPhone → bool
-
final
- id → SnowflakeType
-
final
- lastActiveAt → String?
-
final
- lastActiveIp → String?
-
final
- lastActiveIpReverse → String?
-
final
- lastActiveLocation → String?
-
final
- locale → String?
-
final
- pendingBulkMessageDeletionAt → String?
-
final
- pendingDeletionAt → String?
-
final
-
final
-
final
-
final
-
final
-
final
-
final
- pronouns → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suspiciousActivityFlags → SuspiciousActivityFlags
-
final
- system → bool
-
final
- tempBannedUntil → String?
-
final
-
traits
→ List<
String> -
final
- username → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited