UserDsaReportRequest class

Annotations
  • @JsonSerializable.new()

Constructors

UserDsaReportRequest({required String ticket, required String reporterFullLegalName, required UserDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence reporterCountryOfResidence, required UserDsaReportRequestReportTypeReportType reportType, required UserDsaReportRequestCategoryCategory category, String? additionalInfo, String? reporterFluxerTag, SnowflakeType? userId, String? userTag})
const
UserDsaReportRequest.fromJson(Map<String, Object?> json)
factory

Properties

additionalInfo → String?
Additional context or details about the report
final
category → UserDsaReportRequestCategoryCategory
Category of the user report
final
hashCode → int
The hash code for this object.
no setterinherited
reporterCountryOfResidence → UserDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence
EU country code of the reporter residence
final
reporterFluxerTag → String?
Fluxer tag of the reporter if they have an account
final
reporterFullLegalName → String
Full legal name of the person filing the report
final
reportType → UserDsaReportRequestReportTypeReportType
Type of report
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ticket → String
Verification ticket obtained from email verification
final
userId → String?
final
userTag → String?
Fluxer tag of the user being reported
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited