UserSettingsResponse class

Annotations
  • @JsonSerializable.new()

Constructors

UserSettingsResponse({required bool renderEmbeds, required List<SnowflakeType> staffDmAccessUserIds, required List<SnowflakeType> suppressUnprivilegedSelfMentionsBypassUserIds, required String theme, required Locale locale, required List<SnowflakeType> restrictedGuilds, required List<SnowflakeType> botRestrictedGuilds, required bool defaultGuildsRestricted, required bool botDefaultGuildsRestricted, required bool inlineAttachmentMedia, required bool inlineEmbedMedia, required bool gifAutoPlay, required String status, required bool renderReactions, required bool animateEmoji, required StickerAnimationOptions animateStickers, required RenderSpoilers renderSpoilers, required bool messageDisplayCompact, required FriendSourceFlags friendSourceFlags, required IncomingCallFlags incomingCallFlags, required GroupDmAddPermissionFlags groupDmAddPermissionFlags, required List<UserSettingsResponseGuildFolders> guildFolders, required String syncedPreferences, required int afkTimeout, required TimeFormatTypes timeFormat, required bool developerMode, required List<String> trustedDomains, required bool defaultHideMutedChannels, required SensitiveMediaFilterLevel sensitiveContentFriendDmFilter, required SensitiveMediaFilterLevel sensitiveContentNonFriendDmFilter, required SensitiveMediaGuildFilterLevel sensitiveContentGuildFilter, required bool suppressUnprivilegedSelfMentions, required CustomStatusResponse? customStatus, DateTime? statusResetsAt, String? statusResetsTo})
const
UserSettingsResponse.fromJson(Map<String, Object?> json)
factory

Properties

afkTimeout int
The idle timeout in seconds before going AFK
final
animateEmoji bool
Whether to animate custom emoji
final
animateStickers StickerAnimationOptions
Sticker animation preference setting
final
botDefaultGuildsRestricted bool
Whether new guilds have bot DM restrictions by default
final
botRestrictedGuilds List<SnowflakeType>
Guild IDs where bot direct messages are restricted
final
customStatus CustomStatusResponse?
The custom status set by the user
final
defaultGuildsRestricted bool
Whether new guilds have DM restrictions by default
final
defaultHideMutedChannels bool
Whether muted channels are hidden by default in new guilds
final
developerMode bool
Whether developer mode is enabled
final
friendSourceFlags FriendSourceFlags
final
gifAutoPlay bool
Whether GIFs auto-play in chat
final
groupDmAddPermissionFlags GroupDmAddPermissionFlags
final
guildFolders List<UserSettingsResponseGuildFolders>
The folder structure for organizing guilds in the sidebar
final
hashCode int
The hash code for this object.
no setterinherited
incomingCallFlags IncomingCallFlags
final
inlineAttachmentMedia bool
Whether to display attachments inline in chat
final
inlineEmbedMedia bool
Whether to display embed media inline in chat
final
locale Locale
final
messageDisplayCompact bool
Whether to use compact message display mode
final
renderEmbeds bool
Whether to render message embeds
final
renderReactions bool
Whether to display reactions on messages
final
renderSpoilers RenderSpoilers
Spoiler rendering preference setting
final
restrictedGuilds List<SnowflakeType>
Guild IDs where direct messages are restricted
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sensitiveContentFriendDmFilter SensitiveMediaFilterLevel
Sensitive media filter level for DMs from friends
final
sensitiveContentGuildFilter SensitiveMediaGuildFilterLevel
Sensitive media filter level for community channels
final
sensitiveContentNonFriendDmFilter SensitiveMediaFilterLevel
Sensitive media filter level for DMs from non-friends
final
staffDmAccessUserIds List<SnowflakeType>
User IDs with Staff DM Access enabled
final
status String
The current online status of the user
final
statusResetsAt DateTime?
ISO8601 timestamp of when the status will reset
final
statusResetsTo String?
The status to reset to after the scheduled reset
final
suppressUnprivilegedSelfMentions bool
Whether direct mentions and reply mentions from unprivileged users are suppressed
final
suppressUnprivilegedSelfMentionsBypassUserIds List<SnowflakeType>
User IDs that bypass self-mention suppression
final
syncedPreferences String
Account-wide client preferences as a base64-encoded protobuf snapshot. Empty string when nothing has been synced yet.
final
theme String
The UI theme preference
final
timeFormat TimeFormatTypes
The preferred time format setting
final
trustedDomains List<String>
List of trusted external link domains
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited