statusResetsTo property
The status to reset to after the scheduled reset
Implementation
@JsonKey(includeIfNull: false, name: 'status_resets_to')
final String? statusResetsTo;
The status to reset to after the scheduled reset
@JsonKey(includeIfNull: false, name: 'status_resets_to')
final String? statusResetsTo;