UserSettingsUpdateRequestGuildFolders class

Annotations
  • @JsonSerializable.new()

Properties

color Int32Type?
Color of the folder as integer
final
flags GuildFolderFlags?
final
guildIds List<SnowflakeType>
Guild IDs in this folder
final
hashCode int
The hash code for this object.
no setterinherited
icon UserSettingsUpdateRequestGuildFoldersIconIcon?
Selected icon for the guild folder
final
id int
Unique identifier for the folder (-1 for uncategorized)
final
name String?
Display name of the folder
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited