UserUpdateWithVerificationRequest class

Annotations
  • @JsonSerializable.new()

Constructors

UserUpdateWithVerificationRequest({UsernameType? username, DiscriminatorType? discriminator, String? globalName, EmailType? email, PasswordType? newPassword, PasswordType? password, Base64ImageType? avatar, Base64ImageType? banner, String? bio, String? pronouns, int? accentColor, String? timezone, int? timezonePrivacyFlags, bool? premiumBadgeHidden, bool? premiumBadgeMasked, bool? premiumBadgeTimestampHidden, bool? premiumBadgeSequenceHidden, bool? premiumEnabledOverride, bool? hasDismissedPremiumOnboarding, bool? hasUnreadGiftInventory, MentionReplyPreferences? mentionFlags, String? emailToken, UserUpdateWithVerificationRequestMfaMethodMfaMethod? mfaMethod, String? mfaCode, dynamic webauthnResponse, String? webauthnChallenge})
const
UserUpdateWithVerificationRequest.fromJson(Map<String, Object?> json)
factory

Properties

accentColor → int?
Profile accent color as integer
final
avatar → Base64ImageType?
Base64-encoded avatar image
final
Base64-encoded profile banner image
final
bio → Base64ImageType?
User biography text (max 320 characters)
final
discriminator → Base64ImageType?
final
email → Base64ImageType?
final
emailToken → Base64ImageType?
Email change token for updating email
final
globalName → Base64ImageType?
The display name shown to other users
final
hasDismissedPremiumOnboarding → bool?
Whether user dismissed premium onboarding
final
hashCode → int
The hash code for this object.
no setterinherited
hasUnreadGiftInventory → bool?
Whether user has unread gifts
final
mentionFlags → MentionReplyPreferences?
Account-wide reply mention preference (NO_PREFERENCE, PREFER_MENTION, PREFER_NO_MENTION)
final
mfaCode → Base64ImageType?
MFA verification code from an authenticator app
final
mfaMethod → UserUpdateWithVerificationRequestMfaMethodMfaMethod?
MFA method to use for verification
final
newPassword → Base64ImageType?
final
password → Base64ImageType?
final
premiumBadgeHidden → bool?
Whether to hide the premium badge
final
premiumBadgeMasked → bool?
Whether to mask the premium badge
final
premiumBadgeSequenceHidden → bool?
Whether to hide premium badge sequence
final
premiumBadgeTimestampHidden → bool?
Whether to hide premium badge timestamp
final
premiumEnabledOverride → bool?
Override premium enabled state
final
pronouns → Base64ImageType?
User pronouns (max 40 characters)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timezone → Base64ImageType?
Staff-only IANA timezone identifier saved for profile local time. Ignored for non-staff users.
final
timezonePrivacyFlags → int?
Staff-only bitfield controlling who can see the profile timezone. Ignored for non-staff users.
final
username → Base64ImageType?
final
webauthnChallenge → Base64ImageType?
WebAuthn challenge string
final
webauthnResponse → dynamic
WebAuthn authentication response
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited