VerifyAndCreateConnectionRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
- VerifyAndCreateConnectionRequest({required String initiationToken, Int32Type? visibilityFlags})
-
const
-
VerifyAndCreateConnectionRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- initiationToken → String
-
The signed initiation token returned from the create endpoint
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- visibilityFlags → Int32Type?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited