VoiceActivitySharingUpdateRequest class

Body for PUT /users/@me/settings/voice-activity-sharing. Mass-updates all friend relationships and starts a 24h cooldown.

Annotations
  • @JsonSerializable.new()

Constructors

VoiceActivitySharingUpdateRequest({required bool shareVoiceActivity})
const
VoiceActivitySharingUpdateRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shareVoiceActivity bool
New default for sharing voice activity with friends; also applied to every existing friend relationship
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited