VoiceDebugLoggingEventSchema class

Annotations
  • @JsonSerializable.new()

Constructors

VoiceDebugLoggingEventSchema({required String type, required String timestampNs, String? monotonicNs, Map<String, dynamic>? data})
const
VoiceDebugLoggingEventSchema.fromJson(Map<String, Object?> json)
factory

Properties

data → Map<String, dynamic>?
Event-specific diagnostic payload
final
hashCode → int
The hash code for this object.
no setterinherited
monotonicNs → String?
Client monotonic timestamp in nanoseconds
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestampNs → String
Client wall-clock Unix timestamp in nanoseconds
final
type → String
Client-side diagnostic event type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited