VoiceDebugLoggingEventsBodySchema class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
VoiceDebugLoggingEventsBodySchema({required String sessionId, required List<
VoiceDebugLoggingEventSchema> events, String? connectionId, String? participantIdentity}) -
const
-
VoiceDebugLoggingEventsBodySchema.fromJson(Map<
String, Object?> json) -
factory
Properties
- connectionId → String?
-
Client voice connection id
final
-
events
→ List<
VoiceDebugLoggingEventSchema> -
NDJSON batch events to store
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- participantIdentity → String?
-
LiveKit participant identity
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String
-
Active voice debug logging session id
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited