VoiceDebugLoggingEventsResponse class

Annotations
  • @JsonSerializable.new()

Constructors

VoiceDebugLoggingEventsResponse({required bool accepted, required bool active, required int storedEventCount})
const
VoiceDebugLoggingEventsResponse.fromJson(Map<String, Object?> json)
factory

Properties

accepted bool
Whether the telemetry batch was accepted for storage
final
active bool
Whether the server still considers this logging session active
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
storedEventCount int
Number of events written to diagnostics storage
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited