VoiceDebugLoggingStatusResponse class

Annotations
  • @JsonSerializable.new()

Constructors

VoiceDebugLoggingStatusResponse({required bool active, required String? sessionId, required SnowflakeType? activatedByUserId, required int? startedAtMs, required int? expiresAtMs, required int pollIntervalMs, required int uploadIntervalMs})
const
VoiceDebugLoggingStatusResponse.fromJson(Map<String, Object?> json)
factory

Properties

activatedByUserId → SnowflakeType?
Staff user that activated the session, if active
final
active → bool
Whether clients in this channel should currently send voice diagnostics
final
expiresAtMs → int?
Session expiration Unix timestamp in milliseconds
final
hashCode → int
The hash code for this object.
no setterinherited
pollIntervalMs → int
Recommended client polling interval in milliseconds
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sessionId → SnowflakeType?
Current debug logging session id, if active
final
startedAtMs → int?
Session start Unix timestamp in milliseconds
final
uploadIntervalMs → int
Recommended client telemetry batch upload interval in milliseconds
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited