WebAuthnMfaRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
- WebAuthnMfaRequest({required dynamic response, required String challenge, required String ticket})
-
const
-
WebAuthnMfaRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- challenge → String
-
The challenge string from authentication options
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- response → dynamic
-
WebAuthn authentication response
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ticket → String
-
The MFA ticket from the login response
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited