WebAuthnRegisterRequest class

Annotations
  • @JsonSerializable.new()

Constructors

WebAuthnRegisterRequest({required dynamic response, required String challenge, required String name})
const
WebAuthnRegisterRequest.fromJson(Map<String, Object?> json)
factory

Properties

challenge → String
The challenge from registration options
final
hashCode → int
The hash code for this object.
no setterinherited
name → String
User-assigned name for the credential
final
response → dynamic
WebAuthn registration response
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited