WebAuthnRegisterRequestMfaMethodMfaMethod enum

MFA method to use for verification

Inheritance
  • Object
  • Enum
  • WebAuthnRegisterRequestMfaMethodMfaMethod
Available extensions
Annotations
  • @JsonEnum.new()

Values

totp → const WebAuthnRegisterRequestMfaMethodMfaMethod
const WebAuthnRegisterRequestMfaMethodMfaMethod('totp')
webAuthn → const WebAuthnRegisterRequestMfaMethodMfaMethod
const WebAuthnRegisterRequestMfaMethodMfaMethod('webauthn')
$unknown → const WebAuthnRegisterRequestMfaMethodMfaMethod

Default value for all unparsed values, allows backward compatibility when adding new values on the backend.

const WebAuthnRegisterRequestMfaMethodMfaMethod(null)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
json String?
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

$valuesDefined List<WebAuthnRegisterRequestMfaMethodMfaMethod>
Returns all defined enum values excluding the $unknown value.
no setter

Constants

values → const List<WebAuthnRegisterRequestMfaMethodMfaMethod>
A constant List of the values in this enum, in order of their declaration.