WebhookAttachmentRequest class

Annotations
  • @JsonSerializable.new()

Constructors

WebhookAttachmentRequest({WebhookAttachmentRequestIdId? id, String? filename, String? description, String? contentType, int? size, String? url, String? proxyUrl, int? height, int? width, bool? ephemeral, num? duration, String? waveform, MessageAttachmentFlags? flags})
const
WebhookAttachmentRequest.fromJson(Map<String, Object?> json)
factory

Properties

contentType String?
MIME type of the file
final
description String?
Description for the attachment (max 4096 characters)
final
duration num?
Duration of audio file in seconds
final
ephemeral bool?
Whether this attachment is ephemeral
final
filename String?
Name of the file (1-1024 characters)
final
flags MessageAttachmentFlags?
final
hashCode int
The hash code for this object.
no setterinherited
height int?
Height of the image/video in pixels
final
id WebhookAttachmentRequestIdId?
Attachment ID for referencing uploaded files
final
proxyUrl String?
Proxied URL of the attachment
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int?
Size of the file in bytes
final
url String?
URL of the attachment
final
waveform String?
Base64-encoded bytearray of audio waveform
final
width int?
Width of the image/video in pixels
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited