WebhookCreateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

WebhookCreateRequest({required String name, Base64ImageType? avatar})
const
WebhookCreateRequest.fromJson(Map<String, Object?> json)
factory

Properties

avatar Base64ImageType?
The avatar image as a base64-encoded data URI
final
hashCode int
The hash code for this object.
no setterinherited
name String
The name of the webhook
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited