WebhookMessageEditRequest class

Annotations
  • @JsonSerializable.new()

Properties

allowedMentions → AllowedMentionsRequest?
Controls which mentions trigger notifications
final
content → MessageContentRequest?
The new message content (up to 4000 characters)
final
embeds → List<RichEmbedRequest>?
Array of embed objects to include in the message
final
flags → MessageFlags?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited