embeds property
Array of embed objects to include in the message
Implementation
@JsonKey(includeIfNull: false)
final List<RichEmbedRequest>? embeds;
Array of embed objects to include in the message
@JsonKey(includeIfNull: false)
final List<RichEmbedRequest>? embeds;