WebhookType enum
The type of webhook
Values
- incoming → const WebhookType
-
const WebhookType(1) - channelFollower → const WebhookType
-
const WebhookType(2) - $unknown → const WebhookType
-
Default value for all unparsed values, allows backward compatibility when adding new values on the backend.
const WebhookType(null)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- json → int?
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → int? -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
$valuesDefined
→ List<
WebhookType> -
Returns all defined enum values excluding the $unknown value.
no setter
Constants
-
values
→ const List<
WebhookType> - A constant List of the values in this enum, in order of their declaration.