ReportsApi class abstract

Annotations
  • @RestApi.new()

Constructors

ReportsApi(Dio dio, {String? baseUrl})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDsaReport({required DsaReportRequest body}) Future<ReportResponse>
Create DSA report.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
reportGuild({required ReportGuildRequest body}) Future<ReportResponse>
Report guild.
reportMessage({required ReportMessageRequest body}) Future<ReportResponse>
Report message.
reportUser({required ReportUserRequest body}) Future<ReportResponse>
Report user.
sendDsaReportEmail({required DsaReportEmailSendRequest body}) Future<OkResponse>
Send DSA report email.
toString() String
A string representation of this object.
inherited
verifyDsaReportEmail({required DsaReportEmailVerifyRequest body}) Future<TicketResponse>
Verify DSA report email.

Operators

operator ==(Object other) bool
The equality operator.
inherited