acceptOrUpdateFriendRequest abstract method

  1. @PUT.new('/users/@me/relationships/{user_id}')
Future<RelationshipResponse> acceptOrUpdateFriendRequest({
  1. @Path.new('user_id') required SnowflakeType userId,
  2. @Body.new() required RelationshipTypePutRequest body,
})

Accept or update friend request.

Accepts a pending incoming friend request from a user or updates the relationship type. Can also be used to change friend relationship to blocked status. Returns updated relationship object.

userId - The ID of the user.

body - Name not received - field will be skipped.

Implementation

@PUT('/users/@me/relationships/{user_id}')
Future<RelationshipResponse> acceptOrUpdateFriendRequest({
  @Path('user_id') required SnowflakeType userId,
  @Body() required RelationshipTypePutRequest body,
});