getLatestDataHarvest abstract method
- @GET.new('/users/@me/harvest/latest')
Get latest data harvest.
Retrieves the status of the most recent data harvest request. Returns null if no harvest has been requested yet. Shows progress and estimated completion time.
Implementation
@GET('/users/@me/harvest/latest')
Future<HarvestStatusResponseSchemaNullable> getLatestDataHarvest();