getNoteOnUser abstract method

  1. @GET.new('/users/@me/notes/{target_id}')
Future<UserNoteResponse> getNoteOnUser({
  1. @Path.new('target_id') required String targetId,
})

Get note on user.

Retrieves a specific note the current user has written about another user. Returns the note text and metadata. These are private notes visible only to the authenticated user.

targetId - The target id.

Implementation

@GET('/users/@me/notes/{target_id}')
Future<UserNoteResponse> getNoteOnUser({
  @Path('target_id') required String targetId,
});