listCurrentUserNotes abstract method

  1. @GET.new('/users/@me/notes')
Future<UserNotesRecordResponse> listCurrentUserNotes()

List current user notes.

Retrieves all notes the current user has written about other users. Returns a record of user IDs to notes. These are private notes visible only to the authenticated user.

Implementation

@GET('/users/@me/notes')
Future<UserNotesRecordResponse> listCurrentUserNotes();