listMobilePushDevices abstract method
List mobile push devices.
Lists mobile push device registrations for the current user.
Implementation
@GET('/users/@me/mobile-devices')
Future<MobileDevicesListResponse> listMobilePushDevices();
List mobile push devices.
Lists mobile push device registrations for the current user.
@GET('/users/@me/mobile-devices')
Future<MobileDevicesListResponse> listMobilePushDevices();