listUserGifts abstract method
List user gifts.
Lists all gift codes created by the authenticated user.
Implementation
@GET('/users/@me/gifts')
Future<List<GiftCodeMetadataResponse>> listUserGifts();
List user gifts.
Lists all gift codes created by the authenticated user.
@GET('/users/@me/gifts')
Future<List<GiftCodeMetadataResponse>> listUserGifts();