preloadMessagesForChannelsAlt abstract method

  1. @POST.new('/users/@me/channels/messages/preload')
Future<PreloadMessagesResponse> preloadMessagesForChannelsAlt({
  1. @Body.new() required PreloadMessagesRequest body,
})

Preload messages for channels (alternative).

Alternative endpoint to preload and cache messages for multiple channels to improve performance when opening those channels. Returns preloaded message data for the specified channels.

body - Name not received - field will be skipped.

Implementation

@POST('/users/@me/channels/messages/preload')
Future<PreloadMessagesResponse> preloadMessagesForChannelsAlt({
  @Body() required PreloadMessagesRequest body,
});