requestDataHarvest abstract method

  1. @POST.new('/users/@me/harvest')
Future<HarvestCreationResponseSchema> requestDataHarvest()

Request data harvest.

Requests a data harvest of all user data and content. Initiates an asynchronous process to compile and prepare all data for download in a portable format. Returns harvest ID and status.

Implementation

@POST('/users/@me/harvest')
Future<HarvestCreationResponseSchema> requestDataHarvest();