resendNewEmailConfirmation abstract method
- @POST.new('/users/@me/email-change/resend-new')
- @Body.new() required EmailChangeTicketRequest body,
Resend new email confirmation.
Resends a confirmation code to the new email address during the email change process. Use this if the new email confirmation was not received. Requires valid email change ticket.
body - Name not received - field will be skipped.
Implementation
@POST('/users/@me/email-change/resend-new')
Future<void> resendNewEmailConfirmation({
@Body() required EmailChangeTicketRequest body,
});