rotatePushSubscription abstract method

  1. @POST.new('/users/@me/push/rotate')
Future<PushSubscribeResponse> rotatePushSubscription({
  1. @Body.new() required PushRotateRequest body,
})

Rotate a push notification subscription.

Replaces an existing push subscription whose endpoint has been rotated by the browser (pushsubscriptionchange). Deletes the row keyed by the old endpoint and inserts a new one for the new endpoint.

body - Name not received - field will be skipped.

Implementation

@POST('/users/@me/push/rotate')
Future<PushSubscribeResponse> rotatePushSubscription({
  @Body() required PushRotateRequest body,
});