subscribeToPushNotifications abstract method
- @POST.new('/users/@me/push/subscribe')
- @Body.new() required PushSubscribeRequest body,
Subscribe to push notifications.
Registers a new push notification subscription for the current user. Takes push endpoint and encryption keys from a Web Push API subscription. Returns subscription ID for future reference.
body - Name not received - field will be skipped.
Implementation
@POST('/users/@me/push/subscribe')
Future<PushSubscribeResponse> subscribeToPushNotifications({
@Body() required PushSubscribeRequest body,
});