updateScheduledMessage abstract method
- @MultiPart.new()
- @PATCH.new('/users/@me/scheduled-messages/{scheduled_message_id}')
- @Path.new('scheduled_message_id') required String scheduledMessageId,
- @Part.new(name: 'scheduled_local_at') required String scheduledLocalAt,
- @Part.new(name: 'timezone') required String timezone,
- @Part.new(name: 'content') MessageContentRequest? content,
- @Part.new(name: 'embeds') List<
RichEmbedRequest> ? embeds, - @Part.new(name: 'attachments') List<
Object3> ? attachments, - @Part.new(name: 'message_reference') MessageReferenceRequest? messageReference,
- @Part.new(name: 'allowed_mentions') AllowedMentionsRequest? allowedMentions,
- @Part.new(name: 'flags') MessageFlags? flags,
- @Part.new(name: 'nonce') MessageNonceRequest? nonce,
- @Part.new(name: 'favorite_meme_id') SnowflakeType? favoriteMemeId,
- @Part.new(name: 'sticker_ids') List<
SnowflakeType> ? stickerIds, - @Part.new(name: 'tts') bool? tts,
Update scheduled message.
Updates an existing scheduled message before it is sent. Can modify message content, scheduled time, and timezone. Returns updated scheduled message details.
scheduledMessageId - The scheduled message id.
content - Name not received - field will be skipped.
Name not received - field will be skipped.
embeds - Array of embed objects to include in the message.
Name not received - field will be skipped.
attachments - Array of attachment objects.
Name not received - field will be skipped.
messageReference - Name not received - field will be skipped.
Name not received - field will be skipped.
allowedMentions - Name not received - field will be skipped.
Name not received - field will be skipped.
flags - Name not received - field will be skipped.
nonce - Name not received - field will be skipped.
favoriteMemeId - Name not received - field will be skipped.
Name not received - field will be skipped.
stickerIds - Name not received - field will be skipped.
Name not received - field will be skipped.
tts - Whether this is a text-to-speech message.
Name not received - field will be skipped.
scheduledLocalAt - ISO 8601 timestamp expressed in the user local timezone for when the message should be delivered.
Name not received - field will be skipped.
timezone - IANA timezone identifier the schedule_local_at value is anchored to.
Name not received - field will be skipped.
Implementation
@MultiPart()
@PATCH('/users/@me/scheduled-messages/{scheduled_message_id}')
Future<ScheduledMessageResponseSchema> updateScheduledMessage({
@Path('scheduled_message_id') required String scheduledMessageId,
@Part(name: 'scheduled_local_at') required String scheduledLocalAt,
@Part(name: 'timezone') required String timezone,
@Part(name: 'content') MessageContentRequest? content,
@Part(name: 'embeds') List<RichEmbedRequest>? embeds,
@Part(name: 'attachments') List<Object3>? attachments,
@Part(name: 'message_reference') MessageReferenceRequest? messageReference,
@Part(name: 'allowed_mentions') AllowedMentionsRequest? allowedMentions,
@Part(name: 'flags') MessageFlags? flags,
@Part(name: 'nonce') MessageNonceRequest? nonce,
@Part(name: 'favorite_meme_id') SnowflakeType? favoriteMemeId,
@Part(name: 'sticker_ids') List<SnowflakeType>? stickerIds,
@Part(name: 'tts') bool? tts,
});