verifyNewEmailAddress abstract method
- @POST.new('/users/@me/email-change/verify-new')
- @Body.new() required EmailChangeVerifyNewRequest body,
Verify new email address.
Completes the email change process by verifying the new email address with a confirmation code. Returns an email token that confirms the email change. After this step, the user may need to re-authenticate.
body - Name not received - field will be skipped.
Implementation
@POST('/users/@me/email-change/verify-new')
Future<EmailTokenResponse> verifyNewEmailAddress({
@Body() required EmailChangeVerifyNewRequest body,
});