WebhooksApi class abstract

Annotations
  • @RestApi.new()

Constructors

WebhooksApi(Dio dio, {String? baseUrl})
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

createWebhook({required SnowflakeType channelId, required WebhookCreateRequest body}) Future<WebhookResponse>
Create webhook.
deleteWebhook({required SnowflakeType webhookId}) Future<void>
Delete webhook.
deleteWebhookMessage({required SnowflakeType webhookId, required String token, required SnowflakeType messageId}) Future<void>
Delete webhook message.
deleteWebhookWithToken({required SnowflakeType webhookId, required String token}) Future<void>
Delete webhook with token.
editWebhookMessage({required SnowflakeType webhookId, required String token, required SnowflakeType messageId, required WebhookMessageEditRequest body}) Future<MessageResponseSchema>
Edit webhook message.
executeGithubWebhook({required SnowflakeType webhookId, required String token, required GitHubWebhook body}) Future<void>
Execute GitHub webhook.
executeSlackWebhook({required SnowflakeType webhookId, required String token, required SlackWebhookRequest body}) Future<String>
Execute Slack webhook.
executeWebhook({required SnowflakeType webhookId, required String token, String? wait, MessageContentRequest? content, List<RichEmbedRequest>? embeds, List<WebhookAttachmentRequest>? attachments, MessageReferenceRequest? messageReference, AllowedMentionsRequest? allowedMentions, MessageFlags? flags, MessageNonceRequest? nonce, SnowflakeType? favoriteMemeId, List<SnowflakeType>? stickerIds, bool? tts, String? username, String? avatarUrl}) Future<MessageResponseSchema>
Execute webhook.
getWebhook({required SnowflakeType webhookId}) Future<WebhookResponse>
Get webhook.
getWebhookMessage({required SnowflakeType webhookId, required String token, required SnowflakeType messageId}) Future<MessageResponseSchema>
Get webhook message.
getWebhookWithToken({required SnowflakeType webhookId, required String token}) Future<WebhookTokenResponse>
Get webhook with token.
listChannelWebhooks({required SnowflakeType channelId}) Future<List<WebhookResponse>>
List channel webhooks.
listGuildWebhooks({required SnowflakeType guildId}) Future<List<WebhookResponse>>
List guild webhooks.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateWebhook({required SnowflakeType webhookId, required WebhookUpdateRequest body}) Future<WebhookResponse>
Update webhook.
updateWebhookWithToken({required SnowflakeType webhookId, required String token, required WebhookTokenUpdateRequest body}) Future<WebhookTokenResponse>
Update webhook with token.

Operators

operator ==(Object other) bool
The equality operator.
inherited