sendSystemDm abstract method

  1. @POST.new('/admin/system-dm/send')
Future<SendSystemDmResponse> sendSystemDm({
  1. @Body.new() required SendSystemDmRequest body,
})

Send system DM.

Queue a worker job that sends the same system DM content to each provided user ID. Progress is observable via the Jobs admin page (task_type=sendSystemDm). Requires SYSTEM_DM_SEND permission.

body - Name not received - field will be skipped.

Implementation

@POST('/admin/system-dm/send')
Future<SendSystemDmResponse> sendSystemDm({
  @Body() required SendSystemDmRequest body,
});