setLegalHoldOnEvidence abstract method

  1. @POST.new('/admin/reports/{report_id}/legal-hold')
Future<LegalHoldResponse> setLegalHoldOnEvidence({
  1. @Path.new('report_id') required String reportId,
  2. @Body.new() required LegalHoldRequest body,
})

Set legal hold on evidence.

Place a legal hold on report evidence to prevent automatic deletion. Used for compliance with legal investigations or regulatory requirements. Optionally specify an expiration date.

reportId - The report id.

body - Name not received - field will be skipped.

Implementation

@POST('/admin/reports/{report_id}/legal-hold')
Future<LegalHoldResponse> setLegalHoldOnEvidence({
  @Path('report_id') required String reportId,
  @Body() required LegalHoldRequest body,
});