logoutUser abstract method
Logout account.
Invalidate the current authentication token and end the session. The auth token in the Authorization header will no longer be valid.
Implementation
@POST('/auth/logout')
Future<void> logoutUser();
Logout account.
Invalidate the current authentication token and end the session. The auth token in the Authorization header will no longer be valid.
@POST('/auth/logout')
Future<void> logoutUser();