resendVerificationEmail abstract method
Resend verification email.
Request a new email verification code to be sent. Requires authentication. Use this if the original verification email was lost or expired.
Implementation
@POST('/auth/verify/resend')
Future<void> resendVerificationEmail();