export library
Classes
- AllowedMentionsRequest
- ApplicationCreateRequest
- ApplicationPublicResponse
- ApplicationPublicResponseBot
- ApplicationResponse
- ApplicationResponseBot
- ApplicationsMeResponse
- ApplicationsMeResponseBot
- ApplicationsMeResponseOwner
- ApplicationUpdateRequest
- AuditLogChangeSchema
- AuditLogWebhookResponse
- AuthApi
- AuthLoginResponse
- AuthLoginResponseAuthTokenWithUserIdResponse
- AuthLoginResponseVariant2
- AuthorizationCodeTokenRequest
- AuthorizeConsentRequest
- AuthorizeIpRequest
- AuthRegisterResponse
- AuthRegisterResponseAuthRegistrationPendingApprovalResponse
- AuthRegisterResponseAuthTokenWithUserIdResponse
- AuthRegisterResponseVariant2
- AuthRegistrationPendingApprovalResponse
- AuthSessionLocation
- AuthSessionResponse
- AuthSessionResponseClientInfo
- AuthTokenWithUserIdResponse
- AuthTokenWithUserIdResponseUser
- BillingApi
- BlueskyAuthorizeRequest
- BlueskyAuthorizeResponse
- BotProfileResponse
- BotProfileUpdateRequest
- BotTokenResetResponse
- BotTokenResetResponseBot
- BulkDeleteMessagesRequest
- BulkDeleteSelfMessagesRequest
- BulkIgnoreFriendRequestsRequest
- BulkIgnoreFriendRequestsResponse
- BulkMessageFetchRequest
- BulkMessageFetchRequestRequests
- BulkMessageFetchResponse
- BulkMessageFetchResponseChannels
- CallEligibilityResponse
- CallRingBodySchema
- CallUpdateBodySchema
- ChangeSubscriptionRequest
- ChannelCreateRequest
- ChannelCreateRequest0
- ChannelCreateRequest2
- ChannelCreateRequest4
- ChannelCreateRequest998
- ChannelInviteCreateRequest
- ChannelOverrides
- ChannelOverridesMuteConfig
- ChannelOverwriteResponse
- ChannelPartialResponse
- ChannelPartialResponseRecipients
- ChannelPinResponse
- ChannelPinResponseMessage
- ChannelPinResponseMessageCall
- ChannelPinResponseMessageMessageReference
- ChannelPinsResponse
- ChannelPositionUpdateRequestItem
- ChannelResponse
- ChannelsApi
- ChannelSlowmodeStateResponse
- ChannelUpdateRequest
- ChannelUpdateRequest0
- ChannelUpdateRequest2
- ChannelUpdateRequest3
- ChannelUpdateRequest4
- ChannelUpdateRequest998
- ClientAttachmentReferenceRequest
- ClientAttachmentRequest
- ClientUploadedAttachmentRequest
- CompleteMultipartAttachmentUploadItem
- CompleteMultipartAttachmentUploadRequest
- CompleteMultipartAttachmentUploadResponse
- CompleteMultipartAttachmentUploadResult
- ConnectionResponse
- ConnectionsApi
- ConnectionVerificationResponse
- CreateCheckoutSessionRequest
- CreateConnectionRequest
- CreateFavoriteMemeBodySchema
- CreateFavoriteMemeFromUrlBodySchema
- CreatePrivateChannelRequest
- CurrentSubscriptionPriceResponse
- CurrentSubscriptionPriceResponseVariant1
- CustomStatusPayload
- CustomStatusResponse
- DebugApi
- DisableTotpRequest
- DiscoveryApi
- DiscoveryApplicationPatchRequest
- DiscoveryApplicationRequest
- DiscoveryApplicationResponse
- DiscoveryCategoryResponse
- DiscoveryGuildListResponse
- DiscoveryGuildListResponseGuilds
- DiscoveryStatusResponse
- DonationCheckoutRequest
- DonationCheckoutResponse
- DonationRequestLinkRequest
- DonationsApi
- DsaReportEmailSendRequest
- DsaReportEmailVerifyRequest
- DsaReportRequest
- DsaReportRequestGuild
- DsaReportRequestMessage
- DsaReportRequestUser
- EmailChangeApplyRequest
- EmailChangeBouncedRequestNewRequest
- EmailChangeBouncedVerifyNewRequest
- EmailChangeRequestNewRequest
- EmailChangeRequestNewResponse
- EmailChangeStartResponse
- EmailChangeTicketRequest
- EmailChangeVerifyNewRequest
- EmailChangeVerifyOriginalRequest
- EmailChangeVerifyOriginalResponse
- EmailRevertRequest
- EmailTokenResponse
- EmbedAuthorResponse
- EmbedFieldResponse
- EmbedMediaResponse
- EmojisApi
- EmptyBodyRequest
- EnableMfaTotpRequest
- EntranceSoundLibraryResponse
- EntranceSoundLibraryResponseSelections
- EntranceSoundPlayRequest
- EntranceSoundRenameRequest
- EntranceSoundResponse
- EntranceSoundSelectionRequest
- EntranceSoundUploadRequest
- Error
- ExpiredLocalizedCardPreapprovalContinueResponse
- FavoriteMemeResponse
- FluxerClient
-
Fluxer API
v1.0.0. - ForgotPasswordRequest
- FriendRequestByTagRequest
- FriendRequestCreateRequest
- GatewayApi
- GatewayBotResponse
- GatewayBotResponseSessionStartLimit
- GifMediaFormat
- GiftCodeMetadataResponse
- GiftCodeResponse
- GiftsApi
- GitHubWebhook
- GitHubWebhookAnswer
- GitHubWebhookAnswerUser
- GitHubWebhookCheckRun
- GitHubWebhookCheckRunCheckSuite
- GitHubWebhookCheckRunCheckSuiteApp
- GitHubWebhookCheckRunCheckSuitePullRequests
- GitHubWebhookCheckRunOutput
- GitHubWebhookCheckRunPullRequests
- GitHubWebhookCheckSuite
- GitHubWebhookCheckSuiteApp
- GitHubWebhookCheckSuitePullRequests
- GitHubWebhookComment
- GitHubWebhookCommentUser
- GitHubWebhookCommits
- GitHubWebhookCommitsAuthor
- GitHubWebhookDiscussion
- GitHubWebhookDiscussionUser
- GitHubWebhookForkee
- GitHubWebhookHeadCommit
- GitHubWebhookHeadCommitAuthor
- GitHubWebhookIssue
- GitHubWebhookIssueUser
- GitHubWebhookMember
- GitHubWebhookPullRequest
- GitHubWebhookPullRequestUser
- GitHubWebhookRelease
- GitHubWebhookRepository
- GitHubWebhookReview
- GitHubWebhookReviewUser
- GitHubWebhookSender
- GlobalSearchMessagesRequest
- GroupDmChannelUpdateRequest
- GroupDmInviteMetadataResponse
- GroupDmInviteResponse
- GuildAuditLogEntryResponse
- GuildAuditLogEntryResponseOptions
- GuildAuditLogListResponse
- GuildBanCreateRequest
- GuildBanResponse
- GuildCategoryChannelCreateRequest
- GuildCategoryChannelCreateRequestPermissionOverwrites
- GuildCategoryChannelUpdateRequest
- GuildCategoryChannelUpdateRequestPermissionOverwrites
- GuildCreateRequest
- GuildDeleteRequest
- GuildDsaReportRequest
- GuildEmojiBulkCreateRequest
- GuildEmojiBulkCreateResponse
- GuildEmojiBulkCreateResponseFailed
- GuildEmojiCloneRequest
- GuildEmojiCreateRequest
- GuildEmojiMetadataResponse
- GuildEmojiResponse
- GuildEmojiUpdateRequest
- GuildEmojiWithUserResponse
- GuildInviteMetadataResponse
- GuildInviteMetadataResponseGuild
- GuildInviteResponse
- GuildInviteResponseGuild
- GuildLinkChannelCreateRequest
- GuildLinkChannelCreateRequestPermissionOverwrites
- GuildLinkChannelUpdateRequest
- GuildLinkChannelUpdateRequestPermissionOverwrites
- GuildMemberResponse
- GuildMemberSearchRequest
- GuildMemberSearchResponse
- GuildMemberSearchResult
- GuildMemberSearchResultSupplemental
- GuildMemberUpdateRequest
- GuildResponse
- GuildRoleCreateRequest
- GuildRoleHoistPositionsRequestItem
- GuildRolePositionsRequestItem
- GuildRoleResponse
- GuildRoleUpdateRequest
- GuildsApi
- GuildStickerBulkCreateRequest
- GuildStickerBulkCreateResponse
- GuildStickerBulkCreateResponseFailed
- GuildStickerCloneRequest
- GuildStickerCreateRequest
- GuildStickerMetadataResponse
- GuildStickerResponse
- GuildStickerUpdateRequest
- GuildStickerWithUserResponse
- GuildTextChannelCreateRequest
- GuildTextChannelCreateRequestPermissionOverwrites
- GuildTextChannelUpdateRequest
- GuildTextChannelUpdateRequestPermissionOverwrites
- GuildTransferOwnershipRequest
- GuildUpdateRequest
- GuildVanityUrlResponse
- GuildVanityUrlUpdateRequest
- GuildVanityUrlUpdateResponse
- GuildVoiceChannelCreateRequest
- GuildVoiceChannelCreateRequestPermissionOverwrites
- GuildVoiceChannelUpdateRequest
- GuildVoiceChannelUpdateRequestPermissionOverwrites
- HandoffCompleteRequest
- HandoffInfoResponse
- HandoffInfoResponseClientInfo
- HandoffInitiateResponse
- HandoffStatusResponse
- HarvestCreationResponseSchema
- HarvestDownloadUrlResponse
- HarvestSelfDataRequest
- HarvestStatusResponseSchema
- HarvestStatusResponseSchemaNullable
- HarvestStatusResponseSchemaNullableHarvestStatusResponseSchema
- InboundSmsChallengeStartResponse
- InstanceApi
- InstatusWebhook
- InstatusWebhookComponent
- InstatusWebhookComponentUpdate
- InstatusWebhookIncident
- InstatusWebhookIncidentAffectedComponents
- InstatusWebhookIncidentIncidentUpdates
- InstatusWebhookMaintenance
- InstatusWebhookMaintenanceAffectedComponents
- InstatusWebhookMaintenanceMaintenanceUpdates
- InstatusWebhookMeta
- InstatusWebhookPage
- InviteMetadataResponseSchema
- InviteMetadataResponseSchemaGroupDmInviteMetadataResponse
- InviteMetadataResponseSchemaGuildInviteMetadataResponse
- InviteMetadataResponseSchemaPackInviteMetadataResponse
- InviteResponseSchema
- InviteResponseSchemaGroupDmInviteResponse
- InviteResponseSchemaGuildInviteResponse
- InviteResponseSchemaPackInviteResponse
- InvitesApi
- IpAuthorizationPollResponse
- LocalizedCardPreapprovalContinueRequest
- LocalizedCardPreapprovalContinueResponse
- LocalizedCardPreapprovalContinueResponseExpired
- LocalizedCardPreapprovalContinueResponsePending
- LocalizedCardPreapprovalContinueResponseReady
- LocalizedCardPreapprovalContinueResponseRejected
- LoginRequest
- LogoutAuthSessionsRequest
- MarkMentionsReadRequest
- MessageAckRequest
- MessageAttachmentResponse
- MessageChannelMentionResponse
- MessageDsaReportRequest
- MessageEmbedChildResponse
- MessageEmbedResponse
- MessageReactionResponse
- MessageReactionResponseEmoji
- MessageReferenceRequest
- MessageResponseSchema
- MessageResponseSchemaCall
- MessageResponseSchemaMessageReference
- MessageResponseSchemaReferencedMessage
- MessageResponseSchemaReferencedMessageCall
- MessageResponseSchemaReferencedMessageMessageReference
- MessageSearchResponse
- MessageSearchResponseMessageSearchResultsResponse
- MessageSearchResponseVariant2
- MessageSearchResultsResponse
- MessageSearchResultsResponseMessages
- MessageSearchResultsResponseMessagesCall
- MessageSearchResultsResponseMessagesMessageReference
- MessageSnapshotResponse
- MessageStickerResponse
- MfaBackupCodesRequest
- MfaBackupCodesResponse
- MfaBackupCodesResponseBackupCodes
- MfaTicketRequest
- MfaTotpRequest
- MobileDevicesListResponse
- MobileDevicesListResponseDevices
- MultipartPresignedAttachmentUploadResponseItem
- MultipartPresignedAttachmentUploadResponseItemParts
- MyGuildMemberUpdateRequest
- OAuth2Api
- OAuth2ApplicationsMeResponse
- OAuth2ApplicationsMeResponseApplicationListResponse
- OAuth2ApplicationsMeResponseApplicationsMeResponse
- OAuth2AuthorizationResponse
- OAuth2AuthorizationResponseApplication
- OAuth2AuthorizationsBulkRevokeRequest
- OAuth2ConsentResponse
- OAuth2IntrospectResponse
- OAuth2MeResponse
- OAuth2MeResponseApplication
- OAuth2MeResponseUser
- OAuth2TokenResponse
- OAuth2UserInfoResponse
- Object0
- Name not received and was auto-generated.
- Object0ClientAttachmentRequest
- Object0ClientUploadedAttachmentRequest
- Object1
- Name not received and was auto-generated.
- Object1ClientAttachmentRequest
- Object1ClientUploadedAttachmentRequest
- Object2
- Name not received and was auto-generated.
- Object2ClientAttachmentReferenceRequest
- Object2ClientUploadedAttachmentRequest
- Object3
- Object3Attachments
- Object4
- Name not received and was auto-generated.
- Object4ClientAttachmentRequest
- Object4ClientUploadedAttachmentRequest
- Object5
- OkResponse
- PackCreateRequest
- PackDashboardResponse
- PackDashboardResponseEmoji
- PackDashboardResponseSticker
- PackInviteCreateRequest
- PackInviteMetadataResponse
- PackInviteMetadataResponsePack
- PackInviteResponse
- PackInviteResponsePack
- PacksApi
- PackSummaryResponse
- PackUpdateRequest
- PasswordChangeCompleteRequest
- PasswordChangeCompleteResponse
- PasswordChangeStartResponse
- PasswordChangeTicketRequest
- PasswordChangeVerifyRequest
- PasswordChangeVerifyResponse
- PendingLocalizedCardPreapprovalContinueResponse
- PendingSubscriptionChangeResponse
- PendingSubscriptionChangeResponseVariant1
- PermissionOverwriteCreateRequest
- PhoneSendVerificationRequest
- PhoneSendVerificationResponse
- PhoneSendVerificationResponseInboundChallenge
- PhoneSendVerificationResponseSms
- PhoneVerifyRequest
- PhoneVerifyResponse
- PreloadMessagesRequest
- PremiumApi
- PremiumBillingInvoiceResponse
- PremiumBillingPaymentMethodResponse
- PremiumBillingSubscriptionResponse
- PremiumPricingState
- PremiumStateResponse
- PremiumStateResponseActual
- PremiumStateResponseBilling
- PremiumStateResponseEffective
- PresignedAttachmentUploadRequest
- PresignedAttachmentUploadRequestItem
- PresignedAttachmentUploadResponse
- PresignedAttachmentUploadResponseItem
- PresignedAttachmentUploadResponseItemMultipart
- PresignedAttachmentUploadResponseItemSinglepart
- PriceIdsResponse
- PurgePersonalNotesMessagesResponse
- PushRotateRequest
- PushRotateRequestKeys
- PushSubscribeRequest
- PushSubscribeRequestKeys
- PushSubscribeResponse
- PushSubscriptionsListResponse
- PushSubscriptionsListResponseSubscriptions
- ReactionUsersPageResponse
- ReadStateAckBulkRequest
- ReadStateAckBulkRequestReadStates
- ReadStateAckRequest
- ReadStateAckRequestReadStates
- ReadStateAckResponse
- ReadStateResponse
- ReadStatesApi
- ReadyLocalizedCardPreapprovalContinueResponse
- RefreshTokenTokenRequest
- RegisterMobileDeviceRequest
- RegisterMobileDeviceResponse
- RegisterRequest
- RejectedLocalizedCardPreapprovalContinueResponse
- RelationshipNicknameUpdateRequest
- RelationshipResponse
- RelationshipTypePutRequest
- ReorderConnectionsRequest
- ReportGuildRequest
- ReportMessageRequest
- ReportResponse
- ReportsApi
- ReportUserRequest
- ResetPasswordRequest
- ResolvedGifEntrySchema
- ResolveGifUrlsBodySchema
- ResolveGifUrlsResponse
- RichEmbedAuthorRequest
- RichEmbedAuthorRequestVariant1
- RichEmbedMediaRequest
- RichEmbedMediaRequestRichEmbedMediaRequestShape
- RichEmbedMediaRequestShape
- RichEmbedRequest
- RichEmbedRequestFields
- RtcRegionResponse
- SavedMediaApi
- SavedMessageEntryResponse
- SaveMessageRequest
- ScheduledMessageResponseSchema
- ScheduledMessageResponseSchemaPayload
- ScheduledMessageResponseSchemaPayloadAllowedMentions
- ScheduledMessageResponseSchemaPayloadMessageReference
- SearchApi
- SelfServeRefundEligibilityResponse
- SelfServeRefundResponse
- SinglepartPresignedAttachmentUploadResponseItem
- SlackWebhookRequest
- SlackWebhookRequestAttachments
- SlackWebhookRequestAttachmentsFields
- SsoCompleteRequest
- SsoCompleteResponse
- SsoCompleteResponseUser
- SsoStartRequest
- SsoStartResponse
- SsoStatusResponse
- StickersApi
- StreamPreviewUploadBodySchema
- StreamPreviewUploadUrlBodySchema
- StreamPreviewUploadUrlResponseSchema
- StreamUpdateBodySchema
- SuccessResponse
- SudoMfaMethodsResponse
- SudoVerificationSchema
- TemplateChannel
- TemplateChannelPermissionOverwrites
- TemplateRole
- TemplateSerializedGuild
- ThemeCreateRequest
- ThemeCreateResponse
- ThemesApi
- TicketResponse
- UnfurlRequest
- UnregisterMobileDeviceRequest
- UpdateConnectionRequest
- UpdateFavoriteMemeBodySchema
- UpdatePremiumPerksDisabledRequest
- UrlResponse
- UserDsaReportRequest
- UserGuildSettingsResponse
- UserGuildSettingsResponseMuteConfig
- UserGuildSettingsUpdateRequest
- UserGuildSettingsUpdateRequestMuteConfig
- UsernameSuggestionsRequest
- UsernameSuggestionsResponse
- UserNoteResponse
- UserNoteUpdateRequest
- UserPartialResponse
- UserPrivateResponse
- UserPrivateResponsePendingBulkMessageDeletion
- UserProfileFullResponse
- UserProfileFullResponseGuildMemberProfile
- UserProfileFullResponseMutualGuilds
- UserProfileFullResponseUser
- UserProfileFullResponseUserProfile
- UsersApi
- UserSettingsResponse
- UserSettingsResponseGuildFolders
- UserSettingsUpdateRequest
- UserSettingsUpdateRequestGuildFolders
- UserTagCheckResponse
- UserUpdateWithVerificationRequest
- ValidateResetPasswordTokenResponse
- ValidationErrorItem
- VerifyAndCreateConnectionRequest
- VerifyEmailRequest
- VoiceActivitySharingUpdateRequest
- Body for PUT /users/@me/settings/voice-activity-sharing. Mass-updates all friend relationships and starts a 24h cooldown.
- VoiceApi
- VoiceDebugLoggingEventsBodySchema
- VoiceDebugLoggingEventSchema
- VoiceDebugLoggingEventsResponse
- VoiceDebugLoggingStatusResponse
- VoiceDebugLoggingToggleBodySchema
- VoicePresenceHeartbeatBodySchema
- VoicePresenceHeartbeatEndResponse
- VoicePresenceHeartbeatResponse
- WebAuthnAuthenticateRequest
- WebAuthnChallengeResponse
- WebAuthnCredentialResponse
- WebAuthnCredentialUpdateRequest
- WebAuthnMfaRequest
- WebAuthnRegisterRequest
- WebhookCreateRequest
- WebhookMessageEditRequest
- WebhookReceivedResponse
- WebhookResponse
- WebhooksApi
- WebhookTokenResponse
- WebhookTokenUpdateRequest
- WebhookUpdateRequest
- WellKnownFluxerResponse
- WellKnownFluxerResponseAppPublic
- WellKnownFluxerResponseAppPublicBranding
- WellKnownFluxerResponseAppPublicLegal
- WellKnownFluxerResponseAppPublicRegistration
- WellKnownFluxerResponseAppPublicSetup
- WellKnownFluxerResponseCaptcha
- WellKnownFluxerResponseCommunity
- WellKnownFluxerResponseEndpoints
- WellKnownFluxerResponseFeatures
- WellKnownFluxerResponseGif
- WellKnownFluxerResponseLimits
- WellKnownFluxerResponseLimitsRules
- WellKnownFluxerResponseLimitsRulesFilters
- WellKnownFluxerResponsePush
- WellKnownFluxerResponseRegistration
- WellKnownFluxerResponseServices
- WellKnownFluxerResponseSso
Enums
- AllowedMentionsRequestParseParse
- Types of mentions to parse from content
- ApiErrorCode
- Error codes returned by API operations
- AuditLogActionType
- The type of action that occurred
- AuthenticatorType
- The type of authenticator
- AuthLoginResponseVariant2MfaMfa
- Indicates MFA is required to complete authentication
- AuthorizationCodeTokenRequestGrantTypeGrantType
- The grant type for exchanging an authorization code
- AuthorizeConsentRequestCodeChallengeMethodCodeChallengeMethod
- The PKCE code challenge method
- AuthRegisterResponseVariant2MfaMfa
- Indicates MFA is required to complete authentication
- AuthRegistrationPendingApprovalResponseRegistrationPendingApprovalRegistrationPendingApproval
- Registration succeeded and is waiting for admin approval
- BulkDeleteSelfMessagesRequestGuildFilterModeGuildFilterMode
- How the guild filter list is interpreted when include_guilds is true.
- BulkDeleteSelfMessagesRequestMfaMethodMfaMethod
- MFA method to use for verification
- BulkDeleteSelfMessagesRequestScopeScope
- Which set of contexts the deletion targets
- BulkIgnoreFriendRequestsRequestFilterFilter
- ChangeSubscriptionRequestBillingCycleBillingCycle
- The recurring billing cycle to switch the active subscription to
- ChangeSubscriptionRequestEffectiveAtEffectiveAt
- When the billing cycle change should take effect
- ChannelOverwriteResponseTypeType
- The type of entity the overwrite applies to
- ChannelPinResponseMessageTypeType
- The type of message
- CheckoutPaymentMethodEnum
- ConnectionResponseTypeType
- The type of connection
- ConnectionVerificationResponseTypeType
- The type of connection being verified
- ContentWarningLevel
- The content warning level for a guild, category, or channel
- CreateConnectionRequestTypeType
- The type of connection to create
- CurrentSubscriptionPriceResponseVariant1BillingCycleBillingCycle
- The recurring billing cycle of the active subscription
- CurrentSubscriptionPriceResponseVariant1CurrencyCurrency
- Currency of the charged amount
- DefaultMessageNotifications
- Default notification level for new members
- DisableTotpRequestMfaMethodMfaMethod
- MFA method to use for verification
- DonationCheckoutRequestCurrencyCurrency
- Currency for the donation
- DonationCheckoutRequestIntervalInterval
- EmailChangeApplyRequestMfaMethodMfaMethod
- MFA method to use for verification
- EnableMfaTotpRequestMfaMethodMfaMethod
- MFA method to use for verification
- EntranceSoundResponseExtensionExtensionEnum
-
The name has been replaced because it contains a keyword. Original name:
extension. - Enum0
- A hint about the type of token being revoked. Name not received and was auto-generated.
- ExpiredLocalizedCardPreapprovalContinueResponseStatusStatus
- The preapproval token has expired or is unknown
- GiftCodeMetadataResponseDurationTypeDurationType
- Duration unit for the gift entitlement
- GiftCodeResponseDurationTypeDurationType
- Duration unit for the gift entitlement
- GlobalSearchMessagesRequestAuthorTypeAuthorType
- The type of author who sent the message
- GlobalSearchMessagesRequestEmbedTypeEmbedType
- The type of generated or supplied embed content, not uploaded attachments
- GlobalSearchMessagesRequestExcludeAuthorTypeExcludeAuthorType
- The type of author who sent the message
- GlobalSearchMessagesRequestExcludeEmbedTypeExcludeEmbedType
- The type of generated or supplied embed content, not uploaded attachments
- GlobalSearchMessagesRequestExcludeHasExcludeHas
- The type of content contained in a message. Upload filters inspect attachments; embed filters inspect generated or supplied message embeds.
- GlobalSearchMessagesRequestHasHas
- The type of content contained in a message. Upload filters inspect attachments; embed filters inspect generated or supplied message embeds.
- GlobalSearchMessagesRequestScopeScope
- Scope to search within when querying messages
- GlobalSearchMessagesRequestSortBySortBy
- Field to sort results by
- GlobalSearchMessagesRequestSortOrderSortOrder
- Sort order for results
- GroupDmChannelUpdateRequestTypeType
- GroupDmInviteMetadataResponseTypeType
- The type of invite (group DM)
- GroupDmInviteResponseTypeType
- The type of invite (group DM)
- GuildCategoryChannelCreateRequestPermissionOverwritesTypeType
- The type of overwrite (0 = role, 1 = member)
- GuildCategoryChannelCreateRequestTypeType
- GuildCategoryChannelUpdateRequestPermissionOverwritesTypeType
- The type of overwrite (0 = role, 1 = member)
- GuildCategoryChannelUpdateRequestTypeType
- GuildDeleteRequestMfaMethodMfaMethod
- MFA method to use for verification
- GuildDsaReportRequestCategoryCategory
- Category of the guild report
- GuildDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence
- EU country code of the reporter residence
- GuildDsaReportRequestReportTypeReportType
- Type of report
- GuildExplicitContentFilter
- Level of content filtering for explicit media
- GuildInviteMetadataResponseGuildSplashCardAlignmentSplashCardAlignment
- The alignment of the splash card
- GuildInviteMetadataResponseTypeType
- The type of invite (guild)
- GuildInviteResponseGuildSplashCardAlignmentSplashCardAlignment
- The alignment of the splash card
- GuildInviteResponseTypeType
- The type of invite (guild)
- GuildLinkChannelCreateRequestPermissionOverwritesTypeType
- The type of overwrite (0 = role, 1 = member)
- GuildLinkChannelCreateRequestTypeType
- GuildLinkChannelUpdateRequestPermissionOverwritesTypeType
- The type of overwrite (0 = role, 1 = member)
- GuildLinkChannelUpdateRequestTypeType
- GuildMemberSearchRequestSortBySortBy
- Sort results by field
- GuildMemberSearchRequestSortOrderSortOrder
- Sort order
- GuildMfaLevel
- Required MFA level for moderation actions
- GuildResponseSplashCardAlignmentSplashCardAlignment
- The alignment of the splash card
- GuildTextChannelCreateRequestPermissionOverwritesTypeType
- The type of overwrite (0 = role, 1 = member)
- GuildTextChannelCreateRequestTypeType
- GuildTextChannelUpdateRequestPermissionOverwritesTypeType
- The type of overwrite (0 = role, 1 = member)
- GuildTextChannelUpdateRequestTypeType
- GuildUpdateRequestMfaMethodMfaMethod
- MFA method to use for verification
- GuildUpdateRequestSplashCardAlignmentSplashCardAlignment
- Alignment of the splash card (center, left, or right)
- GuildVerificationLevel
- Required verification level for members
- GuildVoiceChannelCreateRequestPermissionOverwritesTypeType
- The type of overwrite (0 = role, 1 = member)
- GuildVoiceChannelCreateRequestTypeType
- GuildVoiceChannelUpdateRequestPermissionOverwritesTypeType
- The type of overwrite (0 = role, 1 = member)
- GuildVoiceChannelUpdateRequestTypeType
- HarvestCreationResponseSchemaStatusStatus
- Current status of the harvest request
- HarvestSelfDataRequestGuildFilterModeGuildFilterMode
- How the guild filter list is interpreted when include_guilds is true.
- HarvestSelfDataRequestScopeScope
- Which set of contexts the deletion targets
- HarvestStatusResponseSchemaStatusStatus
- Current status of the harvest request
- JoinSourceType
- How the member joined the guild
- Locale
- The locale code for the user interface language
- MentionReplyPreferences
- Reply mention preference
- MessageDsaReportRequestCategoryCategory
- Category of the message report
- MessageDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence
- EU country code of the reporter residence
- MessageDsaReportRequestReportTypeReportType
- Type of report
- MessageReferenceType
- The type of message reference
- MessageResponseSchemaReferencedMessageTypeType
- The type of message
- MessageResponseSchemaTypeType
- The type of message
- MessageSearchResponseVariant2IndexingIndexing
- Indicates that one or more channels are being indexed
- MessageSearchResultsResponseMessagesTypeType
- The type of message
- MessageSnapshotResponseTypeType
- The type of message
- MfaBackupCodesRequestMfaMethodMfaMethod
- MFA method to use for verification
- MultipartPresignedAttachmentUploadResponseItemUploadModeUploadMode
- NsfwLevel
- The NSFW level of the guild
- PackInviteMetadataResponsePackTypeType
- The type of pack (emoji or sticker)
- PackInviteMetadataResponseTypeType
- The type of pack invite (emoji or sticker pack)
- PackInviteResponsePackTypeType
- The type of pack (emoji or sticker)
- PackInviteResponseTypeType
- The type of pack invite (emoji or sticker pack)
- PackSummaryResponseTypeType
- The type of expression pack (emoji or sticker)
- PendingLocalizedCardPreapprovalContinueResponseStatusStatus
- The preapproval result is still being processed
- PendingSubscriptionChangeResponseVariant1CurrencyCurrency
- PendingSubscriptionChangeResponseVariant1CurrentBillingCycleCurrentBillingCycle
- PendingSubscriptionChangeResponseVariant1TargetBillingCycleTargetBillingCycle
- Recurring billing cycle that will start later
- PermissionOverwriteCreateRequestTypeType
- The type of overwrite (0 = role, 1 = member)
- PhoneSendVerificationRequestChannelChannel
- Channel to deliver the OTP on. Defaults to the first available channel from server policy. Server may override to an available fallback when the requested channel is disabled.
- PhoneSendVerificationResponseInboundChallengeReason
- Why inbound verification is required
- PhoneVerifyResponseVerifiedVerified
- Indicates the phone number was verified successfully
- PremiumStateResponseActualPremiumBillingCyclePremiumBillingCycle
- PremiumStateResponseEffectivePremiumBillingCyclePremiumBillingCycle
- PriceIdsResponseCurrencyCurrency
- Currency for the prices
- PriceIdsResponseGiftCurrencyGiftCurrency
- Currency for gift prices
- PricingModeEnum
- ProfilePrivacyLevel
- Profile privacy visibility level
- ReadyLocalizedCardPreapprovalContinueResponseStatusStatus
- The preapproval succeeded and the paid checkout URL is ready
- RefreshTokenTokenRequestGrantTypeGrantType
- The grant type for refreshing an access token
- RegisterMobileDeviceRequestPlatformPlatform
- The mobile push notification platform
- RegisterMobileDeviceRequestProviderEnvironmentProviderEnvironment
- Push provider environment. For APNs, production uses api.push.apple.com and development uses api.sandbox.push.apple.com.
- RegisterRequestThemeTheme
- Initial UI theme preference for the new account
- RejectedLocalizedCardPreapprovalContinueResponseReasonReason
- The reason the preapproval was rejected
- RejectedLocalizedCardPreapprovalContinueResponseStatusStatus
- The preapproval failed and the paid checkout should not continue
- RelationshipTypes
- Relationship type
- RenderSpoilers
- Spoiler rendering preference
- ReportGuildRequestCategoryCategory
- Category of the guild report
- ReportMessageRequestCategoryCategory
- Category of the message report
- ReportUserRequestCategoryCategory
- Category of the user report
- SavedMessageEntryResponseStatusStatus
- Availability status of the saved message
- ScheduledMessageResponseSchemaPayloadAllowedMentionsParseParse
- Types of mentions to parse from content
- ScheduledMessageResponseSchemaStatusStatus
- The current status of the scheduled message
- SelfServeRefundIneligibilityReason
- SensitiveMediaFilterLevel
- Sensitive media filter level
- SensitiveMediaGuildFilterLevel
- Sensitive media filter level for community channels
- SinglepartPresignedAttachmentUploadResponseItemUploadModeUploadMode
- SortBy
- Sort order
- StickerAnimationOptions
- Sticker animation preference
- StreamPreviewUploadUrlResponseSchemaMethodMethod
- HTTP method to use for the upload URL
- SuccessResponseSuccessSuccess
- Whether the operation succeeded
- SudoVerificationSchemaMfaMethodMfaMethod
- MFA method to use for verification
- TimeFormatTypes
- Time format preference
- UnregisterMobileDeviceRequestPlatformPlatform
- The mobile push notification platform
- UnregisterMobileDeviceRequestProviderEnvironmentProviderEnvironment
- Push provider environment used for this registration
- UserAuthenticatorTypes
- Authenticator type
- UserDsaReportRequestCategoryCategory
- Category of the user report
- UserDsaReportRequestReporterCountryOfResidenceReporterCountryOfResidence
- EU country code of the reporter residence
- UserDsaReportRequestReportTypeReportType
- Type of report
- UserNotificationSettings
- Notification level preference
- UserPremiumTypes
- Premium subscription type
- UserSettingsResponseGuildFoldersIconIcon
- Selected icon for the guild folder
- UserSettingsUpdateRequestGuildFoldersIconIcon
- Selected icon for the guild folder
- UserSettingsUpdateRequestStatusResetsToStatusResetsTo
- User online status
- UserSettingsUpdateRequestStatusStatus
- User online status
- UserSettingsUpdateRequestThemeTheme
- UI theme preference
- UserUpdateWithVerificationRequestMfaMethodMfaMethod
- MFA method to use for verification
- WebAuthnCredentialUpdateRequestMfaMethodMfaMethod
- MFA method to use for verification
- WebhookType
- The type of webhook
- WellKnownFluxerResponseLimitsVersionVersion
- Wire format version
- WellKnownFluxerResponseRegistrationModeMode
- Public registration mode for this instance
Extensions
- ChannelCreateRequestUnionDeserializer on ChannelCreateRequest
- ChannelUpdateRequestUnionDeserializer on ChannelUpdateRequest
- DsaReportRequestUnionDeserializer on DsaReportRequest
- LocalizedCardPreapprovalContinueResponseUnionDeserializer on LocalizedCardPreapprovalContinueResponse
- PhoneSendVerificationResponseUnionDeserializer on PhoneSendVerificationResponse
- PresignedAttachmentUploadResponseItemUnionDeserializer on PresignedAttachmentUploadResponseItem
Typedefs
- ApplicationFlags = int
- The application flags
-
ApplicationListResponse
= List<
ApplicationResponse> -
AuthSessionsResponse
= List<
AuthSessionResponse> - Base64ImageType = String
- Base64-encoded image data
- BotFlags = int
- The bot user flags
-
ChannelNicknameOverrides
= Map<
String, String?> - User nickname overrides (user ID to nickname mapping)
-
ChannelPositionUpdateRequest
= List<
ChannelPositionUpdateRequestItem> -
ConnectionListResponse
= List<
ConnectionResponse> -
DiscoveryCategoryListResponse
= List<
DiscoveryCategoryResponse> - DiscriminatorType = String
- EmailType = String
- EmbedMediaFlags = int
- The bitwise flags for this media
-
FavoriteMemeListResponse
= List<
FavoriteMemeResponse> - FriendSourceFlags = int
- Friend source flags
- GroupDmAddPermissionFlags = int
- Group DM add permissions
-
GuildEmojiWithUserListResponse
= List<
GuildEmojiWithUserResponse> - GuildFeatureSchema = String
- A guild feature flag Known values: ANIMATED_ICON, ANIMATED_BANNER, BANNER, CLONE_EMOJI_DISABLED, CLONE_STICKER_DISABLED, DETACHED_BANNER, INVITE_SPLASH, INVITES_DISABLED, RAID_DETECTED, TEXT_CHANNEL_FLEXIBLE_NAMES, HIDE_OWNER_CROWN, MORE_EMOJI, MORE_STICKERS, UNLIMITED_EMOJI, UNLIMITED_STICKERS, EXPRESSION_PURGE_ALLOWED, VANITY_URL, DISCOVERABLE, PARTNERED, VERIFIED, VIP_VOICE, VOICE_E2EE, UNAVAILABLE_FOR_EVERYONE, UNAVAILABLE_FOR_EVERYONE_BUT_STAFF, UNAVAILABLE_HIDDEN, VISIONARY, LARGE_GUILD_OVERRIDE, VERY_LARGE_GUILD (other values allowed)
- GuildFolderFlags = int
- Bitfield for guild folder display behaviour
- GuildMemberProfileFlags = int
- Member profile flags
- GuildOperations = int
- Bitmask of disabled guild operations
-
GuildRoleHoistPositionsRequest
= List<
GuildRoleHoistPositionsRequestItem> -
GuildRolePositionsRequest
= List<
GuildRolePositionsRequestItem> -
GuildStickerWithUserListResponse
= List<
GuildStickerWithUserResponse> - IncomingCallFlags = int
- Incoming call settings
- Int32Type = int
- Int64Type = String
- MessageAttachmentFlags = int
- Attachment flags
- MessageContentRequest = String
- The message content. Non-premium users can send up to 2000 characters; premium users, bots, and webhooks can send up to 4000 characters.
- MessageFlags = int
- Message flags bitfield
-
MessageListResponse
= List<
MessageResponseSchema> - MessageNonceRequest = String
- Client-generated identifier for the message
- NonNegativeSafeIntegerType = int
-
OAuth2AuthorizationsListResponse
= List<
OAuth2AuthorizationResponse> - PasswordType = String
- PhoneNumberType = String
-
PreloadMessagesResponse
= Map<
String, MessageResponseSchema?> - A map of channel IDs to the latest message in each channel
- ProfileFieldPrivacyFlags = int
- Bitfield controlling who can see the profile timezone
- PublicUserFlags = int
- The public flags on the user account
-
ReactionUsersListResponse
= List<
UserPartialResponse> -
SavedMessageEntryListResponse
= List<
SavedMessageEntryResponse> - SnowflakeType = String
- SystemChannelFlags = int
- System channel message flags
-
UnfurlResponse
= List<
MessageEmbedResponse> - The embeds resolved by the unfurler
- UnsignedInt64Type = String
- UsernameType = String
-
UserNotesRecordResponse
= Map<
String, String> - A map of user IDs to note text
- WebAuthnAuthenticationOptionsResponse = dynamic
-
WebAuthnCredentialListResponse
= List<
WebAuthnCredentialResponse>