FluxerClient class
Fluxer API v1.0.0.
API for Fluxer, a free and open source instant messaging and VoIP platform built for friends, groups, and communities.
Constructors
- FluxerClient(Dio dio, {String? baseUrl})
Properties
- admin → AdminApi
-
no setter
- auth → AuthApi
-
no setter
- billing → BillingApi
-
no setter
- channels → ChannelsApi
-
no setter
- connections → ConnectionsApi
-
no setter
- discovery → DiscoveryApi
-
no setter
- donations → DonationsApi
-
no setter
- emojis → EmojisApi
-
no setter
- gateway → GatewayApi
-
no setter
- gifts → GiftsApi
-
no setter
- guilds → GuildsApi
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- instance → InstanceApi
-
no setter
- invites → InvitesApi
-
no setter
- oAuth2 → OAuth2Api
-
no setter
- packs → PacksApi
-
no setter
-
no setter
- readStates → ReadStatesApi
-
no setter
- reports → ReportsApi
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- savedMedia → SavedMediaApi
-
no setter
- search → SearchApi
-
no setter
- stickers → StickersApi
-
no setter
- themes → ThemesApi
-
no setter
- users → UsersApi
-
no setter
- voice → VoiceApi
-
no setter
- webhooks → WebhooksApi
-
no setter
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited