EventParser class

Parses raw gateway dispatch event data into typed GatewayEvent objects.

Constructors

EventParser()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parse(String eventType, Map<String, dynamic> data) GatewayEvent
Parses a dispatch eventType with its associated data payload.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited