GatewayCloseCode enum
Gateway WebSocket close codes for the Fluxer protocol.
Values
- unknownError → const GatewayCloseCode
-
const GatewayCloseCode(4000) - unknownOpcode → const GatewayCloseCode
-
const GatewayCloseCode(4001) - decodeError → const GatewayCloseCode
-
const GatewayCloseCode(4002) - notAuthenticated → const GatewayCloseCode
-
const GatewayCloseCode(4003) - authenticationFailed → const GatewayCloseCode
-
const GatewayCloseCode(4004) - alreadyAuthenticated → const GatewayCloseCode
-
const GatewayCloseCode(4005) - invalidSequence → const GatewayCloseCode
-
const GatewayCloseCode(4007) - rateLimited → const GatewayCloseCode
-
const GatewayCloseCode(4008) - sessionTimedOut → const GatewayCloseCode
-
const GatewayCloseCode(4009) - invalidShard → const GatewayCloseCode
-
const GatewayCloseCode(4010) -
const GatewayCloseCode(4011) - invalidApiVersion → const GatewayCloseCode
-
const GatewayCloseCode(4012)
Properties
- code → int
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isFatal → bool
-
Whether this close code indicates a fatal error that should not
be retried (e.g. bad auth, invalid shard config, bad API version).
no setter
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromCode(
int code) → GatewayCloseCode? -
Looks up a GatewayCloseCode by its integer
code. Returnsnullif no matching code is found.
Constants
-
values
→ const List<
GatewayCloseCode> - A constant List of the values in this enum, in order of their declaration.