AdminPaymentRefundResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- AdminPaymentRefundResponse({required String id, required num amountCents, required String currency, required String? status, required String? reason, required num created, required String? paymentIntentId, required String? chargeId})
-
const
-
AdminPaymentRefundResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- amountCents → num
-
final
- chargeId → String?
-
final
- created → num
-
final
- currency → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
final
- paymentIntentId → String?
-
final
- reason → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited