AdminUserDmChannelSchema class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
AdminUserDmChannelSchema({required SnowflakeType channelId, required Int32Type? channelType, required bool? channelNsfw, required NsfwLevel? guildNsfwLevel, required List<
SnowflakeType> recipientIds, required List<AdminResolvedUserSchema> recipients, required SnowflakeType? lastMessageId, required bool isOpen, required String? name, required String? icon, required SnowflakeType? ownerId}) -
const
-
AdminUserDmChannelSchema.fromJson(Map<
String, Object?> json) -
factory
Properties
- channelId → SnowflakeType
-
final
- channelNsfw → bool?
-
final
- channelType → Int32Type?
-
final
- guildNsfwLevel → NsfwLevel?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
final
- isOpen → bool
-
final
- lastMessageId → SnowflakeType?
-
final
- name → String?
-
final
- ownerId → SnowflakeType?
-
final
-
recipientIds
→ List<
SnowflakeType> -
final
-
recipients
→ List<
AdminResolvedUserSchema> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited