ApplicationAdminResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
ApplicationAdminResponse({required String id, required String name, required String ownerUserId, required String? ownerUsername, required String? ownerGlobalName, required String? ownerDiscriminator, required SnowflakeType? botUserId, required String? botUsername, required String? botGlobalName, required String? botDiscriminator, required bool botIsPublic, required bool botRequireCodeGrant, required List<
String> oauth2RedirectUris, required bool hasClientSecret, required bool hasBotToken, required String? botTokenPreview, required DateTime? botTokenCreatedAt, required DateTime? clientSecretCreatedAt, required int version}) -
const
-
ApplicationAdminResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- botDiscriminator → String?
-
The discriminator of the bot user, if any
final
- botGlobalName → String?
-
The display name of the bot user, if set
final
- botIsPublic → bool
-
Whether the bot is publicly joinable
final
- botRequireCodeGrant → bool
-
Whether an OAuth2 code grant is required for this bot
final
- botTokenCreatedAt → DateTime?
-
ISO 8601 timestamp when the bot token was created
final
- botTokenPreview → String?
-
The preview (last few characters) of the bot token, if any
final
- botUserId → SnowflakeType?
-
The user ID of the associated bot user, if any
final
- botUsername → String?
-
The username of the bot user, if any
final
- clientSecretCreatedAt → DateTime?
-
ISO 8601 timestamp when the client secret was created
final
- hasBotToken → bool
-
Whether a hashed bot token is stored for this application
final
- hasClientSecret → bool
-
Whether a hashed client secret is stored for this application
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The unique identifier for this application
final
- name → String
-
The display name of the application
final
-
oauth2RedirectUris
→ List<
String> -
Registered OAuth2 redirect URIs
final
- ownerDiscriminator → String?
-
The discriminator of the owner, if resolvable
final
- ownerGlobalName → String?
-
The display name of the owner, if set
final
- ownerUserId → String
-
The user ID that owns this application
final
- ownerUsername → String?
-
The username of the owner, if resolvable
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- version → int
-
The optimistic locking version of the application record
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited