ApplicationBotResponse class
Detailed bot user metadata
- Annotations
-
- @JsonSerializable.new()
Constructors
-
ApplicationBotResponse({required String id, required String username, required String discriminator, required String? bio, required BotFlags flags, String? avatar, String? banner, String? token, bool? mfaEnabled, List<
AuthenticatorType> ? authenticatorTypes}) -
const
-
ApplicationBotResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
-
authenticatorTypes
→ List<
AuthenticatorType> ? -
The types of authenticators enabled
final
- avatar → String?
-
The avatar hash of the bot
final
-
The banner hash of the bot
final
- bio → String?
-
The bio or description of the bot
final
- discriminator → String
-
The discriminator of the bot
final
- flags → BotFlags
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The unique identifier of the bot user
final
- mfaEnabled → bool?
-
Whether the bot has MFA enabled
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String?
-
The bot token for authentication
final
- username → String
-
The username of the bot
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited