ApplicationCreateRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
ApplicationCreateRequest({required String name, List<
OAuth2RedirectUriCreateType> ? redirectUris, bool? botPublic, bool? botRequireCodeGrant}) -
const
-
ApplicationCreateRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- botPublic → bool?
-
Whether the bot can be invited by anyone
final
- botRequireCodeGrant → bool?
-
Whether the bot requires OAuth2 code grant
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the application
final
-
redirectUris
→ List<
OAuth2RedirectUriCreateType> ? -
The redirect URIs for OAuth2 flows
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited