ApplicationsMeResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
ApplicationsMeResponse({required String id, required String name, required String? icon, required String? description, required bool botPublic, required bool botRequireCodeGrant, required String verifyKey, required ApplicationsMeResponseOwner owner, ApplicationBotResponse? bot, List<
String> ? redirectUris}) -
const
-
ApplicationsMeResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- bot → ApplicationBotResponse?
-
final
- botPublic → bool
-
Whether the bot can be invited by anyone
final
- botRequireCodeGrant → bool
-
Whether the bot requires OAuth2 code grant
final
- description → String?
-
The persisted bot profile bio used as the application description
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
The persisted bot avatar hash used as the application icon, if available
final
- id → String
-
The unique identifier of the application
final
- name → String
-
The name of the application
final
- owner → ApplicationsMeResponseOwner
-
The owner of the application
final
-
redirectUris
→ List<
String> ? -
The registered redirect URIs for OAuth2
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verifyKey → String
-
Compatibility placeholder for Discord AppInfo clients until keys are persisted
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited