AuditLogWebhookResponse class

Annotations
  • @JsonSerializable.new()

Constructors

AuditLogWebhookResponse({required String id, required WebhookType type, required String name, SnowflakeType? guildId, SnowflakeType? channelId, String? avatarHash})
const
AuditLogWebhookResponse.fromJson(Map<String, Object?> json)
factory

Properties

avatarHash String?
The hash of the webhook avatar
final
channelId SnowflakeType?
The channel ID this webhook posts to
final
guildId SnowflakeType?
The guild ID this webhook belongs to
final
hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier for this webhook
final
name String
The name of the webhook
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type WebhookType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited