AuthLoginResponseAuthMfaRequiredResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
AuthLoginResponseAuthMfaRequiredResponse({required AuthMfaRequiredResponseMfaMfa mfa, required String ticket, required List<
String> allowedMethods, required bool totp, required bool webauthn}) -
const
-
AuthLoginResponseAuthMfaRequiredResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
allowedMethods
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mfa → AuthMfaRequiredResponseMfaMfa
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ticket → String
-
final
- totp → bool
-
final
- webauthn → bool
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited