AuthSessionClientInfo class

Annotations
  • @JsonSerializable.new()

Constructors

AuthSessionClientInfo({String? platform, String? os, String? browser, AuthSessionLocation? location})
const
AuthSessionClientInfo.fromJson(Map<String, Object?> json)
factory

Properties

browser String?
The browser reported by the client
final
hashCode int
The hash code for this object.
no setterinherited
location AuthSessionLocation?
The geolocation data sent by the client
final
os String?
The operating system reported by the client
final
platform String?
The platform reported by the client
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited