AuthSessionLocation class

Annotations
  • @JsonSerializable.new()

Constructors

AuthSessionLocation({String? city, String? region, String? country})
const
AuthSessionLocation.fromJson(Map<String, Object?> json)
factory

Properties

city String?
The city name reported by the client
final
country String?
The country reported by the client
final
hashCode int
The hash code for this object.
no setterinherited
region String?
The region reported by the client
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited