AuthSessionResponse class

Annotations
  • @JsonSerializable.new()

Constructors

AuthSessionResponse({required String idHash, required bool current, AuthSessionClientInfo? clientInfo, DateTime? approxLastUsedAt})
const
AuthSessionResponse.fromJson(Map<String, Object?> json)
factory

Properties

approxLastUsedAt DateTime?
Approximate timestamp of the last session activity
final
clientInfo AuthSessionClientInfo?
Client metadata recorded for this session
final
current bool
Whether this is the current session making the request
final
hashCode int
The hash code for this object.
no setterinherited
idHash String
The base64url-encoded session id hash
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited