AuthorizationCodeTokenRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
- AuthorizationCodeTokenRequest({required AuthorizationCodeTokenRequestGrantTypeGrantType grantType, required String code, required String redirectUri, SnowflakeType? clientId, String? clientSecret, String? codeVerifier})
-
const
-
AuthorizationCodeTokenRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- clientId → SnowflakeType?
-
final
- clientSecret → SnowflakeType?
-
The application client secret
final
- code → String
-
The authorization code received from the authorize endpoint
final
- codeVerifier → SnowflakeType?
-
The PKCE code verifier for the authorization request
final
- grantType → AuthorizationCodeTokenRequestGrantTypeGrantType
-
The grant type for exchanging an authorization code
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- redirectUri → String
-
The redirect URI used in the authorization request
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited