AuthorizeConsentRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
- AuthorizeConsentRequest({required SnowflakeType clientId, required String scope, String? responseType, String? redirectUri, String? state, String? permissions, SnowflakeType? guildId, String? codeChallenge, AuthorizeConsentRequestCodeChallengeMethodCodeChallengeMethod? codeChallengeMethod})
-
const
-
AuthorizeConsentRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- clientId → SnowflakeType
-
final
- codeChallenge → String?
-
The PKCE code challenge
final
- codeChallengeMethod → AuthorizeConsentRequestCodeChallengeMethodCodeChallengeMethod?
-
The PKCE code challenge method
final
- guildId → SnowflakeType?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- permissions → String?
-
The bot permissions to request
final
- redirectUri → String?
-
The URI to redirect to after authorization
final
- responseType → String?
-
The OAuth2 response type
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → String
-
The space-separated list of requested scopes
final
- state → String?
-
A random string for CSRF protection
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited