BulkMessageFetchRequestRequests class

Annotations
  • @JsonSerializable.new()

Constructors

BulkMessageFetchRequestRequests({required SnowflakeType channelId, required int limit, SnowflakeType? before, SnowflakeType? after, SnowflakeType? around})
const
BulkMessageFetchRequestRequests.fromJson(Map<String, Object?> json)
factory

Properties

after SnowflakeType?
final
around SnowflakeType?
final
before SnowflakeType?
final
channelId SnowflakeType
final
hashCode int
The hash code for this object.
no setterinherited
limit int
Number of messages to return for this channel (1-25)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited