CallUpdateBodySchema class
- Annotations
-
- @JsonSerializable.new()
Constructors
- CallUpdateBodySchema({String? region, String? latitude, String? longitude})
-
const
-
CallUpdateBodySchema.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- latitude → String?
-
Client latitude used for automatic region selection
final
- longitude → String?
-
Client longitude used for automatic region selection
final
- region → String?
-
The preferred voice region for the call (1-64 characters). Omit or set to null for automatic region selection.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited