ChannelOverwriteResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- ChannelOverwriteResponse({required String id, required ChannelOverwriteResponseTypeType type, required String allow, required String deny})
-
const
-
ChannelOverwriteResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- allow → String
-
The bitwise value of allowed permissions
final
- deny → String
-
The bitwise value of denied permissions
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The unique identifier for the role or user this overwrite applies to
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → ChannelOverwriteResponseTypeType
-
The type of entity the overwrite applies to
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited