ChannelPinResponse class

Annotations
  • @JsonSerializable.new()

Constructors

ChannelPinResponse({required ChannelPinResponseMessage message, required DateTime pinnedAt})
const
ChannelPinResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
message ChannelPinResponseMessage
The pinned message
final
pinnedAt DateTime
The ISO 8601 timestamp of when the message was pinned
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited