ChannelUpdateRequest2 class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()

Constructors

ChannelUpdateRequest2({required String? topic, required String? url, required SnowflakeType? parentId, required int? bitrate, required int? userLimit, required List<ChannelOverwriteRequest>? permissionOverwrites, required bool? nsfw, required bool? nsfwOverride, required ContentWarningLevel? contentWarningLevel, required String? contentWarningText, required int? rateLimitPerUser, required Base64ImageType? icon, required SnowflakeType? ownerId, required ChannelNicknameOverrides? nicks, required String? rtcRegion, required ChannelUpdateVoiceRequestTypeType type, required String? name})
const
ChannelUpdateRequest2.fromJson(Map<String, dynamic> json)
factory

Properties

bitrate int?
final
contentWarningLevel ContentWarningLevel?
final
contentWarningText String?
final
hashCode int
The hash code for this object.
no setterinherited
icon Base64ImageType?
final
name String?
final
nicks ChannelNicknameOverrides?
final
nsfw bool?
final
nsfwOverride bool?
final
ownerId SnowflakeType?
final
parentId SnowflakeType?
final
permissionOverwrites List<ChannelOverwriteRequest>?
final
rateLimitPerUser int?
final
rtcRegion String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
topic String?
final
type ChannelUpdateVoiceRequestTypeType
final
url String?
final
userLimit int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited