ClientAttachmentReferenceRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
- ClientAttachmentReferenceRequest({required ClientAttachmentReferenceRequestIdId id, String? title, String? description, MessageAttachmentFlags? flags, Int32Type? duration, String? waveform, String? filename})
-
const
-
ClientAttachmentReferenceRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- description → String?
-
An alt text description of the attachment (1-4096 characters)
final
- duration → Int32Type?
-
The duration of the audio file in seconds
final
- filename → String?
-
A new filename for the attachment
final
- flags → MessageAttachmentFlags?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → ClientAttachmentReferenceRequestIdId
-
The identifier of the attachment being referenced (snowflake ID or file index)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- title → String?
-
A title for the attachment (1-1024 characters)
final
- waveform → String?
-
Base64 encoded audio waveform data
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited