ConnectionResponse class

Annotations
  • @JsonSerializable.new()

Constructors

ConnectionResponse({required String id, required ConnectionResponseTypeType type, required String name, required bool verified, required int visibilityFlags, required int sortOrder})
const
ConnectionResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier for this connection
final
name String
The display name of the connection (handle or domain)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sortOrder int
The display order of this connection
final
type ConnectionResponseTypeType
The type of connection
final
verified bool
Whether the connection has been verified
final
visibilityFlags int
Bitfield controlling who can see this connection
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited