ConnectionVerificationResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- ConnectionVerificationResponse({required String token, required ConnectionVerificationResponseTypeType type, required String id, required String instructions, required String initiationToken})
-
const
-
ConnectionVerificationResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The connection identifier (handle or domain)
final
- initiationToken → String
-
Signed token the client sends back at verify time
final
- instructions → String
-
Human-readable instructions for completing verification
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String
-
The verification token to place in DNS or profile
final
- type → ConnectionVerificationResponseTypeType
-
The type of connection being verified
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited