CreateAdminApiKeyResponse class
Properties
-
acls
→ List<String>
-
List of access control permissions for the key
final
-
createdAt
→ String
-
ISO 8601 timestamp when the key was created
final
-
expiresAt
→ String?
-
ISO 8601 timestamp when the key expires, or null if no expiration
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
key
→ String
-
The generated API key secret (only shown once)
final
-
keyId
→ String
-
Unique identifier for the API key
final
-
name
→ String
-
Display name for the API key
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited