CreateCheckoutSessionRequest class

Annotations
  • @JsonSerializable.new()

Constructors

CreateCheckoutSessionRequest({required String priceId, String? countryCode, String? clientGeoipCountryCode, bool? euWithdrawalWaiverAccepted, PricingModeEnum? pricingMode, CheckoutPaymentMethodEnum? paymentMethod})
const
CreateCheckoutSessionRequest.fromJson(Map<String, Object?> json)
factory

Properties

clientGeoipCountryCode String?
Two-letter country code observed by the client GeoIP store before checkout
final
countryCode String?
Two-letter country code used for regional pricing
final
euWithdrawalWaiverAccepted bool?
Whether the EU/EEA digital content withdrawal waiver was expressly accepted before checkout
final
hashCode int
The hash code for this object.
no setterinherited
paymentMethod CheckoutPaymentMethodEnum?
final
priceId String
The Stripe price ID for the subscription plan
final
pricingMode PricingModeEnum?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited