isBusiness property
Whether the purchase is for a business. When true, Stripe Checkout requires a billing address (needed for tax invoicing). When false or omitted, billing address collection is left to Stripe (auto).
Implementation
@JsonKey(includeIfNull: false, name: 'is_business')
final bool? isBusiness;