CreateVoiceServerResponseServer class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
CreateVoiceServerResponseServer({required String regionId, required String serverId, required String endpoint, required num? latitude, required num? longitude, required bool isActive, required bool vipOnly, required List<
String> requiredGuildFeatures, required List<SnowflakeType> allowedGuildIds, required List<SnowflakeType> allowedUserIds, required String? createdAt, required String? updatedAt}) -
const
-
CreateVoiceServerResponseServer.fromJson(Map<
String, Object?> json) -
factory
Properties
-
allowedGuildIds
→ List<
SnowflakeType> -
Guild IDs explicitly allowed to use this server
final
-
allowedUserIds
→ List<
SnowflakeType> -
User IDs explicitly allowed to use this server
final
- createdAt → String?
-
ISO 8601 timestamp when the server was created
final
- endpoint → String
-
Client signal WebSocket endpoint URL for the voice server
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool
-
Whether the server is currently active
final
- latitude → num?
-
Optional geographic latitude override for this server
final
- longitude → num?
-
Optional geographic longitude override for this server
final
- regionId → String
-
ID of the region this server belongs to
final
-
requiredGuildFeatures
→ List<
String> -
Guild features required to use this server
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverId → String
-
Unique identifier for the voice server
final
- updatedAt → String?
-
ISO 8601 timestamp when the server was last updated
final
- vipOnly → bool
-
Whether this server is restricted to VIP users
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited