CurrentSubscriptionPriceResponseVariant1 class
- Annotations
-
- @JsonSerializable.new()
Constructors
- CurrentSubscriptionPriceResponseVariant1({required String priceId, required int amountMinor, required CurrentSubscriptionPriceResponseVariant1CurrencyCurrency currency, required CurrentSubscriptionPriceResponseVariant1BillingCycleBillingCycle billingCycle, required bool isGrandfathered, required int? listAmountMinor, required String? listPriceId})
-
const
-
CurrentSubscriptionPriceResponseVariant1.fromJson(Map<
String, dynamic> json) -
factory
Properties
- amountMinor → int
-
final
- billingCycle → CurrentSubscriptionPriceResponseVariant1BillingCycleBillingCycle
-
final
- currency → CurrentSubscriptionPriceResponseVariant1CurrencyCurrency
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isGrandfathered → bool
-
final
- listAmountMinor → int?
-
final
- listPriceId → String?
-
final
- priceId → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited