CustomStatusPayload class
- Annotations
-
- @JsonSerializable.new()
Constructors
- CustomStatusPayload({String? text, dynamic expiresAt, SnowflakeType? emojiId, String? emojiName})
-
const
-
CustomStatusPayload.fromJson(Map<
String, Object?> json) -
factory
Properties
- emojiId → SnowflakeType?
-
ID of custom emoji to display
final
- emojiName → String?
-
Unicode emoji to display (ignored when emoji_id is provided)
final
- expiresAt → dynamic
-
When the custom status expires
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
Custom status text (max 128 characters)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited