CustomStatusResponse class

Annotations
  • @JsonSerializable.new()

Constructors

CustomStatusResponse({required bool emojiAnimated, String? text, DateTime? expiresAt, SnowflakeType? emojiId, String? emojiName})
const
CustomStatusResponse.fromJson(Map<String, Object?> json)
factory

Properties

emojiAnimated bool
Whether the status emoji is animated
final
emojiId SnowflakeType?
The ID of the custom emoji used in the status
final
emojiName String?
The name of the emoji used in the status
final
expiresAt DateTime?
ISO8601 timestamp of when the custom status expires
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text String?
The custom status message text
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited