DeleteMessageResponseSuccessSuccess enum
Values
- valueTrue → const DeleteMessageResponseSuccessSuccess
-
The name has been replaced because it contains a keyword. Original name:
true.const DeleteMessageResponseSuccessSuccess(true) - $unknown → const DeleteMessageResponseSuccessSuccess
-
Default value for all unparsed values, allows backward compatibility when adding new values on the backend.
const DeleteMessageResponseSuccessSuccess(null)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- json → bool?
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → bool? -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
$valuesDefined
→ List<
DeleteMessageResponseSuccessSuccess> -
Returns all defined enum values excluding the $unknown value.
no setter
Constants
-
values
→ const List<
DeleteMessageResponseSuccessSuccess> - A constant List of the values in this enum, in order of their declaration.