DiscoveryApplicationResponse class

Annotations
  • @JsonSerializable.new()

Constructors

DiscoveryApplicationResponse({required String guildId, required String status, required String description, required num categoryType, required List<String> customTags, required String appliedAt, NsfwLevel? guildNsfwLevel, String? primaryLanguage, String? reviewedAt, String? reviewReason, String? removedAt, String? removalReason})
const
DiscoveryApplicationResponse.fromJson(Map<String, Object?> json)
factory

Properties

appliedAt String
Application timestamp
final
categoryType num
Discovery category type
final
customTags List<String>
Custom discovery tags
final
description String
Discovery description
final
guildId String
Guild ID
final
guildNsfwLevel NsfwLevel?
NSFW level of the guild
final
hashCode int
The hash code for this object.
no setterinherited
primaryLanguage String?
Primary community language
final
removalReason String?
Removal reason
final
removedAt String?
Removal timestamp
final
reviewedAt String?
Review timestamp
final
reviewReason String?
Review reason (approval/rejection)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status String
Application status
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited