DiscoveryGuildResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
DiscoveryGuildResponse({required String id, required String name, required num categoryType, required List<
String> customTags, required num memberCount, required num onlineCount, required List<String> features, required num verificationLevel, String? icon, String? description, String? primaryLanguage}) -
const
-
DiscoveryGuildResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- categoryType → num
-
Discovery category type
final
-
customTags
→ List<
String> -
Custom discovery tags
final
- description → String?
-
Discovery description
final
-
features
→ List<
String> -
Guild feature flags
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
Guild icon hash
final
- id → String
-
Guild ID
final
- memberCount → num
-
Approximate member count
final
- name → String
-
Guild name
final
- onlineCount → num
-
Approximate online member count
final
- primaryLanguage → String?
-
Primary community language
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- verificationLevel → num
-
Verification level
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited