DsaReportGuildRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
- DsaReportGuildRequest({required String ticket, required String reporterFullLegalName, required DsaReportGuildRequestReporterCountryOfResidenceReporterCountryOfResidence reporterCountryOfResidence, required DsaReportGuildRequestReportTypeReportType reportType, required GuildReportCategoryEnum category, required SnowflakeType guildId, String? additionalInfo, String? reporterFluxerTag, String? inviteCode})
-
const
-
DsaReportGuildRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- additionalInfo → String?
-
Additional context or details about the report
final
- category → GuildReportCategoryEnum
-
final
- guildId → SnowflakeType
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inviteCode → String?
-
Invite code used to access the guild
final
- reporterCountryOfResidence → DsaReportGuildRequestReporterCountryOfResidenceReporterCountryOfResidence
-
EU country code of the reporter residence
final
- reporterFluxerTag → String?
-
Fluxer tag of the reporter if they have an account
final
- reporterFullLegalName → String
-
Full legal name of the person filing the report
final
- reportType → DsaReportGuildRequestReportTypeReportType
-
Type of report
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ticket → String
-
Verification ticket obtained from email verification
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited