DsaReportRequestMessage class
- Inheritance
-
- Object
- DsaReportRequest
- DsaReportRequestMessage
- Available extensions
- Annotations
-
- @JsonSerializable.new()
Constructors
- DsaReportRequestMessage({required String ticket, required String? additionalInfo, required String reporterFullLegalName, required DsaReportMessageRequestReporterCountryOfResidenceReporterCountryOfResidence reporterCountryOfResidence, required String? reporterFluxerTag, required DsaReportMessageRequestReportTypeReportType reportType, required MessageReportCategoryEnum category, required String messageLink, required String? reportedUserTag})
-
const
-
DsaReportRequestMessage.fromJson(Map<
String, dynamic> json) -
factory
Properties
- additionalInfo → String?
-
final
- category → MessageReportCategoryEnum
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageLink → String
-
final
- reportedUserTag → String?
-
final
- reporterCountryOfResidence → DsaReportMessageRequestReporterCountryOfResidenceReporterCountryOfResidence
-
final
- reporterFluxerTag → String?
-
final
- reporterFullLegalName → String
-
final
- reportType → DsaReportMessageRequestReportTypeReportType
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ticket → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited