DsaReportRequestUser class
- Inheritance
-
- Object
- DsaReportRequest
- DsaReportRequestUser
- Available extensions
- Annotations
-
- @JsonSerializable.new()
Constructors
- DsaReportRequestUser({required String ticket, required String? additionalInfo, required String reporterFullLegalName, required DsaReportUserRequestReporterCountryOfResidenceReporterCountryOfResidence reporterCountryOfResidence, required String? reporterFluxerTag, required DsaReportUserRequestReportTypeReportType reportType, required UserReportCategoryEnum category, required SnowflakeType? userId, required String? userTag})
-
const
-
DsaReportRequestUser.fromJson(Map<
String, dynamic> json) -
factory
Properties
- additionalInfo → String?
-
final
- category → UserReportCategoryEnum
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- reporterCountryOfResidence → DsaReportUserRequestReporterCountryOfResidenceReporterCountryOfResidence
-
final
- reporterFluxerTag → String?
-
final
- reporterFullLegalName → String
-
final
- reportType → DsaReportUserRequestReportTypeReportType
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- ticket → String
-
final
- userId → SnowflakeType?
-
final
- userTag → String?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited