EmbedAuthorResponse class

Annotations
  • @JsonSerializable.new()

Constructors

EmbedAuthorResponse({required String name, String? url, String? iconUrl, String? proxyIconUrl})
const
EmbedAuthorResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
iconUrl String?
The URL of the author icon
final
name String
The name of the author
final
proxyIconUrl String?
The proxied URL of the author icon
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String?
The URL of the author
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited