EmbedMediaResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- EmbedMediaResponse({required String url, required EmbedMediaFlags flags, String? proxyUrl, String? contentType, String? contentHash, Int32Type? width, Int32Type? height, String? description, String? placeholder, Int32Type? duration})
-
const
-
EmbedMediaResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- contentHash → String?
-
The hash of the media content
final
- contentType → String?
-
The MIME type of the media
final
- description → String?
-
The description of the media
final
- duration → Int32Type?
-
The duration of the media in seconds
final
- flags → EmbedMediaFlags
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- height → Int32Type?
-
The height of the media in pixels
final
- placeholder → String?
-
The base64 encoded placeholder image for lazy loading
final
- proxyUrl → String?
-
The proxied URL of the media
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- url → String
-
The URL of the media
final
- width → Int32Type?
-
The width of the media in pixels
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited