GatewayBotResponse class

Annotations
  • @JsonSerializable.new()

Constructors

GatewayBotResponse({required String url, required int shards, required GatewayBotResponseSessionStartLimit sessionStartLimit})
const
GatewayBotResponse.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sessionStartLimit GatewayBotResponseSessionStartLimit
Session start rate limit information
final
shards int
Recommended number of shards to use when connecting
final
url String
WebSocket URL to connect to the gateway
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited