GatewayBotResponseSessionStartLimit class
- Annotations
-
- @JsonSerializable.new()
Constructors
- GatewayBotResponseSessionStartLimit({required int total, required int remaining, required int resetAfter, required int maxConcurrency})
-
const
-
GatewayBotResponseSessionStartLimit.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxConcurrency → int
-
Maximum number of concurrent IDENTIFY requests
final
- remaining → int
-
Remaining number of session starts
final
- resetAfter → int
-
Milliseconds until the limit resets
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- total → int
-
Total number of session starts allowed
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited