GenerateGiftCodesRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
- GenerateGiftCodesRequest({required int count, required GenerateGiftCodesRequestDurationTypeDurationType durationType, required int durationQuantity})
-
const
-
GenerateGiftCodesRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- count → int
-
Number of gift codes to generate
final
- durationQuantity → int
-
Duration quantity for the selected unit. Lifetime gifts are not supported.
final
- durationType → GenerateGiftCodesRequestDurationTypeDurationType
-
Duration unit for the generated gift codes
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited