GiftCodeMetadataResponse class

Annotations
  • @JsonSerializable.new()

Constructors

GiftCodeMetadataResponse({required String code, required GiftCodeMetadataResponseDurationTypeDurationType durationType, required int durationQuantity, required DateTime createdAt, required UserPartialResponse createdBy, DateTime? redeemedAt, UserPartialResponse? redeemedBy})
const
GiftCodeMetadataResponse.fromJson(Map<String, Object?> json)
factory

Properties

code String
The unique gift code string
final
createdAt DateTime
Timestamp when the gift code was created
final
createdBy UserPartialResponse
final
durationQuantity int
Duration quantity for the selected duration unit
final
durationType GiftCodeMetadataResponseDurationTypeDurationType
Duration unit for the gift entitlement
final
hashCode int
The hash code for this object.
no setterinherited
redeemedAt DateTime?
Timestamp when the gift code was redeemed
final
redeemedBy UserPartialResponse?
The user who redeemed the gift code
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited