GiftCodeResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- GiftCodeResponse({required String code, required GiftCodeResponseDurationTypeDurationType durationType, required int durationQuantity, required bool redeemed, UserPartialResponse? createdBy})
-
const
-
GiftCodeResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- code → String
-
The unique gift code string
final
- createdBy → UserPartialResponse?
-
The user who created the gift code
final
- durationQuantity → int
-
Duration quantity for the selected duration unit
final
- durationType → GiftCodeResponseDurationTypeDurationType
-
Duration unit for the gift entitlement
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- redeemed → bool
-
Whether the gift code has been redeemed
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited