GitHubWebhook class

Annotations
  • @JsonSerializable.new()

Constructors

GitHubWebhook({required GitHubWebhookSender sender, String? action, GitHubWebhookAnswer? answer, GitHubWebhookCheckRun? checkRun, GitHubWebhookCheckSuite? checkSuite, GitHubWebhookComment? comment, List<GitHubWebhookCommits>? commits, String? compare, GitHubWebhookDiscussion? discussion, bool? forced, GitHubWebhookForkee? forkee, GitHubWebhookHeadCommit? headCommit, GitHubWebhookIssue? issue, GitHubWebhookMember? member, GitHubWebhookPullRequest? pullRequest, String? refType, String? ref, GitHubWebhookRelease? release, GitHubWebhookRepository? repository, GitHubWebhookReview? review})
const
GitHubWebhook.fromJson(Map<String, Object?> json)
factory

Properties

action String?
final
answer GitHubWebhookAnswer?
final
checkRun GitHubWebhookCheckRun?
final
checkSuite GitHubWebhookCheckSuite?
final
comment GitHubWebhookComment?
final
commits List<GitHubWebhookCommits>?
final
compare String?
final
discussion GitHubWebhookDiscussion?
final
forced bool?
final
forkee GitHubWebhookForkee?
final
hashCode int
The hash code for this object.
no setterinherited
headCommit GitHubWebhookHeadCommit?
final
issue GitHubWebhookIssue?
final
member GitHubWebhookMember?
final
pullRequest GitHubWebhookPullRequest?
final
ref String?
final
refType String?
final
release GitHubWebhookRelease?
final
repository GitHubWebhookRepository?
final
review GitHubWebhookReview?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender GitHubWebhookSender
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited