GitHubWebhookDiscussion class

Annotations
  • @JsonSerializable.new()

Constructors

GitHubWebhookDiscussion({required String title, required Int32Type number, required String htmlUrl, required GitHubWebhookDiscussionUser user, String? answerHtmlUrl, String? body})
const
GitHubWebhookDiscussion.fromJson(Map<String, Object?> json)
factory

Properties

answerHtmlUrl String?
final
body String?
final
hashCode int
The hash code for this object.
no setterinherited
htmlUrl String
final
number Int32Type
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String
final
user GitHubWebhookDiscussionUser
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited