GuildAdminResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
GuildAdminResponse({required String id, required String name, required List<
GuildFeatureSchema> features, required String ownerId, required String? ownerUsername, required String? ownerGlobalName, required String? ownerDiscriminator, required String? icon, required String? banner, required int memberCount, NsfwLevel? nsfwLevel, bool? nsfw, ContentWarningLevel? contentWarningLevel, String? contentWarningText}) -
const
-
GuildAdminResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
-
The hash of the guild banner
final
- contentWarningLevel → ContentWarningLevel?
-
final
- contentWarningText → String?
-
Custom content warning text shown before entry
final
-
features
→ List<
GuildFeatureSchema> -
Array of guild feature flags
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
The hash of the guild icon
final
- id → String
-
The unique identifier for this guild
final
- memberCount → int
-
The number of members in the guild
final
- name → String
-
The name of the guild
final
- nsfw → bool?
-
Whether the guild is flagged as adult content
final
- nsfwLevel → NsfwLevel?
-
final
- ownerDiscriminator → String?
-
The discriminator of the guild owner
final
- ownerGlobalName → String?
-
The display name of the guild owner, if set
final
- ownerId → String
-
The ID of the guild owner
final
- ownerUsername → String?
-
The username of the guild owner
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited