GuildAuditLogEntryResponseOptions class
- Annotations
-
- @JsonSerializable.new()
Constructors
- GuildAuditLogEntryResponseOptions({String? channelId, num? count, String? deleteMemberDays, String? id, num? integrationType, String? messageId, num? membersRemoved, String? roleName, num? type, String? inviterId, num? maxAge, num? maxUses, bool? temporary, num? uses})
-
const
-
GuildAuditLogEntryResponseOptions.fromJson(Map<
String, Object?> json) -
factory
Properties
- channelId → String?
-
Channel ID for relevant actions
final
- count → num?
-
Count of items affected
final
- deleteMemberDays → String?
-
Number of days of messages to delete on member ban
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String?
-
ID of the affected entity
final
- integrationType → num?
-
Type of integration
final
- inviterId → String?
-
ID of the user who created the invite
final
- maxAge → num?
-
Maximum age of the invite in seconds
final
- maxUses → num?
-
Maximum number of uses for the invite
final
- membersRemoved → num?
-
Number of members removed
final
- messageId → String?
-
Message ID for relevant actions
final
- roleName → String?
-
Name of the role
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temporary → bool?
-
Whether the invite grants temporary membership
final
- type → num?
-
Type identifier
final
- uses → num?
-
Number of times the invite has been used
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited