GuildBanCreateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

GuildBanCreateRequest({int? deleteMessageDays, String? reason, int? banDurationSeconds})
const
GuildBanCreateRequest.fromJson(Map<String, Object?> json)
factory

Properties

banDurationSeconds int?
Duration of the ban in seconds (0 for permanent, or between 60 and 63072000 seconds for a temporary ban)
final
deleteMessageDays int?
Number of days of messages to delete from the banned user (0-7)
final
hashCode int
The hash code for this object.
no setterinherited
reason String?
The reason for the ban (max 512 characters)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited