GuildBanResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- GuildBanResponse({required UserPartialResponse user, required String moderatorId, required DateTime bannedAt, String? reason, DateTime? expiresAt})
-
const
-
GuildBanResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- bannedAt → DateTime
-
ISO8601 timestamp of when the ban was issued
final
- expiresAt → DateTime?
-
ISO8601 timestamp of when the ban expires (null if permanent)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- moderatorId → String
-
The ID of the moderator who issued the ban
final
- reason → String?
-
The reason for the ban
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → UserPartialResponse
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited