GuildEmojiCreateRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
- GuildEmojiCreateRequest({required String name, required Base64ImageType image})
-
const
-
GuildEmojiCreateRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → Base64ImageType
-
final
- name → String
-
The name of the emoji (2-32 characters, alphanumeric and underscores only)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited