GuildInviteResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- GuildInviteResponse({required String code, required GuildInviteResponseTypeType type, required GuildInviteResponseGuild guild, required ChannelPartialResponse channel, required int memberCount, required int presenceCount, required bool temporary, UserPartialResponse? inviter, DateTime? expiresAt})
-
const
-
GuildInviteResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- channel → ChannelPartialResponse
-
final
- code → String
-
The unique invite code
final
- expiresAt → DateTime?
-
ISO8601 timestamp of when the invite expires
final
- guild → GuildInviteResponseGuild
-
The guild this invite is for
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inviter → UserPartialResponse?
-
The user who created the invite
final
- memberCount → int
-
The approximate total member count of the guild
final
- presenceCount → int
-
The approximate online member count of the guild
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temporary → bool
-
Whether the invite grants temporary membership
final
- type → GuildInviteResponseTypeType
-
The type of invite (guild)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited