GuildMemberResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
GuildMemberResponse({required UserPartialResponse user, required List<
String> roles, required DateTime joinedAt, required bool mute, required bool deaf, String? nick, String? avatar, String? banner, Int32Type? accentColor, DateTime? communicationDisabledUntil, GuildMemberProfileFlags? profileFlags, MentionReplyPreferences? mentionFlags}) -
const
-
GuildMemberResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- accentColor → Int32Type?
-
The accent colour of the member guild profile as an integer
final
- avatar → String?
-
The hash of the member guild-specific avatar
final
-
The hash of the member guild-specific banner
final
- communicationDisabledUntil → DateTime?
-
ISO8601 timestamp until which the member is timed out
final
- deaf → bool
-
Whether the member is deafened in voice channels
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- joinedAt → DateTime
-
ISO8601 timestamp of when the user joined the guild
final
- mentionFlags → MentionReplyPreferences?
-
Per-guild reply mention preference override; NO_PREFERENCE means inherit the user-level mention_flags.
final
- mute → bool
-
Whether the member is muted in voice channels
final
- nick → String?
-
The nickname of the member in this guild
final
- profileFlags → GuildMemberProfileFlags?
-
final
-
roles
→ List<
String> -
Array of role IDs the member has
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → UserPartialResponse
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited