GuildMemoryStatsResponseGuilds class
- Annotations
-
- @JsonSerializable.new()
Constructors
- GuildMemoryStatsResponseGuilds({required String nodeId, required SnowflakeType? guildId, required String guildName, required String? guildIcon, required NsfwLevel? nsfwLevel, required Int64StringType memory, required Int32Type memberCount, required Int32Type sessionCount, required Int32Type presenceCount})
-
const
-
GuildMemoryStatsResponseGuilds.fromJson(Map<
String, Object?> json) -
factory
Properties
- guildIcon → String?
-
final
- guildId → SnowflakeType?
-
final
- guildName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- memberCount → Int32Type
-
final
- memory → Int64StringType
-
final
- nodeId → String
-
final
- nsfwLevel → NsfwLevel?
-
final
- presenceCount → Int32Type
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionCount → Int32Type
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited