GuildRoleResponse class
Properties
-
color
→ int
-
The colour of the role as an integer
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
hoist
→ bool
-
Whether this role is displayed separately in the member list
final
-
hoistPosition
→ Int32Type?
-
The position of the role in the hoisted member list
final
-
id
→ String
-
The unique identifier for this role
final
-
mentionable
→ bool
-
Whether this role can be mentioned by anyone
final
-
name
→ String
-
The name of the role
final
-
permissions
→ String
-
The permissions bitfield for the role
final
-
position
→ int
-
The position of the role in the role hierarchy
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
unicodeEmoji
→ String?
-
The unicode emoji for this role
final