GuildRoleUpdateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

GuildRoleUpdateRequest({String? name, int? color, UnsignedInt64Type? permissions, bool? hoist, int? hoistPosition, bool? mentionable})
const
GuildRoleUpdateRequest.fromJson(Map<String, Object?> json)
factory

Properties

color int?
The color of the role as an integer
final
hashCode int
The hash code for this object.
no setterinherited
hoist bool?
Whether the role should be displayed separately in the member list
final
hoistPosition int?
The position of the role in the hoisted member list
final
mentionable bool?
Whether the role can be mentioned by anyone
final
name String?
The name of the role (1-100 characters)
final
permissions UnsignedInt64Type?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited