GuildStickerCreateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

GuildStickerCreateRequest({required String name, required Base64ImageType image, String? description, List<String>? tags})
const
GuildStickerCreateRequest.fromJson(Map<String, Object?> json)
factory

Properties

description String?
Description of the sticker (1-500 characters)
final
hashCode int
The hash code for this object.
no setterinherited
image Base64ImageType
final
name String
The name of the sticker (2-30 characters)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>?
Array of autocomplete/suggestion tags (max 10 tags, each 1-30 characters)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited