GuildStickerResponse class

Annotations
  • @JsonSerializable.new()

Constructors

GuildStickerResponse({required String id, required String name, required String description, required List<String> tags, required bool animated, required bool nsfw})
const
GuildStickerResponse.fromJson(Map<String, Object?> json)
factory

Properties

animated bool
Whether this sticker is animated
final
description String
The description of the sticker
final
hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier for this sticker
final
name String
The name of the sticker
final
nsfw bool
Whether this sticker is classified as NSFW
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
Autocomplete/suggestion tags for the sticker
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited