GuildUpdateResponseGuild class

Annotations
  • @JsonSerializable.new()

Constructors

GuildUpdateResponseGuild({required SnowflakeType id, required String name, required List<String> features, required SnowflakeType ownerId, required String? icon, required String? banner, required Int32Type memberCount, NsfwLevel? nsfwLevel, bool? nsfw, ContentWarningLevel? contentWarningLevel, String? contentWarningText})
const
GuildUpdateResponseGuild.fromJson(Map<String, Object?> json)
factory

Properties

final
contentWarningLevel ContentWarningLevel?
final
contentWarningText String?
final
features List<String>
final
hashCode int
The hash code for this object.
no setterinherited
icon String?
final
id SnowflakeType
final
memberCount Int32Type
final
name String
final
nsfw bool?
final
nsfwLevel NsfwLevel?
final
ownerId SnowflakeType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited