IndexRefreshStatusResponseVariant2 class
- Annotations
-
- @JsonSerializable.new()
Constructors
- IndexRefreshStatusResponseVariant2({required IndexRefreshStatusResponseVariant2StatusStatus status, required String indexType, required num? total, required num? indexed, required String? startedAt, required String? completedAt, required String? failedAt, required String? error})
-
const
-
IndexRefreshStatusResponseVariant2.fromJson(Map<
String, dynamic> json) -
factory
Properties
- completedAt → String?
-
final
- error → String?
-
final
- failedAt → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- indexed → num?
-
final
- indexType → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- startedAt → String?
-
final
- status → IndexRefreshStatusResponseVariant2StatusStatus
-
final
- total → num?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited