InviteMetadataResponseSchemaGuildInviteMetadataResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- InviteMetadataResponseSchemaGuildInviteMetadataResponse({required String code, required GuildInviteMetadataResponseTypeType type, required GuildInviteMetadataResponseGuild guild, required ChannelPartialResponse channel, required UserPartialResponse? inviter, required int memberCount, required int presenceCount, required DateTime? expiresAt, required bool temporary, required DateTime createdAt, required int uses, required int maxUses, required int maxAge})
-
const
-
InviteMetadataResponseSchemaGuildInviteMetadataResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- channel → ChannelPartialResponse
-
final
- code → String
-
final
- createdAt → DateTime
-
final
- expiresAt → DateTime?
-
final
- guild → GuildInviteMetadataResponseGuild
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inviter → UserPartialResponse?
-
final
- maxAge → int
-
final
- maxUses → int
-
final
- memberCount → int
-
final
- presenceCount → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temporary → bool
-
final
- type → GuildInviteMetadataResponseTypeType
-
final
- uses → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited