InviteResponseSchemaGuildInviteResponse class

Annotations
  • @JsonSerializable.new()

Constructors

InviteResponseSchemaGuildInviteResponse({required String code, required GuildInviteResponseTypeType type, required GuildInviteResponseGuild guild, required ChannelPartialResponse channel, required UserPartialResponse? inviter, required int memberCount, required int presenceCount, required DateTime? expiresAt, required bool temporary})
const
InviteResponseSchemaGuildInviteResponse.fromJson(Map<String, dynamic> json)
factory

Properties

channel ChannelPartialResponse
final
code String
final
expiresAt DateTime?
final
guild GuildInviteResponseGuild
final
hashCode int
The hash code for this object.
no setterinherited
inviter UserPartialResponse?
final
memberCount int
final
presenceCount int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
temporary bool
final
type GuildInviteResponseTypeType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited