IpAuthorizationPollResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- IpAuthorizationPollResponse({required bool completed, String? token, SnowflakeType? userId, UserPartialResponse? user})
-
const
-
IpAuthorizationPollResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- completed → bool
-
Whether the IP authorization has been completed
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- token → String?
-
Authentication token if authorization is complete
final
- user → UserPartialResponse?
-
Partial user data if authorization is complete
final
- userId → SnowflakeType?
-
User ID if authorization is complete
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited