ListUserDmChannelsRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
- ListUserDmChannelsRequest({required SnowflakeType userId, SnowflakeType? before, SnowflakeType? after, int? limit})
-
const
-
ListUserDmChannelsRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- after → SnowflakeType?
-
final
- before → SnowflakeType?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- limit → int?
-
Maximum number of DM channels to return
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userId → SnowflakeType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited