LookupGuildResponseGuild class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
LookupGuildResponseGuild({required SnowflakeType id, required SnowflakeType ownerId, required String? ownerUsername, required String? ownerGlobalName, required String? ownerDiscriminator, required String name, required String? vanityUrlCode, required String? icon, required String? banner, required String? splash, required String? embedSplash, required List<
String> features, required GuildVerificationLevel verificationLevel, required GuildMfaLevel mfaLevel, required NsfwLevel nsfwLevel, required GuildExplicitContentFilter explicitContentFilter, required DefaultMessageNotifications defaultMessageNotifications, required SnowflakeType? afkChannelId, required Int32Type afkTimeout, required SnowflakeType? systemChannelId, required SystemChannelFlags systemChannelFlags, required SnowflakeType? rulesChannelId, required Int32Type disabledOperations, required Int32Type memberCount, required List<LookupGuildResponseGuildChannels> channels, required List<LookupGuildResponseGuildRoles> roles, bool? nsfw, ContentWarningLevel? contentWarningLevel, String? contentWarningText}) -
const
-
LookupGuildResponseGuild.fromJson(Map<
String, Object?> json) -
factory
Properties
- afkChannelId → SnowflakeType?
-
final
- afkTimeout → Int32Type
-
final
-
final
-
channels
→ List<
LookupGuildResponseGuildChannels> -
final
- contentWarningLevel → ContentWarningLevel?
-
final
- contentWarningText → String?
-
final
- defaultMessageNotifications → DefaultMessageNotifications
-
final
- disabledOperations → Int32Type
-
final
- embedSplash → String?
-
final
- explicitContentFilter → GuildExplicitContentFilter
-
final
-
features
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- icon → String?
-
final
- id → SnowflakeType
-
final
- memberCount → Int32Type
-
final
- mfaLevel → GuildMfaLevel
-
final
- name → String
-
final
- nsfw → bool?
-
final
- nsfwLevel → NsfwLevel
-
final
- ownerDiscriminator → String?
-
final
- ownerGlobalName → String?
-
final
- ownerId → SnowflakeType
-
final
- ownerUsername → String?
-
final
-
roles
→ List<
LookupGuildResponseGuildRoles> -
final
- rulesChannelId → SnowflakeType?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- splash → String?
-
final
- systemChannelFlags → SystemChannelFlags
-
final
- systemChannelId → SnowflakeType?
-
final
- vanityUrlCode → String?
-
final
- verificationLevel → GuildVerificationLevel
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited