MessageAttachmentResponse class

Annotations
  • @JsonSerializable.new()

Constructors

MessageAttachmentResponse({required String id, required String filename, required int size, required MessageAttachmentFlags flags, String? title, String? description, String? contentType, String? contentHash, String? url, String? proxyUrl, Int32Type? width, Int32Type? height, String? placeholder, bool? nsfw, Int32Type? duration, String? waveform, String? expiresAt, bool? expired})
const
MessageAttachmentResponse.fromJson(Map<String, Object?> json)
factory

Properties

contentHash String?
The hash of the attachment content
final
contentType String?
The MIME type of the attachment
final
description String?
The description of the attachment
final
duration Int32Type?
The duration of the media in seconds
final
expired bool?
Whether the attachment URL has expired
final
expiresAt String?
The ISO 8601 timestamp when the attachment URL expires
final
filename String
The name of the attached file
final
flags MessageAttachmentFlags
final
hashCode int
The hash code for this object.
no setterinherited
height Int32Type?
The height of the attachment in pixels (for images/videos)
final
id String
The unique identifier for this attachment
final
nsfw bool?
Whether the attachment is flagged as NSFW
final
placeholder String?
The base64 encoded placeholder image for lazy loading
final
proxyUrl String?
The proxied URL of the attachment
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size int
The size of the attachment in bytes
final
title String?
The title of the attachment
final
url String?
The URL of the attachment
final
waveform String?
The base64 encoded audio waveform data
final
width Int32Type?
The width of the attachment in pixels (for images/videos)
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited