MessageBaseResponseSchema class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
MessageBaseResponseSchema({required String id, required String channelId, required UserPartialResponse author, required MessageBaseResponseSchemaTypeType type, required MessageFlags flags, required String content, required DateTime timestamp, required bool pinned, required bool mentionEveryone, required bool tts, required List<
UserPartialResponse> mentions, required List<String> mentionRoles, SnowflakeType? webhookId, DateTime? editedTimestamp, List<MessageChannelMentionResponse> ? mentionChannels, List<UserPartialResponse> ? users, List<MessageEmbedResponse> ? embeds, List<MessageAttachmentResponse> ? attachments, List<MessageStickerResponse> ? stickers, List<SnowflakeType> ? nsfwEmojis, List<MessageReactionResponse> ? reactions, MessageReferenceResponse? messageReference, List<MessageSnapshotResponse> ? messageSnapshots, String? nonce, MessageCallResponse? call}) -
const
-
MessageBaseResponseSchema.fromJson(Map<
String, Object?> json) -
factory
Properties
-
attachments
→ List<
MessageAttachmentResponse> ? -
The files attached to the message
final
-
final
- call → MessageCallResponse?
-
Call information if this message represents a call
final
- channelId → String
-
The ID of the channel this message was sent in
final
- content → String
-
The text content of the message
final
- editedTimestamp → DateTime?
-
The ISO 8601 timestamp of when the message was last edited
final
-
embeds
→ List<
MessageEmbedResponse> ? -
The embeds attached to the message
final
- flags → MessageFlags
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The unique identifier (snowflake) for this message
final
-
mentionChannels
→ List<
MessageChannelMentionResponse> ? -
Channels mentioned in the message that are visible to @everyone
final
- mentionEveryone → bool
-
Whether the message mentions @everyone
final
-
mentionRoles
→ List<
String> -
The role IDs mentioned in the message
final
-
mentions
→ List<
UserPartialResponse> -
The users mentioned in the message
final
- messageReference → MessageReferenceResponse?
-
Reference data for replies or forwards
final
-
messageSnapshots
→ List<
MessageSnapshotResponse> ? -
Snapshots of forwarded messages
final
- nonce → String?
-
A client-provided value for message deduplication
final
-
nsfwEmojis
→ List<
SnowflakeType> ? -
IDs of custom emojis in this message that are classified as NSFW
final
- pinned → bool
-
Whether the message is pinned
final
-
reactions
→ List<
MessageReactionResponse> ? -
The reactions on the message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stickers
→ List<
MessageStickerResponse> ? -
The stickers sent with the message
final
- timestamp → DateTime
-
The ISO 8601 timestamp of when the message was created
final
- tts → bool
-
Whether the message was sent as text-to-speech
final
- type → MessageBaseResponseSchemaTypeType
-
The type of message
final
-
users
→ List<
UserPartialResponse> ? -
Users referenced from embed and snapshot text, included for client-side resolution
final
- webhookId → SnowflakeType?
-
The ID of the webhook that sent this message
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited