MessageReferenceResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- MessageReferenceResponse({required String channelId, required String messageId, required MessageReferenceType type, SnowflakeType? guildId})
-
const
-
MessageReferenceResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- channelId → String
-
The ID of the channel containing the referenced message
final
- guildId → SnowflakeType?
-
The ID of the guild containing the referenced message
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- messageId → String
-
The ID of the referenced message
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → MessageReferenceType
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited