MessageSearchResponseMessageSearchResultsResponse class

Annotations
  • @JsonSerializable.new()

Constructors

MessageSearchResponseMessageSearchResultsResponse({required List<MessageSearchResultsResponseMessages> messages, required List<ChannelResponse> channels, required int total, required int hitsPerPage, required int page, required List<String>? cursor})
const
MessageSearchResponseMessageSearchResultsResponse.fromJson(Map<String, dynamic> json)
factory

Properties

channels List<ChannelResponse>
final
cursor List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
hitsPerPage int
final
messages List<MessageSearchResultsResponseMessages>
final
page int
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited