MessageSearchScope enum
Search scope for message searches
Values
- current → const MessageSearchScope
-
const MessageSearchScope('current') - openDms → const MessageSearchScope
-
const MessageSearchScope('open_dms') - allDms → const MessageSearchScope
-
const MessageSearchScope('all_dms') - allGuilds → const MessageSearchScope
-
const MessageSearchScope('all_guilds') - all → const MessageSearchScope
-
const MessageSearchScope('all') - openDmsAndAllGuilds → const MessageSearchScope
-
const MessageSearchScope('open_dms_and_all_guilds') - $unknown → const MessageSearchScope
-
Default value for all unparsed values, allows backward compatibility when adding new values on the backend.
const MessageSearchScope(null)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- json → String?
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
$valuesDefined
→ List<
MessageSearchScope> -
Returns all defined enum values excluding the $unknown value.
no setter
Constants
-
values
→ const List<
MessageSearchScope> - A constant List of the values in this enum, in order of their declaration.