MessageShredStatusProgressResponse class

Annotations
  • @JsonSerializable.new()

Constructors

MessageShredStatusProgressResponse({required MessageShredStatusProgressResponseStatusStatus status, required Int32Type requested, required Int32Type total, required Int32Type processed, required Int32Type skipped, String? startedAt, String? completedAt, String? failedAt, String? error})
const
MessageShredStatusProgressResponse.fromJson(Map<String, Object?> json)
factory

Properties

completedAt String?
final
error String?
final
failedAt String?
final
hashCode int
The hash code for this object.
no setterinherited
processed Int32Type
final
requested Int32Type
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skipped Int32Type
final
startedAt String?
final
status MessageShredStatusProgressResponseStatusStatus
Current message shred job status
final
total Int32Type
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited