MessageShredStatusResponseMessageShredStatusProgressResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- MessageShredStatusResponseMessageShredStatusProgressResponse({required MessageShredStatusProgressResponseStatusStatus status, required Int32Type requested, required Int32Type total, required Int32Type processed, required Int32Type skipped, required String? startedAt, required String? completedAt, required String? failedAt, required String? error})
-
const
-
MessageShredStatusResponseMessageShredStatusProgressResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- completedAt → String?
-
final
- error → String?
-
final
- failedAt → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- processed → Int32Type
-
final
- requested → Int32Type
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- skipped → Int32Type
-
final
- startedAt → String?
-
final
- status → MessageShredStatusProgressResponseStatusStatus
-
final
- total → Int32Type
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited