MessageSnapshotResponse class

Annotations
  • @JsonSerializable.new()

Constructors

MessageSnapshotResponse({required DateTime timestamp, required MessageSnapshotResponseTypeType type, required MessageFlags flags, String? content, DateTime? editedTimestamp, List<String>? mentions, List<String>? mentionRoles, List<MessageChannelMentionResponse>? mentionChannels, List<MessageEmbedResponse>? embeds, List<MessageAttachmentResponse>? attachments, List<MessageStickerResponse>? stickers})
const
MessageSnapshotResponse.fromJson(Map<String, Object?> json)
factory

Properties

attachments List<MessageAttachmentResponse>?
The attachments included in the snapshot
final
content String?
The text content of the snapshot
final
editedTimestamp DateTime?
The ISO 8601 timestamp of when the original message was last edited
final
embeds List<MessageEmbedResponse>?
The embeds included in the snapshot
final
flags MessageFlags
final
hashCode int
The hash code for this object.
no setterinherited
mentionChannels List<MessageChannelMentionResponse>?
Channels mentioned in the snapshot that are visible to @everyone
final
mentionRoles List<String>?
The role IDs mentioned in the snapshot
final
mentions List<String>?
The user IDs mentioned in the snapshot
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stickers List<MessageStickerResponse>?
The stickers included in the snapshot
final
timestamp DateTime
The ISO 8601 timestamp of when the original message was created
final
type MessageSnapshotResponseTypeType
The type of message
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited