MobileDeviceItemResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- MobileDeviceItemResponse({required String deviceId, required String platform, required String? appId, required String? providerEnvironment, required String? userAgent})
-
const
-
MobileDeviceItemResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- appId → String?
-
Client app channel or bundle mapping identifier for this device
final
- deviceId → String
-
The unique identifier for the device
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- platform → String
-
The mobile push notification platform
final
- providerEnvironment → String?
-
Push provider environment used for this device
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- userAgent → String?
-
The user agent that registered this device
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited