OAuth2TokenResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- OAuth2TokenResponse({required String accessToken, required String tokenType, required int expiresIn, required String refreshToken, required String scope})
-
const
-
OAuth2TokenResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- accessToken → String
-
The access token for API authorization
final
- expiresIn → int
-
The number of seconds until the access token expires
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- refreshToken → String
-
The refresh token for obtaining new access tokens
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scope → String
-
The space-separated list of granted scopes
final
- tokenType → String
-
The type of token, typically "Bearer"
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited