PackInviteResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- PackInviteResponse({required String code, required PackInviteResponseTypeType type, required PackInviteResponsePack pack, required bool temporary, UserPartialResponse? inviter, DateTime? expiresAt})
-
const
-
PackInviteResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- code → String
-
The unique invite code
final
- expiresAt → DateTime?
-
ISO8601 timestamp of when the invite expires
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inviter → UserPartialResponse?
-
The user who created the invite
final
- pack → PackInviteResponsePack
-
The pack this invite is for
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- temporary → bool
-
Whether the invite grants temporary access
final
- type → PackInviteResponseTypeType
-
The type of pack invite (emoji or sticker pack)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited