PasswordChangeCompleteRequest class

Annotations
  • @JsonSerializable.new()

Constructors

PasswordChangeCompleteRequest({required String ticket, required String verificationProof, required PasswordType newPassword})
const
PasswordChangeCompleteRequest.fromJson(Map<String, Object?> json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
newPassword PasswordType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
ticket String
Password change ticket identifier
final
verificationProof String
Proof token obtained from verifying the email code
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited