PhoneSendVerificationRequest class

Annotations
  • @JsonSerializable.new()

Properties

channel PhoneSendVerificationRequestChannelChannel?
Channel to deliver the OTP on. Defaults to the first available channel from server policy. Server may override to an available fallback when the requested channel is disabled.
final
hashCode int
The hash code for this object.
no setterinherited
phone PhoneNumberType
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited