PhoneSendVerificationResponseInboundChallenge class

Inheritance
Available extensions
Annotations
  • @JsonSerializable.new()

Properties

challengeCode String
final
channel PhoneSendVerificationInboundChallengeResponseChannelChannel
final
expiresAt DateTime
final
hashCode int
The hash code for this object.
no setterinherited
ourNumber String
final
reason PhoneSendVerificationInboundChallengeResponseReasonReason
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited