PremiumEffectiveState class
- Annotations
-
- @JsonSerializable.new()
Constructors
- PremiumEffectiveState({required bool isPremium, required bool selfHosted, required bool bot})
-
const
-
PremiumEffectiveState.fromJson(Map<
String, Object?> json) -
factory
Properties
- bot → bool
-
Whether the account is a bot account with premium-equivalent service access
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPremium → bool
-
Whether premium perks are currently effective for product gating
final
-
Effective recurring billing cycle, when known
final
-
Whether backend premium override is enabled
final
-
Effective grace timestamp exposed to the client
final
-
Effective Visionary sequence number, when applicable
final
-
Whether the user temporarily disabled premium perks
final
-
Whether premium purchase is disabled for this account
final
-
Effective premium start timestamp exposed to the client
final
-
Effective premium type used by product gates
final
-
Effective premium end timestamp exposed to the client
final
-
Effective cancellation status exposed to the client
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selfHosted → bool
-
Whether the instance treats all users as premium because it is self-hosted
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited