PremiumStateResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- PremiumStateResponse({required PremiumStateResponseActual actual, required PremiumStateResponseEffective effective, required PremiumStateResponseBilling billing, required PremiumPricingState pricing})
-
const
-
PremiumStateResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- actual → PremiumStateResponseActual
-
final
- billing → PremiumStateResponseBilling
-
final
- effective → PremiumStateResponseEffective
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- pricing → PremiumPricingState
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited