PushRotateRequest class

Annotations
  • @JsonSerializable.new()

Constructors

PushRotateRequest({required String oldEndpoint, required String endpoint, required PushRotateRequestKeys keys, String? userAgent})
const
PushRotateRequest.fromJson(Map<String, Object?> json)
factory

Properties

endpoint String
The new push subscription endpoint URL
final
hashCode int
The hash code for this object.
no setterinherited
keys PushRotateRequestKeys
Encryption keys for the new push subscription
final
oldEndpoint String
The previous push subscription endpoint URL being rotated out
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userAgent String?
The user agent string identifying the client
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited