RegisterMobileDeviceRequest class

Annotations
  • @JsonSerializable.new()

Constructors

RegisterMobileDeviceRequest({required RegisterMobileDeviceRequestPlatformPlatform platform, required String token, String? userAgent, String? appId, MobilePushProviderEnvironmentSchema? providerEnvironment, String? encryptionKey, String? authSecret})
const
RegisterMobileDeviceRequest.fromJson(Map<String, Object?> json)
factory

Properties

appId String?
Client app channel or bundle mapping identifier, such as stable, beta, or canary
final
authSecret String?
The authentication secret for UnifiedPush encryption (base64url)
final
encryptionKey String?
The P-256 ECDH public key for UnifiedPush encryption (base64url)
final
hashCode int
The hash code for this object.
no setterinherited
platform RegisterMobileDeviceRequestPlatformPlatform
The mobile push notification platform
final
providerEnvironment MobilePushProviderEnvironmentSchema?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
The platform-specific push notification token or endpoint URL
final
userAgent String?
The user agent string identifying the device
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited