RegisterRequest class

Annotations
  • @JsonSerializable.new()

Constructors

RegisterRequest({required String dateOfBirth, required bool consent, EmailType? email, UsernameType? username, String? globalName, PasswordType? password, String? inviteCode})
const
RegisterRequest.fromJson(Map<String, Object?> json)
factory

Properties

Whether user consents to terms of service
final
dateOfBirth String
Date of birth in YYYY-MM-DD format
final
email EmailType?
final
globalName String?
Display name shown to other users
final
hashCode int
The hash code for this object.
no setterinherited
inviteCode String?
Guild invite code to join after registration
final
password PasswordType?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username UsernameType?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited