RelationshipResponse class
Properties
-
friendSharesVoiceActivity
→ bool
-
Whether this friend has chosen to share their voice activity with the current user; for non-friend types this is always true
final
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
id
→ String
-
The unique identifier for the relationship
final
-
nickname
→ String?
-
A custom nickname set for the related user
final
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
shareVoiceActivity
→ bool
-
Whether the current user has chosen to share their voice activity with this friend on the Active Now panel
final
-
since
→ DateTime?
-
ISO8601 timestamp of when the relationship was established
final
-
type
→ RelationshipTypes
-
The type of relationship (friend, blocked, pending, etc.)
final
-
user
→ UserPartialResponse
-
final