ReportAdminResponseSchema class

Annotations
  • @JsonSerializable.new()

Constructors

ReportAdminResponseSchema({required String? additionalInfo, required SnowflakeType? reporterId, required String? reporterTag, required String? reporterUsername, required String? reporterGlobalName, required String? reporterDiscriminator, required String? reporterEmail, required String? reporterFullLegalName, required String? reporterCountryOfResidence, required String reportedAt, required ReportStatus status, required ReportType reportType, required String? category, required SnowflakeType reportId, required SnowflakeType? reportedUserId, required String? reportedUserTag, required String? reportedUserUsername, required String? reportedUserGlobalName, required String? reportedUserDiscriminator, required String? reportedUserAvatarHash, required SnowflakeType? reportedGuildId, required String? reportedGuildName, required SnowflakeType? reportedMessageId, required SnowflakeType? reportedChannelId, required String? reportedChannelName, required bool? reportedChannelNsfw, required String? reportedGuildInviteCode, required String? publicComment, required SnowflakeType? resolvedByAdminId, required NsfwLevel? reportedGuildNsfwLevel, required String? resolvedAt, bool? reportedChannelNsfwOverride, ContentWarningLevel? reportedChannelContentWarningLevel, String? reportedChannelContentWarningText, bool? reportedChannelEffectiveNsfw, ContentWarningLevel? reportedChannelEffectiveContentWarningLevel, String? reportedChannelEffectiveContentWarningText, ContentWarningLevel? reportedGuildContentWarningLevel, bool? reportedGuildNsfw, List<ReportAdminResponseSchemaMessageContext>? messageContext, SnowflakeType? mutualDmChannelId, String? reportedGuildContentWarningText})
const
ReportAdminResponseSchema.fromJson(Map<String, Object?> json)
factory

Properties

additionalInfo String?
final
category String?
final
hashCode int
The hash code for this object.
no setterinherited
messageContext List<ReportAdminResponseSchemaMessageContext>?
final
mutualDmChannelId SnowflakeType?
final
publicComment String?
final
reportedAt String
final
reportedChannelContentWarningLevel ContentWarningLevel?
final
reportedChannelContentWarningText String?
final
reportedChannelEffectiveContentWarningLevel ContentWarningLevel?
final
reportedChannelEffectiveContentWarningText String?
final
reportedChannelEffectiveNsfw bool?
final
reportedChannelId SnowflakeType?
final
reportedChannelName String?
final
reportedChannelNsfw bool?
final
reportedChannelNsfwOverride bool?
final
reportedGuildContentWarningLevel ContentWarningLevel?
final
reportedGuildContentWarningText String?
final
reportedGuildId SnowflakeType?
final
reportedGuildInviteCode String?
final
reportedGuildName String?
final
reportedGuildNsfw bool?
final
reportedGuildNsfwLevel NsfwLevel?
final
reportedMessageId SnowflakeType?
final
reportedUserAvatarHash String?
final
reportedUserDiscriminator String?
final
reportedUserGlobalName String?
final
reportedUserId SnowflakeType?
final
reportedUserTag String?
final
reportedUserUsername String?
final
reporterCountryOfResidence String?
final
reporterDiscriminator String?
final
reporterEmail String?
final
reporterFullLegalName String?
final
reporterGlobalName String?
final
reporterId SnowflakeType?
final
reporterTag String?
final
reporterUsername String?
final
reportId SnowflakeType
final
reportType ReportType
final
resolvedAt String?
final
resolvedByAdminId SnowflakeType?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status ReportStatus
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited