ReportAdminResponseSchemaMessageContext class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
ReportAdminResponseSchemaMessageContext({required SnowflakeType id, required SnowflakeType channelId, required bool? channelNsfw, required SnowflakeType? guildId, required NsfwLevel? guildNsfwLevel, required String content, required String timestamp, required List<
ReportAdminResponseSchemaMessageContextAttachments> attachments, required SnowflakeType authorId, required String authorUsername, required String? authorGlobalName, required String authorDiscriminator, required String? authorAvatar, ContentWarningLevel? channelContentWarningLevel, String? channelContentWarningText, bool? guildNsfw, ContentWarningLevel? guildContentWarningLevel, String? guildContentWarningText, List<String> ? userPriorNcmecReportIds}) -
const
-
ReportAdminResponseSchemaMessageContext.fromJson(Map<
String, Object?> json) -
factory
Properties
-
attachments
→ List<
ReportAdminResponseSchemaMessageContextAttachments> -
final
-
final
-
final
-
final
-
final
-
final
- channelContentWarningLevel → ContentWarningLevel?
-
final
- channelContentWarningText → String?
-
final
- channelId → SnowflakeType
-
final
- channelNsfw → bool?
-
final
- content → String
-
final
- guildContentWarningLevel → ContentWarningLevel?
-
final
- guildContentWarningText → String?
-
final
- guildId → SnowflakeType?
-
final
- guildNsfw → bool?
-
final
- guildNsfwLevel → NsfwLevel?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → SnowflakeType
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → String
-
final
-
userPriorNcmecReportIds
→ List<
String> ? -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited