ReportResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- ReportResponse({required String reportId, required String status, required String reportedAt})
-
const
-
ReportResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- reportedAt → String
-
ISO 8601 timestamp when the report was submitted
final
- reportId → String
-
The unique identifier for this report
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → String
-
Current status of the report (pending, reviewed, resolved)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited