RichEmbedRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
RichEmbedRequest({String? url, String? title, int? color, dynamic timestamp, String? description, RichEmbedAuthorRequest? author, RichEmbedMediaRequest? image, RichEmbedMediaRequest? thumbnail, List<
RichEmbedFieldRequest> ? fields}) -
const
-
RichEmbedRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
-
Author information
final
- color → int?
-
Color code of the embed (hex integer)
final
- description → String?
-
Description of the embed (1-4096 characters)
final
-
fields
→ List<
RichEmbedFieldRequest> ? -
Array of field objects (max 25)
final
-
Footer information
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- image → RichEmbedMediaRequest?
-
Image to display in the embed
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- thumbnail → RichEmbedMediaRequest?
-
Thumbnail image for the embed
final
- timestamp → dynamic
-
ISO8601 timestamp for the embed
final
- title → String?
-
Title of the embed (0-256 characters)
final
- url → String?
-
URL of the embed
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited