ScheduledMessageResponseSchema class
- Annotations
-
- @JsonSerializable.new()
Constructors
- ScheduledMessageResponseSchema({required String id, required String channelId, required String scheduledAt, required String scheduledLocalAt, required String timezone, required ScheduledMessageResponseSchemaStatusStatus status, required String? statusReason, required ScheduledMessageResponseSchemaPayload payload, required String createdAt, required String? invalidatedAt})
-
const
-
ScheduledMessageResponseSchema.fromJson(Map<
String, Object?> json) -
factory
Properties
- channelId → String
-
The ID of the channel this message will be sent to
final
- createdAt → String
-
The ISO 8601 timestamp when this scheduled message was created
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The unique identifier for this scheduled message
final
- invalidatedAt → String?
-
The ISO 8601 timestamp when the message was marked invalid
final
- payload → ScheduledMessageResponseSchemaPayload
-
The message content and metadata to be sent
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- scheduledAt → String
-
The ISO 8601 UTC timestamp when the message is scheduled to be sent
final
- scheduledLocalAt → String
-
The ISO 8601 timestamp in the user local timezone
final
- status → ScheduledMessageResponseSchemaStatusStatus
-
The current status of the scheduled message
final
- statusReason → String?
-
A human-readable reason for the current status, if applicable
final
- timezone → String
-
The IANA timezone identifier used for scheduling
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited