SendSystemDmRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
SendSystemDmRequest({required String content, required List<
SnowflakeType> userIds}) -
const
-
SendSystemDmRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- content → String
-
Message content to send to each recipient
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
userIds
→ List<
SnowflakeType> -
Recipient user IDs. Each receives the same content as a system DM.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited