SlackWebhookRequestAttachments class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
SlackWebhookRequestAttachments({String? fallback, String? pretext, String? text, String? color, String? title, String? titleLink, List<
SlackWebhookRequestAttachmentsFields> ? fields, int? ts, String? authorName, String? authorLink, String? authorIcon, String? imageUrl, String? thumbUrl}) -
const
-
SlackWebhookRequestAttachments.fromJson(Map<
String, Object?> json) -
factory
Properties
-
URL for the author icon image
final
-
URL to link from the author name
final
-
Name of the author
final
- color → String?
-
Colour of the attachment sidebar (hex code or preset)
final
- fallback → String?
-
Fallback text for notifications
final
-
fields
→ List<
SlackWebhookRequestAttachmentsFields> ? -
Array of field objects
final
-
Footer text displayed at the bottom
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- imageUrl → String?
-
URL of the main image to display
final
- pretext → String?
-
Text that appears above the attachment block
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
Main text content of the attachment
final
- thumbUrl → String?
-
URL of a thumbnail image
final
- title → String?
-
Title of the attachment
final
- titleLink → String?
-
URL to link from the title
final
- ts → int?
-
Unix timestamp for the attachment footer
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited