SortBy enum

Sort order

Inheritance
Available extensions
Annotations
  • @JsonEnum.new()

Values

memberCount → const SortBy
const SortBy('member_count')
onlineCount → const SortBy
const SortBy('online_count')
relevance → const SortBy
const SortBy('relevance')
$unknown → const SortBy

Default value for all unparsed values, allows backward compatibility when adding new values on the backend.

const SortBy(null)

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
json String?
final
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() String
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

$valuesDefined List<SortBy>
Returns all defined enum values excluding the $unknown value.
no setter

Constants

values → const List<SortBy>
A constant List of the values in this enum, in order of their declaration.