TemplatePermissionOverwrite class
- Annotations
-
- @JsonSerializable.new()
Constructors
- TemplatePermissionOverwrite({required dynamic id, required dynamic type, required dynamic allow, required dynamic deny})
-
const
-
TemplatePermissionOverwrite.fromJson(Map<
String, Object?> json) -
factory
Properties
- allow → dynamic
-
The allowed permissions bitfield as a string
final
- deny → dynamic
-
The denied permissions bitfield as a string
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → dynamic
-
The ID of the role or user for this overwrite
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → dynamic
-
The type of overwrite (0/role = role, 1/member = member)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited