UpdateVoiceServerRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
UpdateVoiceServerRequest({required String regionId, required String serverId, String? endpoint, String? apiKey, String? apiSecret, num? latitude, num? longitude, bool? isActive, bool? vipOnly, List<
String> ? requiredGuildFeatures, List<SnowflakeType> ? allowedGuildIds, List<SnowflakeType> ? allowedUserIds}) -
const
-
UpdateVoiceServerRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
-
allowedGuildIds
→ List<
SnowflakeType> ? -
Guild IDs explicitly allowed to use this server
final
-
allowedUserIds
→ List<
SnowflakeType> ? -
User IDs explicitly allowed to use this server
final
- apiKey → String?
-
API key for authenticating with the voice server
final
- apiSecret → String?
-
API secret for authenticating with the voice server
final
- endpoint → String?
-
Client signal WebSocket endpoint URL for the voice server
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isActive → bool?
-
Whether the server is currently active
final
- latitude → num?
-
Optional geographic latitude override for this server
final
- longitude → num?
-
Optional geographic longitude override for this server
final
- regionId → String
-
ID of the region this server belongs to
final
-
requiredGuildFeatures
→ List<
String> ? -
Guild features required to use this server
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- serverId → String
-
Unique identifier for the voice server
final
- vipOnly → bool?
-
Whether this server is restricted to VIP users
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited