UserGuildSettingsResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
UserGuildSettingsResponse({required SnowflakeType? guildId, required UserNotificationSettings messageNotifications, required bool muted, required UserGuildSettingsResponseMuteConfig? muteConfig, required bool mobilePush, required bool suppressEveryone, required bool suppressRoles, required bool hideMutedChannels, required Map<
String, ChannelOverrides> ? channelOverrides, required int version, UserNotificationSettings? unreadBadges}) -
const
-
UserGuildSettingsResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
-
channelOverrides
→ Map<
String, ChannelOverrides> ? -
Per-channel notification overrides
final
- guildId → SnowflakeType?
-
The ID of the guild these settings apply to
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideMutedChannels → bool
-
Whether muted channels are hidden in the sidebar
final
- messageNotifications → UserNotificationSettings
-
The default notification level for the guild
final
- mobilePush → bool
-
Whether mobile push notifications are enabled
final
- muteConfig → UserGuildSettingsResponseMuteConfig?
-
The mute configuration for the guild
final
- muted → bool
-
Whether the guild is muted
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suppressEveryone → bool
-
Whether @everyone mentions are suppressed
final
- suppressRoles → bool
-
Whether role mentions are suppressed
final
- unreadBadges → UserNotificationSettings?
-
Default unread badges level for the guild
final
- version → int
-
The version number of these settings for sync
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited