UserGuildSettingsUpdateRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
UserGuildSettingsUpdateRequest({UserNotificationSettings? messageNotifications, bool? muted, UserGuildSettingsUpdateRequestMuteConfig? muteConfig, bool? mobilePush, bool? suppressEveryone, bool? suppressRoles, bool? hideMutedChannels, Map<
String, ChannelOverrides> ? channelOverrides, UserNotificationSettings? unreadBadges}) -
const
-
UserGuildSettingsUpdateRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
-
channelOverrides
→ Map<
String, ChannelOverrides> ? -
Per-channel overrides
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hideMutedChannels → bool?
-
Hide muted channels
final
- messageNotifications → UserNotificationSettings?
-
Default guild notification level
final
- mobilePush → bool?
-
Mobile push notifications enabled
final
- muteConfig → UserGuildSettingsUpdateRequestMuteConfig?
-
Guild mute configuration
final
- muted → bool?
-
Guild muted
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suppressEveryone → bool?
-
Suppress @everyone mentions
final
- suppressRoles → bool?
-
Suppress role mentions
final
- unreadBadges → UserNotificationSettings?
-
Default unread badges level for the guild
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited