UserNotificationSettings enum
Notification level preference
Values
- allMessages → const UserNotificationSettings
-
const UserNotificationSettings(0) - onlyMentions → const UserNotificationSettings
-
const UserNotificationSettings(1) - noMessages → const UserNotificationSettings
-
const UserNotificationSettings(2) - inherit → const UserNotificationSettings
-
const UserNotificationSettings(3) - $unknown → const UserNotificationSettings
-
Default value for all unparsed values, allows backward compatibility when adding new values on the backend.
const UserNotificationSettings(null)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- json → int?
-
final
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → int? -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
$valuesDefined
→ List<
UserNotificationSettings> -
Returns all defined enum values excluding the $unknown value.
no setter
Constants
-
values
→ const List<
UserNotificationSettings> - A constant List of the values in this enum, in order of their declaration.