UserPartialResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- UserPartialResponse({required String id, required String username, required String discriminator, required String? globalName, required String? avatar, required Int32Type? avatarColor, required PublicUserFlags flags, bool? bot, bool? system, MentionReplyPreferences? mentionFlags})
-
const
-
UserPartialResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- avatar → String?
-
The hash of the user avatar image
final
- avatarColor → Int32Type?
-
The dominant avatar color of the user as an integer
final
- bot → bool?
-
Whether the user is a bot account
final
- discriminator → String
-
The four-digit discriminator tag of the user
final
- flags → PublicUserFlags
-
final
- globalName → String?
-
The display name of the user, if set
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → String
-
The unique identifier (snowflake) for this user
final
- mentionFlags → MentionReplyPreferences?
-
The user's account-wide reply mention preference
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- system → bool?
-
Whether the user is an official system user
final
- username → String
-
The username of the user, not unique across the platform
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited