UserProfileFullResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
UserProfileFullResponse({required UserProfileFullResponseUser user, required UserProfileFullResponseUserProfile userProfile, GuildMemberResponse? guildMember, UserProfileFullResponseGuildMemberProfile? guildMemberProfile, List<
UserPartialResponse> ? mutualFriends, List<MutualGuildResponse> ? mutualGuilds, List<ConnectionResponse> ? connectedAccounts}) -
const
-
UserProfileFullResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
-
connectedAccounts
→ List<
ConnectionResponse> ? -
Array of verified external connections
final
- guildMember → GuildMemberResponse?
-
final
- guildMemberProfile → UserProfileFullResponseGuildMemberProfile?
-
Guild-specific profile data
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mutualFriends
→ List<
UserPartialResponse> ? -
Array of mutual friends
final
-
mutualGuilds
→ List<
MutualGuildResponse> ? -
Array of mutual guilds
final
-
final
-
ISO8601 timestamp of when premium was activated
final
-
The type of premium subscription
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- user → UserProfileFullResponseUser
-
The user object
final
- userProfile → UserProfileFullResponseUserProfile
-
The user profile data
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited