UserSessionResponse class
- Annotations
-
- @JsonSerializable.new()
Constructors
- UserSessionResponse({required String sessionIdHash, required String createdAt, required String approxLastUsedAt, required String clientIp, required String? clientIpReverse, required String? clientOs, required String? clientPlatform, required String? clientLocation})
-
const
-
UserSessionResponse.fromJson(Map<
String, Object?> json) -
factory
Properties
- approxLastUsedAt → String
-
ISO timestamp of the session last usage (approximate)
final
- clientIp → String
-
Client IP address
final
- clientIpReverse → String?
-
Reverse DNS hostname for the client IP (PTR), if available
final
- clientLocation → String?
-
Approximate geo location label for the client IP, if available
final
- clientOs → String?
-
Client operating system, if detected
final
- clientPlatform → String?
-
Client platform, if detected
final
- createdAt → String
-
ISO timestamp when the session was created
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionIdHash → String
-
Hashed session identifier (base64url)
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited