UserSettingsUpdateRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
-
UserSettingsUpdateRequest({bool? inlineEmbedMedia, UserStatusType? status, dynamic statusResetsAt, UserStatusType? statusResetsTo, UserThemeType? theme, Locale? locale, List<
SnowflakeType> ? restrictedGuilds, List<SnowflakeType> ? botRestrictedGuilds, bool? defaultGuildsRestricted, bool? botDefaultGuildsRestricted, bool? inlineAttachmentMedia, FriendSourceFlags? flags, bool? gifAutoPlay, bool? renderEmbeds, bool? renderReactions, bool? animateEmoji, StickerAnimationOptions? animateStickers, RenderSpoilers? renderSpoilers, bool? messageDisplayCompact, FriendSourceFlags? friendSourceFlags, IncomingCallFlags? incomingCallFlags, GroupDmAddPermissionFlags? groupDmAddPermissionFlags, List<UserSettingsUpdateRequestGuildFolders> ? guildFolders, String? syncedPreferences, int? afkTimeout, TimeFormatTypes? timeFormat, bool? developerMode, List<String> ? trustedDomains, bool? defaultHideMutedChannels, SensitiveMediaFilterLevel? sensitiveContentFriendDmFilter, SensitiveMediaFilterLevel? sensitiveContentNonFriendDmFilter, SensitiveMediaGuildFilterLevel? sensitiveContentGuildFilter, bool? suppressUnprivilegedSelfMentions, List<SnowflakeType> ? suppressUnprivilegedSelfMentionsBypassUserIds, List<SnowflakeType> ? staffDmAccessUserIds, CustomStatusPayload? customStatus}) -
const
-
UserSettingsUpdateRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- afkTimeout → int?
-
AFK timeout in seconds
final
- animateEmoji → bool?
-
Animate custom emoji
final
- animateStickers → StickerAnimationOptions?
-
Sticker animation preference
final
- botDefaultGuildsRestricted → bool?
-
Default bot DM restriction for new guilds
final
-
botRestrictedGuilds
→ List<
SnowflakeType> ? -
Guilds with bot DM restrictions
final
- customStatus → CustomStatusPayload?
-
Custom status
final
- defaultGuildsRestricted → bool?
-
Default DM restriction for new guilds
final
- defaultHideMutedChannels → bool?
-
Hide muted channels by default in new guilds
final
- developerMode → bool?
-
Developer mode enabled
final
- flags → FriendSourceFlags?
-
final
- friendSourceFlags → FriendSourceFlags?
-
final
- gifAutoPlay → bool?
-
Auto-play GIFs
final
- groupDmAddPermissionFlags → GroupDmAddPermissionFlags?
-
final
-
guildFolders
→ List<
UserSettingsUpdateRequestGuildFolders> ? -
Guild folder organization
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- incomingCallFlags → IncomingCallFlags?
-
final
- inlineAttachmentMedia → bool?
-
Display attachments inline
final
- inlineEmbedMedia → bool?
-
Display embed media inline
final
- locale → Locale?
-
final
- messageDisplayCompact → bool?
-
Compact message display
final
- renderEmbeds → bool?
-
Render message embeds
final
- renderReactions → bool?
-
Display reactions
final
- renderSpoilers → RenderSpoilers?
-
Spoiler rendering preference
final
-
restrictedGuilds
→ List<
SnowflakeType> ? -
Guilds with DM restrictions
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sensitiveContentFriendDmFilter → SensitiveMediaFilterLevel?
-
Sensitive media filter level for DMs from friends
final
- sensitiveContentGuildFilter → SensitiveMediaGuildFilterLevel?
-
Sensitive media filter level for community channels
final
- sensitiveContentNonFriendDmFilter → SensitiveMediaFilterLevel?
-
Sensitive media filter level for DMs from non-friends
final
-
staffDmAccessUserIds
→ List<
SnowflakeType> ? -
User IDs with Staff DM Access enabled
final
- status → UserStatusType?
-
final
- statusResetsAt → dynamic
-
When status resets
final
- statusResetsTo → UserStatusType?
-
final
- suppressUnprivilegedSelfMentions → bool?
-
Suppress direct mentions and reply mentions from unprivileged users
final
-
suppressUnprivilegedSelfMentionsBypassUserIds
→ List<
SnowflakeType> ? -
User IDs that bypass self-mention suppression
final
- syncedPreferences → String?
-
Account-wide client preferences as a base64-encoded protobuf snapshot. Replaces the entire stored snapshot; pass null to clear it.
final
- theme → UserThemeType?
-
final
- timeFormat → TimeFormatTypes?
-
Time format preference
final
-
trustedDomains
→ List<
String> ? -
Trusted external link domains. Use "*" to trust all domains.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited