UserUpdateWithVerificationRequest class
- Annotations
-
- @JsonSerializable.new()
Constructors
- UserUpdateWithVerificationRequest({UsernameType? username, String? discriminator, String? globalName, EmailType? email, PasswordType? newPassword, PasswordType? password, Base64ImageType? avatar, Base64ImageType? banner, String? bio, String? pronouns, int? accentColor, bool? hasDismissedPremiumOnboarding, bool? hasUnreadGiftInventory, MentionReplyPreferences? mentionFlags, String? emailToken, UserUpdateWithVerificationRequestMfaMethodMfaMethod? mfaMethod, String? mfaCode, dynamic webauthnResponse, String? webauthnChallenge})
-
const
-
UserUpdateWithVerificationRequest.fromJson(Map<
String, Object?> json) -
factory
Properties
- accentColor → int?
-
Profile accent color as integer
final
- avatar → Base64ImageType?
-
Base64-encoded avatar image
final
-
Base64-encoded profile banner image
final
- bio → String?
-
User biography text (max 320 characters)
final
- discriminator → String?
-
The 4-digit discriminator tag
final
- email → EmailType?
-
final
- emailToken → String?
-
Email change token for updating email
final
- globalName → String?
-
The display name shown to other users
final
- hasDismissedPremiumOnboarding → bool?
-
Whether user dismissed premium onboarding
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasUnreadGiftInventory → bool?
-
Whether user has unread gifts
final
- mentionFlags → MentionReplyPreferences?
-
Account-wide reply mention preference (NO_PREFERENCE, PREFER_MENTION, PREFER_NO_MENTION)
final
- mfaCode → String?
-
MFA verification code from an authenticator app
final
- mfaMethod → UserUpdateWithVerificationRequestMfaMethodMfaMethod?
-
MFA method to use for verification
final
- newPassword → PasswordType?
-
final
- password → PasswordType?
-
final
-
Whether to hide the premium badge
final
-
Whether to mask the premium badge
final
-
Whether to hide premium badge sequence
final
-
Whether to hide premium badge timestamp
final
-
Override premium enabled state
final
- pronouns → String?
-
User pronouns (max 40 characters)
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- username → UsernameType?
-
final
- webauthnChallenge → String?
-
WebAuthn challenge string
final
- webauthnResponse → dynamic
-
WebAuthn authentication response
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, Object?> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited