ValidationErrorItem class

Annotations
  • @JsonSerializable.new()

Constructors

ValidationErrorItem({required String path, required String message, ValidationErrorCodeSchema? code})
const
ValidationErrorItem.fromJson(Map<String, Object?> json)
factory

Properties

code ValidationErrorCodeSchema?
final
hashCode int
The hash code for this object.
no setterinherited
message String
A human-readable description of the validation issue
final
path String
The field path where the validation error occurred
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited