VoiceDebugLoggingToggleBodySchema class

Annotations
  • @JsonSerializable.new()

Constructors

VoiceDebugLoggingToggleBodySchema({required bool enabled, int? durationMs})
const
VoiceDebugLoggingToggleBodySchema.fromJson(Map<String, Object?> json)
factory

Properties

durationMs int?
Optional activation duration in milliseconds. Defaults to one hour and is capped at four hours.
final
enabled bool
Whether voice debug logging should be active for this channel
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited