WebAuthnCredentialResponse class

Annotations
  • @JsonSerializable.new()

Constructors

WebAuthnCredentialResponse({required String id, required String name, required String createdAt, required String? lastUsedAt})
const
WebAuthnCredentialResponse.fromJson(Map<String, Object?> json)
factory

Properties

createdAt String
When the credential was registered
final
hashCode int
The hash code for this object.
no setterinherited
id String
The credential ID
final
lastUsedAt String?
When the credential was last used
final
name String
User-assigned name for the credential
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited