WebAuthnRegisterRequest class

Annotations
  • @JsonSerializable.new()

Constructors

WebAuthnRegisterRequest({required dynamic response, required String challenge, required String name, PasswordType? password, WebAuthnRegisterRequestMfaMethodMfaMethod? mfaMethod, String? mfaCode, dynamic webauthnResponse, String? webauthnChallenge})
const
WebAuthnRegisterRequest.fromJson(Map<String, Object?> json)
factory

Properties

challenge String
The challenge from registration options
final
hashCode int
The hash code for this object.
no setterinherited
mfaCode String?
MFA verification code from an authenticator app
final
mfaMethod WebAuthnRegisterRequestMfaMethodMfaMethod?
MFA method to use for verification
final
name String
User-assigned name for the credential
final
password PasswordType?
final
response → dynamic
WebAuthn registration response
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
webauthnChallenge String?
WebAuthn challenge string
final
webauthnResponse → dynamic
WebAuthn authentication response
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited