WebhookResponse class

Annotations
  • @JsonSerializable.new()

Constructors

WebhookResponse({required String id, required String guildId, required String channelId, required String name, required String token, required UserPartialResponse user, String? avatar})
const
WebhookResponse.fromJson(Map<String, Object?> json)
factory

Properties

avatar String?
The hash of the webhook avatar image
final
channelId String
The ID of the channel this webhook posts to
final
guildId String
The ID of the guild this webhook belongs to
final
hashCode int
The hash code for this object.
no setterinherited
id String
The unique identifier (snowflake) for the webhook
final
name String
The display name of the webhook
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
token String
The secure token used to execute the webhook
final
user UserPartialResponse
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, Object?>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited