reportMessage abstract method
- @POST.new('/reports/message')
- @Body.new() required ReportMessageRequest body,
Report message.
Submits a report about a message to moderators for content violation review. The reporter must be able to access the channel and target message.
body - Name not received - field will be skipped.
Implementation
@POST('/reports/message')
Future<ReportResponse> reportMessage({
@Body() required ReportMessageRequest body,
});