pinDirectMessageChannel abstract method
- @PUT.new('/users/@me/channels/{channel_id}/pin')
- @Path.new('channel_id') required SnowflakeType channelId,
Pin direct message channel.
Pins a private message channel for the current user. Pinned channels appear at the top of the channel list for easy access.
channelId - The ID of the channel.
Implementation
@PUT('/users/@me/channels/{channel_id}/pin')
Future<void> pinDirectMessageChannel({
@Path('channel_id') required SnowflakeType channelId,
});