sendFriendRequest abstract method

  1. @POST.new('/users/@me/relationships/{user_id}')
Future<RelationshipResponse> sendFriendRequest({
  1. @Path.new('user_id') required SnowflakeType userId,
  2. @Body.new() required FriendRequestCreateRequest body,
})

Send friend request.

Sends a friend request to a user identified by user ID. Returns the new relationship object. Can fail if user not found or request already sent.

userId - The ID of the user.

body - Name not received - field will be skipped.

Implementation

@POST('/users/@me/relationships/{user_id}')
Future<RelationshipResponse> sendFriendRequest({
  @Path('user_id') required SnowflakeType userId,
  @Body() required FriendRequestCreateRequest body,
});