sendPhoneVerificationCode abstract method
- @POST.new('/users/@me/phone/send-verification')
- @Body.new() required PhoneSendVerificationRequest body,
Send phone verification code.
Send a one-time code on the requested channel. Defaults to the first available channel from server policy. Pass channel="sms" to request SMS (only honoured for SMS-allowlisted destinations) or channel="inbound_challenge" to receive challenge details to text in. Expensive outbound destinations always downgrade to an inbound challenge.
body - Name not received - field will be skipped.
Implementation
@POST('/users/@me/phone/send-verification')
Future<PhoneSendVerificationResponse> sendPhoneVerificationCode({
@Body() required PhoneSendVerificationRequest body,
});