setNoteOnUser abstract method
- @PUT.new('/users/@me/notes/{target_id}')
- @Path.new('target_id') required String targetId,
- @Body.new() required UserNoteUpdateRequest body,
Set note on user.
Creates or updates a private note on another user. The note is visible only to the authenticated user. Send null or empty string to delete an existing note.
targetId - The target id.
body - Name not received - field will be skipped.
Implementation
@PUT('/users/@me/notes/{target_id}')
Future<void> setNoteOnUser({
@Path('target_id') required String targetId,
@Body() required UserNoteUpdateRequest body,
});