startInboundPhoneChallenge abstract method

  1. @POST.new('/users/@me/phone/inbound-challenge')
Future<InboundSmsChallengeStartResponse> startInboundPhoneChallenge()

Start an inbound SMS challenge.

For very-high-risk registrations the platform requires the user to text a one-time code to the platform's number, instead of receiving a code from the platform. This endpoint generates the code and the destination number to display.

Implementation

@POST('/users/@me/phone/inbound-challenge')
Future<InboundSmsChallengeStartResponse> startInboundPhoneChallenge();