unpinDirectMessageChannel abstract method
- @DELETE.new('/users/@me/channels/{channel_id}/pin')
- @Path.new('channel_id') required SnowflakeType channelId,
Unpin direct message channel.
Unpins a private message channel for the current user. The channel will return to its normal position in the channel list based on activity.
channelId - The ID of the channel.
Implementation
@DELETE('/users/@me/channels/{channel_id}/pin')
Future<void> unpinDirectMessageChannel({
@Path('channel_id') required SnowflakeType channelId,
});