unsubscribeFromPushNotifications abstract method
- @DELETE.new('/users/@me/push/subscriptions/{subscription_id}')
- @Path.new('subscription_id') required String subscriptionId,
Unsubscribe from push notifications.
Unregisters a push notification subscription for the current user. Push notifications will no longer be sent to this subscription endpoint.
subscriptionId - The subscription id.
Implementation
@DELETE('/users/@me/push/subscriptions/{subscription_id}')
Future<SuccessResponse> unsubscribeFromPushNotifications({
@Path('subscription_id') required String subscriptionId,
});