getWebhook abstract method
- @GET.new('/webhooks/{webhook_id}')
- @Path.new('webhook_id') required SnowflakeType webhookId,
Get webhook.
Retrieves detailed information about a specific webhook by its ID. Requires authentication and appropriate permissions to access the webhook.
webhookId - The ID of the webhook.
Implementation
@GET('/webhooks/{webhook_id}')
Future<WebhookResponse> getWebhook({
@Path('webhook_id') required SnowflakeType webhookId,
});