listChannelWebhooks abstract method
- @GET.new('/channels/{channel_id}/webhooks')
- @Path.new('channel_id') required SnowflakeType channelId,
List channel webhooks.
Returns a list of all webhooks configured in the specified channel. Requires the user to have appropriate permissions to view webhooks in the channel.
channelId - The ID of the channel.
Implementation
@GET('/channels/{channel_id}/webhooks')
Future<List<WebhookResponse>> listChannelWebhooks({
@Path('channel_id') required SnowflakeType channelId,
});