listGuildWebhooks abstract method
- @GET.new('/guilds/{guild_id}/webhooks')
- @Path.new('guild_id') required SnowflakeType guildId,
List guild webhooks.
Returns a list of all webhooks configured in the specified guild. Requires the user to have appropriate permissions to view webhooks in the guild.
guildId - The ID of the guild.
Implementation
@GET('/guilds/{guild_id}/webhooks')
Future<List<WebhookResponse>> listGuildWebhooks({
@Path('guild_id') required SnowflakeType guildId,
});